@@ -1,4 +1,4 @@
-#!/usr/bin/php -d short_open_tag=on
+#!/usr/bin/php
 <?php
 if ('cli' != php_sapi_name()) die();
 
@@ -13,13 +13,13 @@ require_once DOKU_INC.'inc/cliopts.php';
 #------------------------------------------------------------------------------
 function usage() {
     print "Usage: wantedpages.php [wiki:namespace]
-    
+
     Outputs a list of wanted pages (pages which have
     internal links but do not yet exist).
-    
+
     If the optional [wiki:namespace] is not provided,
     defaults to the root wiki namespace
-    
+
     OPTIONS
         -h, --help get help
 ";
@@ -49,17 +49,17 @@ function dw_dir_filter($entry, $basepath) {
 
 #------------------------------------------------------------------------------
 function dw_get_pages($dir) {
-    static $trunclen = NULL;
+    static $trunclen = null;
     if ( !$trunclen ) {
         global $conf;
         $trunclen = strlen($conf['datadir'].':');
     }
-    
+
     if ( !is_dir($dir) ) {
         fwrite( STDERR, "Unable to read directory $dir\n");
         exit(1);
     }
-    
+
     $pages = array();
     $dh = opendir($dir);
     while ( false !== ( $entry = readdir($dh) ) ) {
@@ -92,7 +92,7 @@ function dw_internal_links($page) {
             $mid = $ins[1][0];
             resolve_pageid($cns,$mid,$exists);
             if ( !$exists ) {
-								list($mid) = explode('#',$mid); //record pages without hashs
+                list($mid) = explode('#',$mid); //record pages without hashs
                 $links[] = $mid;
             }
         }
