@@ -20,6 +20,7 @@ function act_dispatch(){
     global $ID;
     global $INFO;
     global $QUERY;
+    global $INPUT;
     global $lang;
     global $conf;
 
@@ -30,7 +31,7 @@ function act_dispatch(){
     if ($evt->advise_before()) {
 
         //sanitize $ACT
-        $ACT = act_clean($ACT);
+        $ACT = act_validate($ACT);
 
         //check if searchword was given - else just show
         $s = cleanID($QUERY);
@@ -52,7 +53,7 @@ function act_dispatch(){
             }
         }
 
-        //display some infos
+        //display some info
         if($ACT == 'check'){
             check();
             $ACT = 'show';
@@ -63,11 +64,27 @@ function act_dispatch(){
 
         //sitemap
         if ($ACT == 'sitemap'){
-            $ACT = act_sitemap($ACT);
+            act_sitemap($ACT);
+        }
+
+        //recent changes
+        if ($ACT == 'recent'){
+            $show_changes = $INPUT->str('show_changes');
+            if (!empty($show_changes)) {
+                set_doku_pref('show_changes', $show_changes);
+            }
+        }
+
+        //diff
+        if ($ACT == 'diff'){
+            $difftype = $INPUT->str('difftype');
+            if (!empty($difftype)) {
+                set_doku_pref('difftype', $difftype);
+            }
         }
 
         //register
-        if($ACT == 'register' && $_POST['save'] && register()){
+        if($ACT == 'register' && $INPUT->post->bool('save') && register()){
             $ACT = 'login';
         }
 
@@ -75,14 +92,26 @@ function act_dispatch(){
             $ACT = 'login';
         }
 
-        //update user profile
-        if ($ACT == 'profile') {
+        // user profile changes
+        if (in_array($ACT, array('profile','profile_delete'))) {
             if(!$_SERVER['REMOTE_USER']) {
                 $ACT = 'login';
             } else {
-                if(updateprofile()) {
-                    msg($lang['profchanged'],1);
-                    $ACT = 'show';
+                switch ($ACT) {
+                    case 'profile' :
+                        if(updateprofile()) {
+                            msg($lang['profchanged'],1);
+                            $ACT = 'show';
+                        }
+                        break;
+                    case 'profile_delete' :
+                        if(auth_deleteprofile()){
+                            msg($lang['profdeleted'],1);
+                            $ACT = 'show';
+                        } else {
+                            $ACT = 'profile';
+                        }
+                        break;
                 }
             }
         }
@@ -101,7 +130,7 @@ function act_dispatch(){
             if(checkSecurityToken()){
                 $ACT = act_save($ACT);
             }else{
-                $ACT = 'show';
+                $ACT = 'preview';
             }
         }
 
@@ -131,14 +160,16 @@ function act_dispatch(){
         //handle admin tasks
         if($ACT == 'admin'){
             // retrieve admin plugin name from $_REQUEST['page']
-            if (!empty($_REQUEST['page'])) {
+            if (($page = $INPUT->str('page', '', true)) != '') {
                 $pluginlist = plugin_list('admin');
-                if (in_array($_REQUEST['page'], $pluginlist)) {
+                if (in_array($page, $pluginlist)) {
                     // attempt to load the plugin
-                    if ($plugin =& plugin_load('admin',$_REQUEST['page']) !== null){
+
+                    if (($plugin = plugin_load('admin',$page)) !== null){
+                        /** @var DokuWiki_Admin_Plugin $plugin */
                         if($plugin->forAdminOnly() && !$INFO['isadmin']){
                             // a manager tried to load a plugin that's for admins only
-                            unset($_REQUEST['page']);
+                            $INPUT->remove('page');
                             msg('For admins only',-1);
                         }else{
                             $plugin->handle();
@@ -154,7 +185,7 @@ function act_dispatch(){
     $evt->advise_after();
     // Make sure plugs can handle 'denied'
     if($conf['send404'] && $ACT == 'denied') {
-        header('HTTP/1.0 403 Forbidden');
+        http_status(403);
     }
     unset($evt);
 
@@ -176,6 +207,11 @@ function act_dispatch(){
     // in function tpl_content()
 }
 
+/**
+ * Send the given headers using header()
+ *
+ * @param array $headers The headers that shall be sent
+ */
 function act_sendheaders($headers) {
     foreach ($headers as $hdr) header($hdr);
 }
@@ -183,15 +219,9 @@ function act_sendheaders($headers) {
 /**
  * Sanitize the action command
  *
- * Add all allowed commands here.
- *
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function act_clean($act){
-    global $lang;
-    global $conf;
-    global $INFO;
-
     // check if the action was given as array key
     if(is_array($act)){
         list($act) = array_keys($act);
@@ -205,6 +235,21 @@ function act_clean($act){
     if($act == 'export_htmlbody') $act = 'export_xhtmlbody';
 
     if($act === '') $act = 'show';
+    return $act;
+}
+
+/**
+ * Sanitize and validate action commands.
+ *
+ * Add all allowed commands here.
+ *
+ * @author Andreas Gohr <andi@splitbrain.org>
+ */
+function act_validate($act) {
+    global $conf;
+    global $INFO;
+
+    $act = act_clean($act);
 
     // check if action is disabled
     if(!actionOK($act)){
@@ -215,7 +260,7 @@ function act_clean($act){
     //disable all acl related commands if ACL is disabled
     if(!$conf['useacl'] && in_array($act,array('login','logout','register','admin',
                     'subscribe','unsubscribe','profile','revert',
-                    'resendpwd','subscribens','unsubscribens',))){
+                    'resendpwd','profile_delete'))){
         msg('Command unavailable: '.htmlspecialchars($act),-1);
         return 'show';
     }
@@ -226,8 +271,8 @@ function act_clean($act){
     if(!in_array($act,array('login','logout','register','save','cancel','edit','draft',
                     'preview','search','show','check','index','revisions',
                     'diff','recent','backlink','admin','subscribe','revert',
-                    'unsubscribe','profile','resendpwd','recover',
-                    'draftdel','subscribens','unsubscribens','sitemap')) && substr($act,0,7) != 'export_' ) {
+                    'unsubscribe','profile','profile_delete','resendpwd','recover',
+                    'draftdel','sitemap','media')) && substr($act,0,7) != 'export_' ) {
         msg('Command unknown: '.htmlspecialchars($act),-1);
         return 'show';
     }
@@ -255,7 +300,7 @@ function act_permcheck($act){
         }else{
             $permneed = AUTH_CREATE;
         }
-    }elseif(in_array($act,array('login','search','recent','profile','index', 'sitemap'))){
+    }elseif(in_array($act,array('login','search','recent','profile','profile_delete','index', 'sitemap'))){
         $permneed = AUTH_NONE;
     }elseif($act == 'revert'){
         $permneed = AUTH_ADMIN;
@@ -300,13 +345,14 @@ function act_draftdel($act){
 function act_draftsave($act){
     global $INFO;
     global $ID;
+    global $INPUT;
     global $conf;
-    if($conf['usedraft'] && $_POST['wikitext']){
+    if($conf['usedraft'] && $INPUT->post->has('wikitext')) {
         $draft = array('id'     => $ID,
-                'prefix' => substr($_POST['prefix'], 0, -1),
-                'text'   => $_POST['wikitext'],
-                'suffix' => $_POST['suffix'],
-                'date'   => (int) $_POST['date'],
+                'prefix' => substr($INPUT->post->str('prefix'), 0, -1),
+                'text'   => $INPUT->post->str('wikitext'),
+                'suffix' => $INPUT->post->str('suffix'),
+                'date'   => $INPUT->post->int('date'),
                 'client' => $INFO['client'],
                 );
         $cname = getCacheName($draft['client'].$ID,'.draft');
@@ -335,6 +381,7 @@ function act_save($act){
     global $SUM;
     global $lang;
     global $INFO;
+    global $INPUT;
 
     //spam check
     if(checkwordblock()) {
@@ -346,7 +393,7 @@ function act_save($act){
         return 'conflict';
 
     //save it
-    saveWikiText($ID,con($PRE,$TEXT,$SUF,1),$SUM,$_REQUEST['minor']); //use pretty mode for con
+    saveWikiText($ID,con($PRE,$TEXT,$SUF,1),$SUM,$INPUT->bool('minor')); //use pretty mode for con
     //unlock it
     unlock($ID);
 
@@ -380,7 +427,7 @@ function act_revert($act){
     if($REV){
         $text = rawWiki($ID,$REV);
         if(!$text) return 'show'; //something went wrong
-        $sum  = $lang['restored'];
+        $sum = sprintf($lang['restored'], dformat($REV));
     }
 
     // spam check
@@ -425,6 +472,11 @@ function act_redirect($id,$preact){
     trigger_event('ACTION_SHOW_REDIRECT',$opts,'act_redirect_execute');
 }
 
+/**
+ * Execute the redirect
+ *
+ * @param array $opts id and fragment for the redirect
+ */
 function act_redirect_execute($opts){
     $go = wl($opts['id'],'',true);
     if(isset($opts['fragment'])) $go .= '#'.$opts['fragment'];
@@ -498,7 +550,7 @@ function act_edit($act){
     //set summary default
     if(!$SUM){
         if($REV){
-            $SUM = $lang['restored'];
+            $SUM = sprintf($lang['restored'], dformat($REV));
         }elseif(!$INFO['exists']){
             $SUM = $lang['created'];
         }
@@ -506,7 +558,7 @@ function act_edit($act){
 
     // Use the date of the newest revision, not of the revision we edit
     // This is used for conflict detection
-    if(!$DATE) $DATE = $INFO['meta']['date']['modified'];
+    if(!$DATE) $DATE = @filemtime(wikiFN($ID));
 
     //check if locked by anyone - if not lock for my self
     //do not lock when the user can't edit anyway
@@ -556,12 +608,10 @@ function act_export($act){
             $output = rawWiki($ID,$REV);
             break;
         case 'xhtml':
-            $pre .= '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"' . DOKU_LF;
-            $pre .= ' "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">' . DOKU_LF;
-            $pre .= '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="'.$conf['lang'].'"' . DOKU_LF;
-            $pre .= ' lang="'.$conf['lang'].'" dir="'.$lang['direction'].'">' . DOKU_LF;
+            $pre .= '<!DOCTYPE html>' . DOKU_LF;
+            $pre .= '<html lang="'.$conf['lang'].'" dir="'.$lang['direction'].'">' . DOKU_LF;
             $pre .= '<head>' . DOKU_LF;
-            $pre .= '  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />' . DOKU_LF;
+            $pre .= '  <meta charset="utf-8" />' . DOKU_LF;
             $pre .= '  <title>'.$ID.'</title>' . DOKU_LF;
 
             // get metaheaders
@@ -621,13 +671,13 @@ function act_sitemap($act) {
     global $conf;
 
     if ($conf['sitemap'] < 1 || !is_numeric($conf['sitemap'])) {
-        header("HTTP/1.0 404 Not Found");
+        http_status(404);
         print "Sitemap generation is disabled.";
         exit;
     }
 
     $sitemap = Sitemapper::getFilePath();
-    if(strrchr($sitemap, '.') === '.gz'){
+    if (Sitemapper::sitemapIsCompressed()) {
         $mime = 'application/x-gzip';
     }else{
         $mime = 'application/xml; charset=utf-8';
@@ -641,7 +691,7 @@ function act_sitemap($act) {
     if (is_readable($sitemap)) {
         // Send headers
         header('Content-Type: '.$mime);
-        header('Content-Disposition: attachment; filename='.basename($sitemap));
+        header('Content-Disposition: attachment; filename='.utf8_basename($sitemap));
 
         http_conditionalRequest(filemtime($sitemap));
 
@@ -653,7 +703,7 @@ function act_sitemap($act) {
         exit;
     }
 
-    header("HTTP/1.0 500 Internal Server Error");
+    http_status(500);
     print "Could not read the sitemap file - bad permissions?";
     exit;
 }
@@ -669,6 +719,7 @@ function act_subscription($act){
     global $lang;
     global $INFO;
     global $ID;
+    global $INPUT;
 
     // subcriptions work for logged in users only
     if(!$_SERVER['REMOTE_USER']) return 'show';
@@ -676,8 +727,8 @@ function act_subscription($act){
     // get and preprocess data.
     $params = array();
     foreach(array('target', 'style', 'action') as $param) {
-        if (isset($_REQUEST["sub_$param"])) {
-            $params[$param] = $_REQUEST["sub_$param"];
+        if ($INPUT->has("sub_$param")) {
+            $params[$param] = $INPUT->str("sub_$param");
         }
     }
 
@@ -689,21 +740,28 @@ function act_subscription($act){
 
     $target = $params['target'];
     $style  = $params['style'];
-    $data   = $params['data'];
     $action = $params['action'];
 
     // Perform action.
-    if (!subscription_set($_SERVER['REMOTE_USER'], $target, $style, $data)) {
+    $sub = new Subscription();
+    if($action == 'unsubscribe'){
+        $ok = $sub->remove($target, $_SERVER['REMOTE_USER'], $style);
+    }else{
+        $ok = $sub->add($target, $_SERVER['REMOTE_USER'], $style);
+    }
+
+    if($ok) {
+        msg(sprintf($lang["subscr_{$action}_success"], hsc($INFO['userinfo']['name']),
+                    prettyprint_id($target)), 1);
+        act_redirect($ID, $act);
+    } else {
         throw new Exception(sprintf($lang["subscr_{$action}_error"],
                                     hsc($INFO['userinfo']['name']),
                                     prettyprint_id($target)));
     }
-    msg(sprintf($lang["subscr_{$action}_success"], hsc($INFO['userinfo']['name']),
-                prettyprint_id($target)), 1);
-    act_redirect($ID, $act);
 
     // Assure that we have valid data if act_redirect somehow fails.
-    $INFO['subscribed'] = get_info_subscribed();
+    $INFO['subscribed'] = $sub->user_subscription();
     return 'show';
 }
 
@@ -755,8 +813,7 @@ function subscription_handle_post(&$params) {
         $style = null;
     }
 
-    $data = in_array($style, array('list', 'digest')) ? time() : null;
-    $params = compact('target', 'style', 'data', 'action');
+    $params = compact('target', 'style', 'action');
 }
 
 //Setup VIM: ex: et ts=2 :
