@@ -37,12 +37,8 @@ $lang['btn_back']              = 'Geri';
 $lang['btn_backlink']          = 'Bura olan link-lər';
 $lang['btn_backtomedia']       = 'media-fayl seçiminə qayıt';
 $lang['btn_subscribe']         = 'Abunə ol (bütün dəyişiklər)';
-$lang['btn_unsubscribe']       = 'Abunəlikdən çıx (bütün dəyişiklər)';
-$lang['btn_subscribens']       = 'Abunə ol (bu bölümün dəyişikləri)';
-$lang['btn_unsubscribens']     = 'Abunəlikdən çıx (bu bölümün dəyişikləri)';
 $lang['btn_profile']           = 'Profil';
 $lang['btn_reset']             = 'Boşalt';
-$lang['btn_resendpwd']         = 'Yeni şifrəni göndər';
 $lang['btn_draft']             = 'Qaralamada düzəliş etmək';
 $lang['btn_recover']           = 'Qaralamanı qaytar';
 $lang['btn_draftdel']          = 'Qaralamanı sil';
@@ -77,7 +73,6 @@ $lang['profnoempty']           = 'istifadəci adı və e-mail ünvanı boş ola
 $lang['profchanged']           = 'İstifadəçi profili uğurla yeniləndi.';
 $lang['pwdforget']             = 'Şifrəni yaddan çıxartmısız? Buyurun yenisini əldə edin';
 $lang['resendna']              = 'Bu wiki şifrəni yenidən göndərməyi dəstəkləmir.';
-$lang['resendpwd']             = 'Yeni şifrəni göndər:';
 $lang['resendpwdmissing']      = 'Formanın bütün xanəlırini doldurun.';
 $lang['resendpwdnouser']       = 'Verilənlər bazasında bu ad ilə istifadəçi tapılmadı.';
 $lang['resendpwdbadauth']      = 'Ativləşdirmə kodu səhvdir. Link-i tam olaraq köçürdüyünüzü yoxlayın. ';
@@ -92,8 +87,7 @@ $lang['txt_filename']          = 'Faylın wiki-də olan adını daxil edin (müt
 $lang['txt_overwrt']           = 'Mövcud olan faylın üstündən yaz';
 $lang['lockedby']              = 'В данный момент заблокирован Bu an blokdadır';
 $lang['lockexpire']            = 'Blok bitir:';
-$lang['willexpire']            = 'Sizin bu səhifədə dəyişik etmək üçün blokunuz bir dəqiqə ərzində bitəcək.\nMünaqişələrdən yayınmaq və blokun taymerini sıfırlamaq üçün, baxış düyməsini sıxın.';
-$lang['notsavedyet']           = 'Yaddaşa yazılmamış dəyişiklər itəcəklər.\nSiz davam etmək istəyirsiz?';
+$lang['js']['willexpire']            = 'Sizin bu səhifədə dəyişik etmək üçün blokunuz bir dəqiqə ərzində bitəcək.\nMünaqişələrdən yayınmaq və blokun taymerini sıfırlamaq üçün, baxış düyməsini sıxın.';
 $lang['rssfailed']             = 'Aşağıda göstərilmiş xəbər lentini əldə edən zaman xəta baş verdi: ';
 $lang['nothingfound']          = 'Heçnə tapılmadı.';
 $lang['mediaselect']           = 'Mediya-faylın seçilməsi';
@@ -118,7 +112,6 @@ $lang['js']['nosmblinks']      = 'Windows-un şəbəkə qovluqlarına link ancaq
 $lang['js']['linkwiz']         = 'Linklər köməkçisi';
 $lang['js']['linkto']          = 'Link göstərir:';
 $lang['js']['del_confirm']     = 'Siz əminsiz ki, seçilmişləri silmək istəyirsiniz?';
-$lang['js']['mu_btn']          = 'Bir neçə faylı birdən yükləmək';
 $lang['mediausage']            = 'Bu fayla link yaratmaq üçün aşağıdakı sintaksisdən istifadə edin:';
 $lang['mediaview']             = 'Bu faylın ilkinə bax';
 $lang['mediaroot']             = 'kök';
@@ -141,7 +134,7 @@ $lang['lastmod']               = 'Son dəyişiklər';
 $lang['by']                    = ' Kimdən';
 $lang['deleted']               = 'silinib';
 $lang['created']               = 'yaranıb';
-$lang['restored']              = 'köhnə versiya qaytarıldı';
+$lang['restored']              = 'köhnə versiya qaytarıldı (%s)';
 $lang['external_edit']         = 'bayırdan dəyişik';
 $lang['summary']               = 'Dəyişiklər xülasəsi';
 $lang['noflash']               = 'Bu məzmuna baxmaq üçün <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> tələb olunur.';
@@ -190,12 +183,6 @@ $lang['img_copyr']             = 'Müəllif hüquqları';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Model';
 $lang['img_keywords']          = 'Açar sözlər';
-$lang['subscribe_success']     = '%s adlı istifadəçi %s səhifənin paylanma siyahısına əlavə olundu';
-$lang['subscribe_error']       = '%s adlı istifadəçini %s səhifənin paylanma siyahısına əlavə etmə zamanı səhv baş verdi';
-$lang['subscribe_noaddress']   = 'Sizin profilinizdə e-mail göstərilməyib.Ona görə siz paylnma siyahılarına əlavə edilə bilməzsiniz.';
-$lang['unsubscribe_success']   = '%s adlı istifadəçi %s səhifənin paylanma siyahısından silinmişdir';
-$lang['unsubscribe_error']     = '%s adlı istifadəçini %s səhifənin paylanma siyahısından silən zaman xəta baş verdi.';
-$lang['authmodfailed']         = 'İstifadəçinin autentifikasiyasının konfiqurasiyası səhfdir. Xaiş olunur ki wiki-nin administratoru ilə əlaqə saxlayasınız.';
 $lang['authtempfail']          = 'İstifadəçilərin autentifikasiyası müvəqqəti dayandırılıb. Əgər bu problem uzun müddət davam edir sə, administrator ilə əlaqə saxlayın.';
 $lang['i_chooselang']          = 'Dili seçin/Language';
 $lang['i_installer']           = 'DokuWiki quraşdırılır';
@@ -213,28 +200,13 @@ $lang['i_writeerr']            = '<code>%s</code> yaradıla bilmədi. Faylın/qo
 $lang['i_badhash']             = 'dokuwiki.php tanıla bilmir və ya dəyişdirilmişdir (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - səhv ya boş qiymətdir';
 $lang['i_success']             = 'Konfiqurasiya uğurla başa çatdı. İndi siz install.php faylını silə bilərsiniz.
-                        <a href="doku.php">Yeni DokuWiki-nizə</a> xoş gəlmişsiniz!';
-$lang['i_failure']             = 'Konfiqurasiya fayllarına məlumat yazan zaman səhvlər tapıldı. Yəgin ki, <a href="doku.php">yeni DokuWiki-nizi</a> istifadə etmədən öncə, Siz o xətaları əl ilə düzəltməli olacaqsınız.';
+                        <a href="doku.php?id=wiki:welcome">Yeni DokuWiki-nizə</a> xoş gəlmişsiniz!';
+$lang['i_failure']             = 'Konfiqurasiya fayllarına məlumat yazan zaman səhvlər tapıldı. Yəgin ki, <a href="doku.php?id=wiki:welcome">yeni DokuWiki-nizi</a> istifadə etmədən öncə, Siz o xətaları əl ilə düzəltməli olacaqsınız.';
 $lang['i_policy']              = 'İlkin giriş haqları siyasəti';
 $lang['i_pol0']                = 'Tam açıq wiki (oxumaq, yazmaq, fayl yükləmək hamıya olar)';
 $lang['i_pol1']                = 'Acıq wiki (oxumaq hamıya olar, yazmaq və fayl yükləmək ancaq üzv olan istifadəçilərə olar)';
 $lang['i_pol2']                = 'Bağlı wiki (uxumaq, yazmaq və yükləmək ancaq üzv olan istifadəçilərə olar)';
 $lang['i_retry']               = 'Cəhdi təkrarla';
-$lang['mu_intro']              = 'Burda siz bir neçə faylı birdən yükləyə bilərsiniz. Fayl əlavə etmək üçün "fayl seç" düyməsini sıxın. Sonda "yüklə" düyməsini sıxın.';
-$lang['mu_gridname']           = 'Faylın adı';
-$lang['mu_gridsize']           = 'Həcmi';
-$lang['mu_gridstat']           = 'Status';
-$lang['mu_namespace']          = 'Namespace';
-$lang['mu_browse']             = 'Fayl seç';
-$lang['mu_toobig']             = 'çox böyükdür';
-$lang['mu_ready']              = 'yükləməyə hazırdı';
-$lang['mu_done']               = 'başa çatdı';
-$lang['mu_fail']               = 'xəta baş verdi';
-$lang['mu_authfail']           = 'sessiyanın vaxtı bitdi';
-$lang['mu_progress']           = '@PCT@% yükləndi';
-$lang['mu_filetypes']          = 'İçazə olan fayl növləri';
-$lang['mu_info']               = 'fayllar yükləndi.';
-$lang['mu_lasterr']            = 'Son xəta:';
 $lang['recent_global']         = '<b>%s</b> namespace-də baş vermiş dəyışıklərə baxırsınız. Siz həmçinin <a href="%s">wiki-də bu yaxında baş vermiş bütün dəyişiklərə</a> baxa bilərsiniz.';
 $lang['years']                 = '%d il əvvəl';
 $lang['months']                = '%d ay əvvəl';
