@@ -1,15 +1,15 @@
 <?php
+
 /**
- * Esperanta dosiero
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Antono Vasiljev <esperanto.minsk ĈE tut.by>
  * @author Felipe Castro <fefcas@yahoo.com.br>
  * @author Felipe Castro <fefcas@uol.com.br>
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Robert Bogenschneider <robog@gmx.de>
  * @author Erik Pedersen <erik.pedersen@shaw.ca>
- * @author Robert BOGENSCHNEIDER <bogi@UEA.org>
+ * @author Robert Bogenschneider <bogi@uea.org>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -53,6 +53,7 @@ $lang['btn_revert']            = 'Restarigi';
 $lang['btn_register']          = 'Registriĝi';
 $lang['btn_apply']             = 'Apliki';
 $lang['btn_media']             = 'Medio-administrilo';
+$lang['btn_deleteuser']        = 'Forigi mian aliĝon';
 $lang['loggedinas']            = 'Ensalutinta kiel';
 $lang['user']                  = 'Uzant-nomo';
 $lang['pass']                  = 'Pasvorto';
@@ -64,44 +65,51 @@ $lang['fullname']              = 'Kompleta nomo';
 $lang['email']                 = 'Retpoŝto';
 $lang['profile']               = 'Uzanto-profilo';
 $lang['badlogin']              = 'Pardonu, uzant-nomo aŭ pasvorto estis erara.';
+$lang['badpassconfirm']        = 'Pardonu, la pasvorto malĝustis';
 $lang['minoredit']             = 'Etaj modifoj';
 $lang['draftdate']             = 'Lasta konservo de la skizo:';
 $lang['nosecedit']             = 'La paĝo ŝanĝiĝis intertempe, sekcio-informo estis malĝisdata, tial la tuta paĝo estas reŝargita.';
 $lang['regmissing']            = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
 $lang['reguexists']            = 'Pardonu, ĉi tiu uzanto-nomo jam ekzistas.';
-$lang['regsuccess']            = 'La uzanto estas kreita kaj la pasvorto estis elsendita per retpoŝto.';
-$lang['regsuccess2']           = 'La uzanto estas kreita.';
+$lang['regsuccess']            = 'La uzanto kreiĝis kaj la pasvorto sendiĝis per retpoŝto.';
+$lang['regsuccess2']           = 'La uzanto kreiĝis.';
 $lang['regmailfail']           = 'Ŝajne okazis eraro dum elsendo de la pasvorto. Bonvolu informi administranton pri tio!';
-$lang['regbadmail']            = 'Entajpita retpoŝta adreso ne ŝajnas valida. Se vi pensas, ke tio estas eraro, kontaktu la administranton.';
+$lang['regbadmail']            = 'Entajpita retpoŝta adreso ŝajnas ne valida. Se vi pensas, ke tio estas eraro, kontaktu la administranton.';
 $lang['regbadpass']            = 'La du pasvortoj ne samas, bonvolu provi refoje.';
 $lang['regpwmail']             = 'Via DokuWiki-pasvorto';
 $lang['reghere']               = 'Se vi ne havas konton, vi povas akiri ĝin';
 $lang['profna']                = 'Tiu ĉi vikio ne ebligas modifon en la profiloj.';
 $lang['profnochange']          = 'Neniu ŝanĝo, nenio farinda.';
-$lang['profnoempty']           = 'Malplena nomo aŭ retadreso ne estas permesataj.';
-$lang['profchanged']           = 'La profilo de la uzanto estas sukcese ĝisdatigita.';
+$lang['profnoempty']           = 'Malplena nomo aŭ retadreso ne estas permesata.';
+$lang['profchanged']           = 'La profilo de la uzanto sukcese ĝisdatiĝis.';
+$lang['profnodelete']          = 'Tiu ĉi vikio ne subtenas forigo de uzantoj';
+$lang['profdeleteuser']        = 'Forigi aliĝon';
+$lang['profdeleted']           = 'Via uzant-aliĝo estis forigata de tiu ĉi vikio';
+$lang['profconfdelete']        = 'Mi deziras forigi mian aliĝon de tiu ĉi vikio. <br/> Tiu ĉi ago ne povos esti malfarata.';
+$lang['profconfdeletemissing'] = 'Konfirmilo ne estas markita';
 $lang['pwdforget']             = 'Ĉu vi forgesis vian pasvorton? Prenu novan';
 $lang['resendna']              = 'Tiu ĉi vikio ne ebligas resendon de la pasvortoj.';
 $lang['resendpwd']             = 'Sendi novan pasvorton al';
 $lang['resendpwdmissing']      = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
-$lang['resendpwdnouser']       = 'Pardonu, ni ne trovas tiun uzanton en nia datenbazo.';
+$lang['resendpwdnouser']       = 'Pardonu, tiu uzanto ne troveblas en nia datumbazo.';
 $lang['resendpwdbadauth']      = 'Pardonu, tiu aŭtentiga kodo ne validas. Certiĝu, ke vi uzis la kompletan konfirmigan ligilon.';
-$lang['resendpwdconfirm']      = 'Konfirmiga ligilo estas sendita per retpoŝto.';
-$lang['resendpwdsuccess']      = 'Via nova pasvorto estas sendita per retpoŝto.';
+$lang['resendpwdconfirm']      = 'Konfirmiga ligilo sendiĝis per retpoŝto.';
+$lang['resendpwdsuccess']      = 'Via nova pasvorto sendiĝis per retpoŝto.';
 $lang['license']               = 'Krom kie rekte indikite, enhavo de tiu ĉi vikio estas publikigita laŭ la jena permesilo:';
 $lang['licenseok']             = 'Rimarku: redaktante tiun ĉi paĝon vi konsentas publikigi vian enhavon laŭ la jena permesilo:';
 $lang['searchmedia']           = 'Serĉi dosiernomon:';
 $lang['searchmedia_in']        = 'Serĉi en %s';
-$lang['txt_upload']            = 'Elektu dosieron por alŝuto';
+$lang['txt_upload']            = 'Elektu dosieron por alŝuti';
 $lang['txt_filename']          = 'Alŝuti kiel (laŭvole)';
 $lang['txt_overwrt']           = 'Anstataŭigi ekzistantan dosieron';
+$lang['maxuploadsize']         = 'Alŝuto maks. %s po dosiero.';
 $lang['lockedby']              = 'Nune ŝlosita de';
 $lang['lockexpire']            = 'Ŝlosado ĉesos en';
-$lang['js']['willexpire']      = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempkontrolon de la ŝlosado, do premu butonon "Antaŭrigardi".';
+$lang['js']['willexpire']      = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempokontrolon de la ŝlosado, premu la butonon "Antaŭrigardi".';
 $lang['js']['notsavedyet']     = 'Ne konservitaj modifoj perdiĝos.
 Ĉu vi certe volas daŭrigi la procezon?';
 $lang['js']['searchmedia']     = 'Serĉi dosierojn';
-$lang['js']['keepopen']        = 'Tenu la fenestron malfermata dum elekto';
+$lang['js']['keepopen']        = 'Tenu la fenestron malferma dum elekto';
 $lang['js']['hidedetails']     = 'Kaŝi detalojn';
 $lang['js']['mediatitle']      = 'Ligilaj agordoj';
 $lang['js']['mediadisplay']    = 'Ligila tipo';
@@ -124,10 +132,10 @@ $lang['js']['medialeft']       = 'Meti la bildon maldekstren.';
 $lang['js']['mediaright']      = 'Meti la bildon dekstren.';
 $lang['js']['mediacenter']     = 'Meti la bildon mezen.';
 $lang['js']['medianoalign']    = 'Ne uzi poziciigon.';
-$lang['js']['nosmblinks']      = 'Tio ĉi nur funkcias en la Vindozaĉa "Microsoft Internet Explorer".\nVi ankoraŭ povas kopii kaj almeti la ligilon.';
+$lang['js']['nosmblinks']      = 'Tio ĉi nur funkcias en "Microsoft Internet Explorer".\nVi ankoraŭ povas kopii kaj almeti la ligilon.';
 $lang['js']['linkwiz']         = 'Ligil-Asistanto';
 $lang['js']['linkto']          = 'Ligilo al:';
-$lang['js']['del_confirm']     = 'Ĉu vere forigi elektitajn ero(j)n?';
+$lang['js']['del_confirm']     = 'Ĉu vere forigi elektita(j)n ero(j)n?';
 $lang['js']['restore_confirm'] = 'Ĉu vere restarigi ĉi tiun version?';
 $lang['js']['media_diff']      = 'Rigardu la diferencojn:';
 $lang['js']['media_diff_both'] = 'Flankon apud flanko';
@@ -143,27 +151,27 @@ $lang['rssfailed']             = 'Okazis eraro dum ricevado de la novaĵ-fluo: '
 $lang['nothingfound']          = 'Ankoraŭ nenio troviĝas tie ĉi.';
 $lang['mediaselect']           = 'Elekto de aŭdvidaĵa dosiero';
 $lang['fileupload']            = 'Alŝuto de aŭdvidaĵa dosiero';
-$lang['uploadsucc']            = 'Alŝuto estis sukcesa';
-$lang['uploadfail']            = 'Alŝuto estis malsukcesa. Eble ĉu estas problemoj pro permes-atributoj?';
+$lang['uploadsucc']            = 'Alŝuto sukcesis';
+$lang['uploadfail']            = 'Alŝuto malsukcesis. Ĉu eble estas problemoj pro permes-atributoj?';
 $lang['uploadwrong']           = 'Rifuzita alŝuto. Tiu ĉi dosiersufikso estas malpermesata!';
 $lang['uploadexist']           = 'La dosiero jam ekzistas. Nenio estas farita.';
 $lang['uploadbadcontent']      = 'La alŝutita enhavo ne kongruas al la sufikso %s.';
-$lang['uploadspam']            = 'La alŝutaĵo estis blokita de kontraŭspama vortlisto.';
-$lang['uploadxss']             = 'La alŝutajo estis blokita pro ebla malica enhavo.';
+$lang['uploadspam']            = 'La alŝutaĵo blokiĝis de kontraŭspama vortlisto.';
+$lang['uploadxss']             = 'La alŝutajo blokiĝis pro ebla malica enhavo.';
 $lang['uploadsize']            = 'La alŝutita dosiero estis tro granda. (maks. %s)';
-$lang['deletesucc']            = 'La dosiero "%s" estas forigita.';
+$lang['deletesucc']            = 'La dosiero "%s" forigiĝis.';
 $lang['deletefail']            = '"%s" ne povis esti forigita - kontrolu permes-atributojn.';
-$lang['mediainuse']            = 'La dosiero "%s" ne estis forigita - ĝi ankoraŭ estas uzata.';
+$lang['mediainuse']            = 'La dosiero "%s" ne forigiĝis - ĝi ankoraŭ estas uzata.';
 $lang['namespaces']            = 'Nomspacoj';
 $lang['mediafiles']            = 'Disponeblaj dosieroj';
 $lang['accessdenied']          = 'Vi ne rajtas vidi tiun paĝon.';
-$lang['mediausage']            = 'Uzu la jenan sintakson por referenci tiun ĉi dosieron:';
+$lang['mediausage']            = 'Uzu jenan sintakson por referenci tiun ĉi dosieron:';
 $lang['mediaview']             = 'Rigardi originalan dosieron';
 $lang['mediaroot']             = 'ĉefo (root)';
-$lang['mediaupload']           = 'Alŝutu dosieron al la kuranta nomspaco tien ĉi. Por krei subnomspacojn, antaŭmetu ilin al via "Alŝuti kiel" dosiernomo, apartigante per dupunktoj (:).';
+$lang['mediaupload']           = 'Alŝutu dosieron al la kuranta nomspaco tien ĉi. Por krei subnomspacojn, antaŭmetu ilin al via "Alŝuti kiel" dosiernomo, disigigante per dupunktoj (:).';
 $lang['mediaextchange']        = 'La dosiersufikso ŝanĝis de .%s al .%s!';
 $lang['reference']             = 'Referencoj por';
-$lang['ref_inuse']             = 'La dosiero ne povas esti forigita, ĉar ĝi ankoraŭ estas uzata de la jenaj paĝoj:';
+$lang['ref_inuse']             = 'La dosiero ne povas esti forigita, ĉar ĝi ankoraŭ estas uzata de jenaj paĝoj:';
 $lang['ref_hidden']            = 'Kelkaj referencoj estas en paĝoj, kiujn vi ne rajtas legi';
 $lang['hits']                  = 'Trafoj';
 $lang['quickhits']             = 'Trafoj trovitaj en paĝnomoj';
@@ -183,11 +191,17 @@ $lang['lastmod']               = 'Lastaj ŝanĝoj';
 $lang['by']                    = 'de';
 $lang['deleted']               = 'forigita';
 $lang['created']               = 'kreita';
-$lang['restored']              = 'malnova revizio restarigita';
+$lang['restored']              = 'malnova revizio restarigita (%s)';
 $lang['external_edit']         = 'ekstera redakto';
 $lang['summary']               = 'Bulteno de ŝanĝoj';
-$lang['noflash']               = 'La <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> estas bezonata por montrigi tiun ĉi enhavon.';
+$lang['noflash']               = 'La <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> necesas por montri tiun ĉi enhavon.';
 $lang['download']              = 'Elŝuti eltiraĵon';
+$lang['tools']                 = 'Iloj';
+$lang['user_tools']            = 'Uzantaj iloj';
+$lang['site_tools']            = 'Retejaj iloj';
+$lang['page_tools']            = 'Paĝaj iloj';
+$lang['skip_to_content']       = 'al la enhavo';
+$lang['sidebar']               = 'Flanka strio';
 $lang['mail_newpage']          = 'paĝo aldonita:';
 $lang['mail_changed']          = 'paĝo modifita:';
 $lang['mail_subscribe_list']   = 'ŝanĝitaj paĝoj en nomspaco:';
@@ -223,10 +237,10 @@ $lang['qb_smileys']            = 'Ridetuloj';
 $lang['qb_chars']              = 'Specialaj signaĵoj';
 $lang['upperns']               = 'saltu al la parenca nomspaco';
 $lang['admin_register']        = 'Aldoni novan uzanton';
-$lang['metaedit']              = 'Redakti metadatenaron';
-$lang['metasaveerr']           = 'La konservo de metadatenaro malsukcesis';
-$lang['metasaveok']            = 'La metadatenaro estis konservita';
-$lang['img_backto']            = 'Retroiri al';
+$lang['metaedit']              = 'Redakti metadatumaron';
+$lang['metasaveerr']           = 'La konservo de metadatumaro malsukcesis';
+$lang['metasaveok']            = 'La metadatumaro konserviĝis';
+$lang['img_backto']            = 'Iri reen al';
 $lang['img_title']             = 'Titolo';
 $lang['img_caption']           = 'Priskribo';
 $lang['img_date']              = 'Dato';
@@ -239,7 +253,7 @@ $lang['img_camera']            = 'Kamerao';
 $lang['img_keywords']          = 'Ŝlosilvortoj';
 $lang['img_width']             = 'Larĝeco';
 $lang['img_height']            = 'Alteco';
-$lang['img_manager']           = 'Rigardi en media-administrilo';
+$lang['img_manager']           = 'Rigardi en aŭdvidaĵ-administrilo';
 $lang['subscr_subscribe_success'] = 'Aldonis %s al la abonlisto por %s';
 $lang['subscr_subscribe_error'] = 'Eraro dum aldono de %s al la abonlisto por %s';
 $lang['subscr_subscribe_noaddress'] = 'Ne estas adreso ligita al via ensaluto, ne eblas aldoni vin al la abonlisto';
@@ -256,8 +270,8 @@ $lang['subscr_m_receive']      = 'Ricevi';
 $lang['subscr_style_every']    = 'retpoŝtaĵo pro ĉiu ŝanĝo';
 $lang['subscr_style_digest']   = 'resuma retpoŝtaĵo de ŝanĝoj por ĉiu paĝo (je %.2f tagoj)';
 $lang['subscr_style_list']     = 'listo de ŝanĝitaj paĝoj ekde la lasta retpoŝtaĵo (je %.2f tagoj)';
-$lang['authmodfailed']         = 'Malbona agordo por identigi la uzanton. Bonvolu informi la administranton de la vikio.';
 $lang['authtempfail']          = 'La identigo de via uzantonomo estas intertempe maldisponebla. Se tiu ĉi situacio daŭros, bonvolu informi la adminstranton de la vikio.';
+$lang['authpwdexpire']         = 'Via pasvorto malvalidos post %d tagoj, prefere ŝanĝu ĝin baldaũ.';
 $lang['i_chooselang']          = 'Elektu vian lingvon';
 $lang['i_installer']           = 'Instalilo de DokuWiki';
 $lang['i_wikiname']            = 'Nomo de la vikio';
@@ -273,14 +287,17 @@ $lang['i_confexists']          = '<code>%s</code> jam ekzistas';
 $lang['i_writeerr']            = 'Ne eblas krei "<code>%s</code>". Vi bezonas kontroli la permesojn de la dosier(uj)oj kaj mem krej la dosieron.';
 $lang['i_badhash']             = 'dokuwiki.php ne estas rekonebla aŭ ĝi estas modifita (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - malvalida aŭ malplena valoro';
-$lang['i_success']             = 'La agordado estas sukcese kompletita. Vi povas forigi la dosieron nun. Pluiru al <a href="doku.php">via nova DokuWiki</a>.';
-$lang['i_failure']             = 'Kelkaj eraroj okazis dum la konservo de la agordaj dosieroj. Vi devas senpere korekti ilin antaŭ ol vi povos uzi <a href="doku.php">vian novan DokuWiki-on</a>.                       ';
+$lang['i_success']             = 'La agordado sukcese kompletiĝis. Vi povas forigi la dosieron nun. Pluiru al <a href="doku.php?id=wiki:welcome">via nova DokuWiki</a>.';
+$lang['i_failure']             = 'Kelkaj eraroj okazis dum la konservo de la agordaj dosieroj. Vi devas senpere korekti ilin antaŭ ol vi povos uzi <a href="doku.php?id=wiki:welcome">vian novan DokuWiki-on</a>.                       ';
 $lang['i_policy']              = 'Komenca ACL-a agordo';
 $lang['i_pol0']                = 'Malferma Vikio (legi, skribi, alŝuti povas ĉiuj)';
 $lang['i_pol1']                = 'Publika Vikio (legi povas ĉiuj, skribi kaj alŝuti povas registritaj uzantoj)';
 $lang['i_pol2']                = 'Ferma Vikio (legi, skribi, alŝuti nur povas registritaj uzantoj)';
 $lang['i_retry']               = 'Reprovi';
 $lang['i_license']             = 'Bonvolu elekti la permesilon, sub kiun vi volas meti vian enhavon:';
+$lang['i_license_none']        = 'Ne montri licencinformojn';
+$lang['i_pop_field']           = 'Bonvolu helpi nin plibonigi la DokuWiki-sperton:';
+$lang['i_pop_label']           = 'Sendi unufoje monate anonimajn datumojn pri la uzo al la DokuWiki-evoluigantoj';
 $lang['recent_global']         = 'Vi nun rigardas la ŝanĝojn ene de la nomspaco <b>%s</b>. Vi povas ankaŭ <a href="%s">vidi la freŝajn ŝanĝojn de la tuta vikio</a>.';
 $lang['years']                 = 'antaŭ %d jaroj';
 $lang['months']                = 'antaŭ %d monatoj';
@@ -289,7 +306,7 @@ $lang['days']                  = 'antaŭ %d tagoj';
 $lang['hours']                 = 'antaŭ %d horoj';
 $lang['minutes']               = 'antaŭ %d minutoj';
 $lang['seconds']               = 'antaŭ %d sekundoj';
-$lang['wordblock']             = 'Via ŝanĝo ne estis savita, ĉar ĝi enhavas blokitan tekston (spamon).';
+$lang['wordblock']             = 'Via ŝanĝo ne konserviĝis, ĉar ĝi enhavas blokitan tekston (spamon).';
 $lang['media_uploadtab']       = 'Alŝuto';
 $lang['media_searchtab']       = 'Serĉo';
 $lang['media_file']            = 'Dosiero';
@@ -313,4 +330,7 @@ $lang['media_perm_read']       = 'Bedaûrinde viaj rajtoj ne sufiĉas por legi d
 $lang['media_perm_upload']     = 'Bedaûrinde viaj rajtoj ne sufiĉas por alŝuti dosierojn.';
 $lang['media_update']          = 'Alŝuti novan version';
 $lang['media_restore']         = 'Restarigi ĉi tiun version';
-$lang['plugin_install_err']    = 'Kromaĵo instalita malĝuste. Renomu la kromaĵan dosierujon \'%s\' al \'%s\'.';
+$lang['currentns']             = 'Aktuala nomspaco';
+$lang['searchresult']          = 'Serĉrezulto';
+$lang['plainhtml']             = 'Plena HTML';
+$lang['wikimarkup']            = 'Vikiteksto';
