@@ -1,8 +1,8 @@
 <?php
+
 /**
- * Hungarian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Ziegler Gábor <gziegler@freemail.hu>
  * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
  * @author Siaynoq Mage <siaynoqmage@gmail.com>
@@ -10,6 +10,8 @@
  * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
  * @author Sándor TIHANYI <stihanyi+dw@gmail.com>
  * @author David Szabo <szabo.david@gyumolcstarhely.hu>
+ * @author Marton Sebok <sebokmarton@gmail.com>
+ * @author Serenity87HUN <anikototh87@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -42,15 +44,18 @@ $lang['btn_delete']            = 'Törlés';
 $lang['btn_back']              = 'Vissza';
 $lang['btn_backlink']          = 'Hivatkozások';
 $lang['btn_backtomedia']       = 'Vissza a médiafájlok kezeléséhez';
-$lang['btn_subscribe']         = 'Oldalváltozások-hírlevél feliratkozás';
+$lang['btn_subscribe']         = 'Feliratkozás az oldalváltozásokra';
 $lang['btn_profile']           = 'Személyes beállítások';
 $lang['btn_reset']             = 'Alaphelyzet';
-$lang['btn_resendpwd']         = 'Új jelszó küldése';
+$lang['btn_resendpwd']         = 'Jelszóváltoztatás';
 $lang['btn_draft']             = 'Piszkozat szerkesztése';
 $lang['btn_recover']           = 'Piszkozat folytatása';
 $lang['btn_draftdel']          = 'Piszkozat törlése';
 $lang['btn_revert']            = 'Helyreállítás';
 $lang['btn_register']          = 'Regisztráció';
+$lang['btn_apply']             = 'Alkalmaz';
+$lang['btn_media']             = 'Médiakezelő';
+$lang['btn_deleteuser']        = 'Felhasználói fiókom eltávolítása';
 $lang['loggedinas']            = 'Belépett felhasználó: ';
 $lang['user']                  = 'Azonosító';
 $lang['pass']                  = 'Jelszó';
@@ -61,16 +66,17 @@ $lang['remember']              = 'Emlékezz rám';
 $lang['fullname']              = 'Teljes név';
 $lang['email']                 = 'E-Mail';
 $lang['profile']               = 'Személyes beállítások';
-$lang['badlogin']              = 'Sajnáljuk, az azonosító, vagy a jelszó nem jó.';
+$lang['badlogin']              = 'Sajnáljuk, az azonosító vagy a jelszó nem jó.';
+$lang['badpassconfirm']        = 'Hibás jelszó';
 $lang['minoredit']             = 'Apróbb változások';
 $lang['draftdate']             = 'Piszkozat elmentve:';
-$lang['nosecedit']             = 'Időközben megváltozott az oldal, emiatt a szakasz nem friss. Töltse újra az egész oldalt!';
+$lang['nosecedit']             = 'Időközben megváltozott az oldal, emiatt a szakasz nem friss. Töltsd újra az egész oldalt!';
 $lang['regmissing']            = 'Sajnáljuk, az összes mezőt ki kell töltened.';
 $lang['reguexists']            = 'Sajnáljuk, ilyen azonosítójú felhasználónk már van.';
 $lang['regsuccess']            = 'A felhasználói azonosítót létrehoztuk. A jelszót postáztuk.';
 $lang['regsuccess2']           = 'A felhasználói azonosítót létrehoztuk.';
-$lang['regmailfail']           = 'Úgy tűnik hiba történt a jelszó postázása során. Kérjük lépj kapcsolatba a Wiki-gazdával!!';
-$lang['regbadmail']            = 'A megadott e-mail cím érvénytelennek tűnik. Ha úgy gondolod ez hiba, lépj kapcsolatba Wiki-gazdával!';
+$lang['regmailfail']           = 'Úgy tűnik hiba történt a jelszó postázása során. Kérjük lépj kapcsolatba az Adminisztrátorokkal!';
+$lang['regbadmail']            = 'A megadott e-mail cím érvénytelennek tűnik. Ha úgy gondolod ez hiba, lépj kapcsolatba az Adminisztrátorokkal!';
 $lang['regbadpass']            = 'A két megadott jelszó nem egyezik, próbáld újra!';
 $lang['regpwmail']             = 'A DokuWiki jelszavad';
 $lang['reghere']               = 'Még nincs azonosítód? Itt kérhetsz';
@@ -78,24 +84,30 @@ $lang['profna']                = 'Ez a wiki nem támogatja a személyes beállí
 $lang['profnochange']          = 'Nem történt változás.';
 $lang['profnoempty']           = 'A név és e-mail mező nem maradhat üresen!';
 $lang['profchanged']           = 'A személyes beállítások változtatása megtörtént.';
+$lang['profnodelete']          = 'Ez a wiki nem támogatja a felhasználói fiókok törlését';
+$lang['profdeleteuser']        = 'Felhasználói fiók törlése';
+$lang['profdeleted']           = 'Felhasználói fiókodat eltávolítottuk erről a wiki-ről.';
+$lang['profconfdelete']        = 'Szeretném eltávolítani a felhasználói fiókomat erről a wikiről. <br/> Ez a cselekvés nem visszavonható.';
+$lang['profconfdeletemissing'] = 'A megerősítő négyzet nincs bepipálva';
 $lang['pwdforget']             = 'Elfelejtetted a jelszavad? Itt kérhetsz újat';
 $lang['resendna']              = 'Ez a wiki nem támogatja a jelszó újraküldést.';
-$lang['resendpwd']             = 'Új jelszó kiküldése ennek a felhasználónak';
+$lang['resendpwd']             = 'Új jelszó beállítása a következőhöz:';
 $lang['resendpwdmissing']      = 'Sajnáljuk, az összes mezőt ki kell töltened.';
 $lang['resendpwdnouser']       = 'Sajnáljuk, ilyen azonosítójú felhasználónk nem létezik.';
-$lang['resendpwdbadauth']      = 'Sajnáljuk, ez a megerősítő kód nem helyes. Biztos, hogy a teljes megerősítés linket beírtad pontosan?';
-$lang['resendpwdconfirm']      = 'A megerősítés linket e-mailben elküldtük.';
+$lang['resendpwdbadauth']      = 'Sajnáljuk, ez a megerősítő kód nem helyes. Biztos, hogy a teljes megerősítő linket pontosan beírtad?';
+$lang['resendpwdconfirm']      = 'A megerősítő linket e-mailben elküldtük.';
 $lang['resendpwdsuccess']      = 'Az új jelszavadat elküldtük e-mailben.';
 $lang['license']               = 'Hacsak máshol nincs egyéb rendelkezés, ezen wiki tartalma a következő licenc alatt érhető el:';
 $lang['licenseok']             = 'Megjegyzés: az oldal szerkesztésével elfogadja, hogy a tartalom a következő licenc alatt lesz elérhető:';
 $lang['searchmedia']           = 'Keresett fájl neve:';
 $lang['searchmedia_in']        = 'Keresés a következőben: %s';
 $lang['txt_upload']            = 'Válaszd ki a feltöltendő fájlt';
-$lang['txt_filename']          = 'feltöltési név (elhagyható)';
+$lang['txt_filename']          = 'Feltöltési név (elhagyható)';
 $lang['txt_overwrt']           = 'Létező fájl felülírása';
+$lang['maxuploadsize']         = 'Maximum %s méretű fájlokat tölthetsz fel.';
 $lang['lockedby']              = 'Jelenleg zárolta:';
 $lang['lockexpire']            = 'A zárolás lejár:';
-$lang['js']['willexpire']            = 'Az oldalszerkesztési zárolásod körülbelül egy percen belül lejár.\nAz ütközések elkerülése végett használd az előnézet gombot a zárolási időzítés frissítéséhez.';
+$lang['js']['willexpire']      = 'Az oldalszerkesztési zárolásod körülbelül egy percen belül lejár.\nAz ütközések elkerülése végett használd az előnézet gombot a zárolásod frissítéséhez.';
 $lang['js']['notsavedyet']     = 'Elmentetlen változások vannak, amelyek el fognak veszni.
 Tényleg ezt akarod?';
 $lang['js']['searchmedia']     = 'Fájlok keresése';
@@ -105,50 +117,60 @@ $lang['js']['mediatitle']      = 'Link beállítások';
 $lang['js']['mediadisplay']    = 'Link típusa';
 $lang['js']['mediaalign']      = 'Igazítás';
 $lang['js']['mediasize']       = 'Képméret';
-$lang['js']['mediatarget']     = 'Link';
+$lang['js']['mediatarget']     = 'Link célja';
 $lang['js']['mediaclose']      = 'Bezárás';
 $lang['js']['mediainsert']     = 'Beillesztés';
 $lang['js']['mediadisplayimg'] = 'Kép megtekintése.';
 $lang['js']['mediadisplaylnk'] = 'Link megtekintése.';
-$lang['js']['mediasmall']      = 'Kisebb méret';
+$lang['js']['mediasmall']      = 'Kis méret';
 $lang['js']['mediamedium']     = 'Közepes méret';
-$lang['js']['medialarge']      = 'Nagyobb méret';
-$lang['js']['mediaoriginal']   = 'Eredeti';
+$lang['js']['medialarge']      = 'Nagy méret';
+$lang['js']['mediaoriginal']   = 'Eredeti verzió';
 $lang['js']['medialnk']        = 'Link a részletekre';
 $lang['js']['mediadirect']     = 'Közvetlen link az eredetire';
-$lang['js']['medianolnk']      = 'Nincsen link';
+$lang['js']['medianolnk']      = 'Nincs link';
 $lang['js']['medianolink']     = 'Ne linkelje a képet';
 $lang['js']['medialeft']       = 'Kép igazítása balra.';
 $lang['js']['mediaright']      = 'Kép igazítása jobbra.';
 $lang['js']['mediacenter']     = 'Kép igazítása középre.';
 $lang['js']['medianoalign']    = 'Nem legyen igazítás.';
-$lang['js']['nosmblinks']      = 'A Windows megosztott könyvtárak kereszthivatkozása csak  Microsoft Internet Explorerben működik közvetlenül.
-A hivatkozást másolni és beszúrni ettől fügetlenül mndig tudod.';
+$lang['js']['nosmblinks']      = 'A Windows megosztott könyvtárak kereszthivatkozása csak Microsoft Internet Explorerben működik közvetlenül.\nA hivatkozást másolni és beszúrni ettől függetlenül mindig tudod.';
 $lang['js']['linkwiz']         = 'Hivatkozás varázsló';
 $lang['js']['linkto']          = 'Hivatkozás erre:';
 $lang['js']['del_confirm']     = 'Valóban törölni akarod a kiválasztott elem(ek)et?';
-$lang['rssfailed']             = 'Hiba történt ennek a betöltésekor: ';
-$lang['nothingfound']          = 'Semmit sem találtam.';
+$lang['js']['restore_confirm'] = 'Valóban visszaállítod ezt a verziót?';
+$lang['js']['media_diff']      = 'Különbségek megtekintése:';
+$lang['js']['media_diff_both'] = 'Egymás mellett';
+$lang['js']['media_diff_opacity'] = 'Áttetszően';
+$lang['js']['media_diff_portions'] = 'Húzással';
+$lang['js']['media_select']    = 'Fájlok kiválasztása...';
+$lang['js']['media_upload_btn'] = 'Feltöltés';
+$lang['js']['media_done_btn']  = 'Kész';
+$lang['js']['media_drop']      = 'Húzd ide a fájlokat a feltöltéshez';
+$lang['js']['media_cancel']    = 'eltávolítás';
+$lang['js']['media_overwrt']   = 'Meglévő fájlok felülírása';
+$lang['rssfailed']             = 'Hiba történt a hírfolyam betöltésekor: ';
+$lang['nothingfound']          = 'Üres mappa.';
 $lang['mediaselect']           = 'Médiafájl kiválasztása';
 $lang['fileupload']            = 'Médiafájl feltöltése';
-$lang['uploadsucc']            = 'A feltöltés sikerült';
+$lang['uploadsucc']            = 'Sikeres feltöltés';
 $lang['uploadfail']            = 'A feltöltés nem sikerült. Talán rosszak a jogosultságok?';
-$lang['uploadwrong']           = 'A feltöltés megtagadva. Ez a fájl kiterjesztés tiltott.';
+$lang['uploadwrong']           = 'A feltöltés megtagadva. Ez a fájlkiterjesztés tiltott.';
 $lang['uploadexist']           = 'A fájl már létezik, nem történt semmi.';
-$lang['uploadbadcontent']      = 'A feltöltött tartalom nem egyezik a %s fájl kiterjesztéssel.';
+$lang['uploadbadcontent']      = 'A feltöltött tartalom nem egyezik a %s fájlkiterjesztéssel.';
 $lang['uploadspam']            = 'A feltöltést visszautasítottuk spam-gyanú miatt.';
 $lang['uploadxss']             = 'A feltöltést visszautasítottuk, mert lehetséges, hogy kártékony kódot tartalmaz.';
 $lang['uploadsize']            = 'A feltöltött fájl túl nagy. (max. %s)';
 $lang['deletesucc']            = 'A "%s" fájlt töröltük.';
-$lang['deletefail']            = 'A "%s" fájl nem törölhető. - Ellenőrizd a jogosultságokat!';
-$lang['mediainuse']            = 'A "%s" fájl nem törlődött - még használat alatt van.';
-$lang['namespaces']            = 'Névtér';
+$lang['deletefail']            = 'A "%s" fájl nem törölhető - ellenőrizd a jogosultságokat!';
+$lang['mediainuse']            = 'A "%s" fájl nem törlődött - még használat alatt van!';
+$lang['namespaces']            = 'Névterek';
 $lang['mediafiles']            = 'Elérhető fájlok itt:';
-$lang['accessdenied']          = 'Nincsen jogod az oldal megtekintésére.';
-$lang['mediausage']            = 'A következő formában hivatkozhatsz erre az állományra:';
-$lang['mediaview']             = 'Eredeti állomány megtekintése';
+$lang['accessdenied']          = 'Nincs jogod az oldal megtekintésére.';
+$lang['mediausage']            = 'A következő formában hivatkozhatsz erre a fájlra:';
+$lang['mediaview']             = 'Eredeti fájl megtekintése';
 $lang['mediaroot']             = 'kiindulási hely';
-$lang['mediaupload']           = 'Itt tölthetsz fel állományt az aktuális névtérbe. Al-névtér létrehozásához a "Feltöltési név" mezőben kell kettősponttal elválasztva megadnod azt.';
+$lang['mediaupload']           = 'Itt tölthetsz fel állományt az aktuális névtérbe. Alnévtér létrehozásához a "Feltöltési név" mezőben kell kettősponttal elválasztva megadnod azt.';
 $lang['mediaextchange']        = 'Az állomány kiterjesztése erről: .%s erre: .%s változott!';
 $lang['reference']             = 'Hivatkozások';
 $lang['ref_inuse']             = 'A fájl nem törölhető, mert a következő oldalakon használják:';
@@ -157,34 +179,44 @@ $lang['hits']                  = 'Találatok';
 $lang['quickhits']             = 'Illeszkedő oldalnevek';
 $lang['toc']                   = 'Tartalomjegyzék';
 $lang['current']               = 'aktuális';
-$lang['yours']                 = 'A te változatod';
-$lang['diff']                  = 'a különbségeket mutatja az aktuális változathoz képest';
-$lang['diff2']                 = 'a különbségeket mutatja a kiválasztott változatok között';
+$lang['yours']                 = 'A Te változatod';
+$lang['diff']                  = 'Különbségek az aktuális változathoz képest';
+$lang['diff2']                 = 'Különbségek a kiválasztott változatok között';
 $lang['difflink']              = 'Összehasonlító nézet linkje';
 $lang['diff_type']             = 'Összehasonlítás módja:';
 $lang['diff_inline']           = 'Sorok között';
-$lang['diff_side']             = 'Kétoldalas';
-$lang['line']                  = 'sorszám';
+$lang['diff_side']             = 'Egymás mellett';
+$lang['line']                  = 'Sor';
 $lang['breadcrumb']            = 'Nyomvonal';
 $lang['youarehere']            = 'Itt vagy';
 $lang['lastmod']               = 'Utolsó módosítás';
 $lang['by']                    = 'szerkesztette:';
 $lang['deleted']               = 'eltávolítva';
 $lang['created']               = 'létrehozva';
-$lang['restored']              = 'az előző változat helyreállítva';
+$lang['restored']              = 'régebbi változat helyreállítva (%s)';
 $lang['external_edit']         = 'külső szerkesztés';
 $lang['summary']               = 'A változások összefoglalása';
 $lang['noflash']               = 'Ennek a tartalomnak a megtekintéséhez <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> szükséges.';
 $lang['download']              = 'Kódrészlet letöltése';
+$lang['tools']                 = 'Eszközök';
+$lang['user_tools']            = 'Felhasználói eszközök';
+$lang['site_tools']            = 'Eszközök a webhelyen';
+$lang['page_tools']            = 'Eszközök az oldalon';
+$lang['skip_to_content']       = 'ugrás a tartalomhoz';
+$lang['sidebar']               = 'Oldalsáv';
 $lang['mail_newpage']          = 'új oldal jött létre:';
 $lang['mail_changed']          = 'oldal megváltozott:';
 $lang['mail_subscribe_list']   = 'oldalak megváltoztak ebben a névtérben:';
-$lang['mail_new_user']         = 'Új felhasználó:';
-$lang['mail_upload']           = 'állományt töltöttek fel:';
+$lang['mail_new_user']         = 'új felhasználó:';
+$lang['mail_upload']           = 'új állományt töltöttek fel:';
+$lang['changes_type']          = 'A következő változásainak megtekintése:';
+$lang['pages_changes']         = 'Oldalak';
+$lang['media_changes']         = 'Médiafájlok';
+$lang['both_changes']          = 'Oldalak és médiafájlok';
 $lang['qb_bold']               = 'Félkövér szöveg';
 $lang['qb_italic']             = 'Dőlt szöveg';
 $lang['qb_underl']             = 'Aláhúzott szöveg';
-$lang['qb_code']               = 'Forráskód szöveg';
+$lang['qb_code']               = 'Forráskód';
 $lang['qb_strike']             = 'Áthúzott szöveg';
 $lang['qb_h1']                 = '1. szintű címsor';
 $lang['qb_h2']                 = '2. szintű címsor';
@@ -200,16 +232,16 @@ $lang['qb_link']               = 'Belső hivatkozás';
 $lang['qb_extlink']            = 'Külső hivatkozás';
 $lang['qb_hr']                 = 'Vízszintes elválasztó vonal';
 $lang['qb_ol']                 = 'Sorszámozott lista elem';
-$lang['qb_ul']                 = 'Felsorolás lista elem';
+$lang['qb_ul']                 = 'Felsorolásos lista elem';
 $lang['qb_media']              = 'Képek és más fájlok hozzáadása';
 $lang['qb_sig']                = 'Aláírás beszúrása';
-$lang['qb_smileys']            = 'Szmájlik';
+$lang['qb_smileys']            = 'Smiley-k';
 $lang['qb_chars']              = 'Speciális karakterek';
-$lang['upperns']               = 'Ugrás a szülő névtérhez';
+$lang['upperns']               = 'ugrás a tartalmazó névtérhez';
 $lang['admin_register']        = 'Új felhasználó';
-$lang['metaedit']              = 'Meta-adatok szerkesztése';
-$lang['metasaveerr']           = 'A meta-adatok írása meghiúsult ';
-$lang['metasaveok']            = 'Meta-adatok elmentve';
+$lang['metaedit']              = 'Metaadatok szerkesztése';
+$lang['metasaveerr']           = 'A metaadatok írása nem sikerült';
+$lang['metasaveok']            = 'Metaadatok elmentve';
 $lang['img_backto']            = 'Vissza';
 $lang['img_title']             = 'Cím';
 $lang['img_caption']           = 'Képaláírás';
@@ -217,17 +249,20 @@ $lang['img_date']              = 'Dátum';
 $lang['img_fname']             = 'Fájlnév';
 $lang['img_fsize']             = 'Méret';
 $lang['img_artist']            = 'Készítette';
-$lang['img_copyr']             = 'Copyright';
+$lang['img_copyr']             = 'Szerzői jogok';
 $lang['img_format']            = 'Formátum';
-$lang['img_camera']            = 'Fényképező típusa';
+$lang['img_camera']            = 'Fényképezőgép típusa';
 $lang['img_keywords']          = 'Kulcsszavak';
+$lang['img_width']             = 'Szélesség';
+$lang['img_height']            = 'Magasság';
+$lang['img_manager']           = 'Megtekintés a médiakezelőben';
 $lang['subscr_subscribe_success'] = '%s hozzáadva az értesítési listához: %s';
 $lang['subscr_subscribe_error'] = 'Hiba történt %s hozzáadásakor az értesítési listához: %s';
-$lang['subscr_subscribe_noaddress'] = 'Nincsen e-mail cím megadva az adataidnál, így a rendszer nem tudott hozzáadni az értesítési listához';
+$lang['subscr_subscribe_noaddress'] = 'Nincs e-mail cím megadva az adataidnál, így a rendszer nem tudott hozzáadni az értesítési listához';
 $lang['subscr_unsubscribe_success'] = '%s eltávolítva az értesítési listából: %s';
 $lang['subscr_unsubscribe_error'] = 'Hiba történt %s eltávolításakor az értesítési listából: %s';
 $lang['subscr_already_subscribed'] = '%s már feliratkozott erre: %s';
-$lang['subscr_not_subscribed'] = '%s nincsen feliratkozva erre: %s';
+$lang['subscr_not_subscribed'] = '%s nincs feliratkozva erre: %s';
 $lang['subscr_m_not_subscribed'] = 'Jelenleg nem vagy feliratkozva erre az oldalra vagy névtérre';
 $lang['subscr_m_new_header']   = 'Feliratkozás hozzáadása';
 $lang['subscr_m_current_header'] = 'Feliratkozások';
@@ -237,13 +272,13 @@ $lang['subscr_m_receive']      = 'Küldj';
 $lang['subscr_style_every']    = 'e-mailt minden változásról';
 $lang['subscr_style_digest']   = 'összefoglaló e-mailt oldalanként (minden %.2f nap)';
 $lang['subscr_style_list']     = 'egy listát a módosított oldalakról a legutóbbi e-mail óta (minden %.2f nap)';
-$lang['authmodfailed']         = 'Hibás felhasználó-aznosítási módszer van beállítva. Légy szíves értesítsd a Wiki-gazdát!';
-$lang['authtempfail']          = 'A felhasználó azonosítás átmenetileg nem működik. Ha sokáig így lenne, légy szíves értesítsd a Wiki-gazdát!';
+$lang['authtempfail']          = 'A felhasználó azonosítás átmenetileg nem működik. Ha sokáig így lenne, légy szíves értesítsd az Adminisztrátorokat!';
+$lang['authpwdexpire']         = 'A jelszavad %d nap múlva lejár, hamarosan meg kell változtatnod.';
 $lang['i_chooselang']          = 'Válassz nyelvet';
 $lang['i_installer']           = 'DokuWiki Beállító Varázsló';
 $lang['i_wikiname']            = 'A Wiki neve';
 $lang['i_enableacl']           = 'Hozzáférési listák engedélyezése (ajánlott)';
-$lang['i_superuser']           = 'Wiki-gazda';
+$lang['i_superuser']           = 'Adminisztrátor';
 $lang['i_problems']            = 'A Beállító Varázsló a következő problémák miatt megakadt. Nem tudjuk folytatni, amíg ezek nincsenek elhárítva!';
 $lang['i_modified']            = 'Biztonsági okokból ez a Varázsló csak új és módosítatlan DokuWiki változaton működik.
 Csomagold ki újra a fájlokat a letöltött csomagból, vagy nézd meg a teljes <a href="http://dokuwiki.org/install">Dokuwiki telepítési útmutatót</a>.';
@@ -254,14 +289,17 @@ $lang['i_confexists']          = '<code>%s</code> már létezik.';
 $lang['i_writeerr']            = 'Nem tudom ezt létrehozni: <code>%s</code>. Ellenőrizd a könyvtár/fájl jogosultságokat, és hozd létre az állományt kézzel.';
 $lang['i_badhash']             = 'A dokuwiki.php nem felismerhető vagy módosított (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - nem helyes vagy üres érték';
-$lang['i_success']             = 'A beállítás sikeresen befejeződött. Most már letörölhető az install.php fájl. Látogasd meg az <a href="doku.php">új DokuWikidet</a>!';
-$lang['i_failure']             = 'Hiba lépett fel a konfigurációs állományok írásakor. Ki kell javítanod kézzel, mielőtt használni kezded az <a href="doku.php">új DokuWikidet</a>.';
-$lang['i_policy']              = 'Kezdeti hozzáférési politika';
-$lang['i_pol0']                = 'Nyitott Wiki (mindenki olvashatja, írhatja, és fájlokat tölthet fel)';
-$lang['i_pol1']                = 'Publikus Wiki (mindenki olvashatja, de csak regisztrált felhasználók írhatják, és tölthetnek fel fájlokat)';
-$lang['i_pol2']                = 'Zárt Wiki (csak regisztrált felhasználók olvashatják, írhatják és tölthetnek fel fájlokat)';
+$lang['i_success']             = 'A beállítás sikeresen befejeződött. Most már letörölhető az install.php fájl. Látogasd meg az <a href="doku.php?id=wiki:welcome">új DokuWikidet</a>!';
+$lang['i_failure']             = 'Hiba lépett fel a konfigurációs állományok írásakor. Ki kell javítanod kézzel, mielőtt használni kezded az <a href="doku.php?id=wiki:welcome">új DokuWikidet</a>.';
+$lang['i_policy']              = 'Kezdeti hozzáférési lista házirend';
+$lang['i_pol0']                = 'Nyitott wiki (mindenki olvashatja, írhatja és fájlokat tölthet fel)';
+$lang['i_pol1']                = 'Publikus wiki (mindenki olvashatja, de csak regisztrált felhasználók írhatják és tölthetnek fel fájlokat)';
+$lang['i_pol2']                = 'Zárt wiki (csak regisztrált felhasználók olvashatják, írhatják és tölthetnek fel fájlokat)';
 $lang['i_retry']               = 'Újra';
-$lang['i_license']             = 'Kérlek válassz licenszt a feltöltött tartalomhoz:';
+$lang['i_license']             = 'Kérlek, válassz licencet a feltöltött tartalomhoz:';
+$lang['i_license_none']        = 'Ne jelenítsen meg licenc információt';
+$lang['i_pop_field']           = 'Kérjük, segíts a DokuWiki továbbfejlesztésében:';
+$lang['i_pop_label']           = 'Havonta egyszer névtelen üzenet küldése a DokuWiki fejlesztőinek';
 $lang['recent_global']         = 'Jelenleg csak a <b>%s</b> névtér friss változásai látszanak. Megtekinthetők <a href="%s">a teljes wiki friss változásai</a> is.';
 $lang['years']                 = '%d évvel ezelőtt';
 $lang['months']                = '%d hónappal ezelőtt';
@@ -270,4 +308,27 @@ $lang['days']                  = '%d nappal ezelőtt';
 $lang['hours']                 = '%d órával ezelőtt';
 $lang['minutes']               = '%d perccel ezelőtt';
 $lang['seconds']               = '%d másodperccel ezelőtt';
-$lang['wordblock']             = 'A változásokat nem sikerült menteni, mert tiltott tartalom van benne (spam)';
+$lang['wordblock']             = 'A változásokat nem sikerült menteni, mert tiltott tartalom van benne (spam).';
+$lang['media_uploadtab']       = 'Feltöltés';
+$lang['media_searchtab']       = 'Keresés';
+$lang['media_file']            = 'Fájl';
+$lang['media_viewtab']         = 'Megtekintés';
+$lang['media_edittab']         = 'Szerkesztés';
+$lang['media_historytab']      = 'Korábbi változatok';
+$lang['media_list_thumbs']     = 'Bélyegképek';
+$lang['media_list_rows']       = 'Sorok';
+$lang['media_sort_name']       = 'Név';
+$lang['media_sort_date']       = 'Dátum';
+$lang['media_namespaces']      = 'Névtér kiválasztása';
+$lang['media_files']           = 'Fájlok itt: %s';
+$lang['media_upload']          = 'Feltöltés ide: %s';
+$lang['media_search']          = 'Keresés itt: %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s itt: %s';
+$lang['media_edit']            = '%s szerkesztése';
+$lang['media_history']         = '%s korábbi változatai';
+$lang['media_meta_edited']     = 'metaadatot szerkesztve';
+$lang['media_perm_read']       = 'Sajnáljuk, nincs jogod a fájlok olvasásához.';
+$lang['media_perm_upload']     = 'Sajnáljuk, nincs jogod a feltöltéshez.';
+$lang['media_update']          = 'Új verzió feltöltése';
+$lang['media_restore']         = 'Ezen verzió visszaállítása';
