@@ -45,7 +45,6 @@ $lang['btn_backtomedia']       = 'Retornar al selection de files multimedia';
 $lang['btn_subscribe']         = 'Gerer subscriptiones';
 $lang['btn_profile']           = 'Actualisar profilo';
 $lang['btn_reset']             = 'Reinitialisar';
-$lang['btn_resendpwd']         = 'Inviar nove contrasigno';
 $lang['btn_draft']             = 'Modificar version provisori';
 $lang['btn_recover']           = 'Recuperar version provisori';
 $lang['btn_draftdel']          = 'Deler version provisori';
@@ -80,7 +79,6 @@ $lang['profnoempty']           = 'Un nomine o adresse de e-mail vacue non es per
 $lang['profchanged']           = 'Actualisation del profilo de usator succedite.';
 $lang['pwdforget']             = 'Contrasigno oblidate? Obtene un altere';
 $lang['resendna']              = 'Iste wiki non supporta le invio de un nove contrasigno.';
-$lang['resendpwd']             = 'Inviar nove contrasigno pro';
 $lang['resendpwdmissing']      = 'Es necessari completar tote le campos.';
 $lang['resendpwdnouser']       = 'Iste usator non ha essite trovate in le base de datos.';
 $lang['resendpwdbadauth']      = 'Iste codice de authentication non es valide. Assecura te que tu ha usate le ligamine de confirmation complete.';
@@ -95,8 +93,8 @@ $lang['txt_filename']          = 'Incargar como (optional)';
 $lang['txt_overwrt']           = 'Reimplaciar le file existente';
 $lang['lockedby']              = 'Actualmente serrate per';
 $lang['lockexpire']            = 'Serratura expira le';
-$lang['willexpire']            = 'Tu serratura super le modification de iste pagina expirara post un minuta.\nPro evitar conflictos, usa le button Previsualisar pro reinitialisar le timer del serratura.';
-$lang['js']['notsavedyet']     = "Le modificationes non salveguardate essera perdite.\nRealmente continuar?";
+$lang['js']['willexpire']            = 'Tu serratura super le modification de iste pagina expirara post un minuta.\nPro evitar conflictos, usa le button Previsualisar pro reinitialisar le timer del serratura.';
+$lang['js']['notsavedyet']     = 'Le modificationes non salveguardate essera perdite.\nRealmente continuar?';
 $lang['rssfailed']             = 'Un error occurreva durante le obtention de iste syndication:';
 $lang['nothingfound']          = 'Nihil ha essite trovate.';
 $lang['mediaselect']           = 'Files multimedia';
@@ -143,7 +141,6 @@ Tu pote nonobstante copiar e collar le ligamine.';
 $lang['js']['linkwiz']         = 'Assistente pro ligamines';
 $lang['js']['linkto']          = 'Ligar verso:';
 $lang['js']['del_confirm']     = 'Realmente deler le entrata(s) seligite?';
-$lang['js']['mu_btn']          = 'Incargar plure files simultaneemente';
 $lang['mediausage']            = 'Usa le syntaxe sequente pro referer a iste file:';
 $lang['mediaview']             = 'Vider file original';
 $lang['mediaroot']             = 'radice';
@@ -166,7 +163,7 @@ $lang['lastmod']               = 'Ultime modification';
 $lang['by']                    = 'per';
 $lang['deleted']               = 'removite';
 $lang['created']               = 'create';
-$lang['restored']              = 'ancian version restaurate';
+$lang['restored']              = 'ancian version restaurate (%s)';
 $lang['external_edit']         = 'modification externe';
 $lang['summary']               = 'Modificar summario';
 $lang['noflash']               = 'Le <a href="http://www.adobe.com/products/flashplayer/">plug-in Flash de Adobe</a> es necessari pro monstrar iste contento.';
@@ -230,9 +227,6 @@ $lang['subscr_m_unsubscribe']  = 'Cancellar subscription';
 $lang['subscr_m_subscribe']    = 'Subscriber';
 $lang['subscr_m_receive']      = 'Reciper';
 $lang['subscr_style_every']    = 'un message pro cata modification';
-$lang['subscr_style_digest']   = 'un digesto de modificationes pro cata pagina';
-$lang['subscr_style_list']     = 'lista de paginas modificate depost le ultime e-mail';
-$lang['authmodfailed']         = 'Configuration incorrecte de authentication de usator. Per favor informa le administrator de tu wiki.';
 $lang['authtempfail']          = 'Le authentication de usator temporarimente non es disponibile. Si iste situation persiste, per favor informa le administrator de tu wiki.';
 $lang['i_chooselang']          = 'Selige tu lingua';
 $lang['i_installer']           = 'Installator de DokuWiki';
@@ -250,29 +244,14 @@ $lang['i_writeerr']            = 'Impossibile crear <code>%s</code>. Tu debe ver
 $lang['i_badhash']             = 'dokuwiki.php non recognoscite o modificate (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valor vacue o invalide';
 $lang['i_success']             = 'Le configuration ha succedite. Tu pote ora deler le file install.php. Continua a
-<a href="doku.php">tu nove DokuWiki</a>.';
+<a href="doku.php?id=wiki:welcome">tu nove DokuWiki</a>.';
 $lang['i_failure']             = 'Alcun errores occurreva durante le scriptura del files de configuration. Es possibile que tu debe remediar iste errores manualmente ante que
-tu pote usar <a href="doku.php">tu nove DokuWiki</a>.';
+tu pote usar <a href="doku.php?id=wiki:welcome">tu nove DokuWiki</a>.';
 $lang['i_policy']              = 'Politica de ACL interne';
 $lang['i_pol0']                = 'Wiki aperte (lectura, scriptura, incargamento pro omnes)';
 $lang['i_pol1']                = 'Wiki public (lectura pro omnes, scriptura e incargamento pro usatores registrate)';
 $lang['i_pol2']                = 'Wiki claudite (lectura, scriptura e incargamento solmente pro usatores registrate)';
 $lang['i_retry']               = 'Reprobar';
-$lang['mu_intro']              = 'Hic tu pote incargar plure files insimul. Clicca super le button Navigar pro adder los al cauda. Preme Incargar quando tu ha finite.';
-$lang['mu_gridname']           = 'Nomine de file';
-$lang['mu_gridsize']           = 'Dimension';
-$lang['mu_gridstat']           = 'Stato';
-$lang['mu_namespace']          = 'Spatio de nomines';
-$lang['mu_browse']             = 'Navigar';
-$lang['mu_toobig']             = 'troppo grande';
-$lang['mu_ready']              = 'preste pro incargamento';
-$lang['mu_done']               = 'complete';
-$lang['mu_fail']               = 'fallite';
-$lang['mu_authfail']           = 'session expirate';
-$lang['mu_progress']           = '@PCT@% incargate';
-$lang['mu_filetypes']          = 'Typos de file permittite';
-$lang['mu_info']               = 'files incargate.';
-$lang['mu_lasterr']            = 'Ultime error:';
 $lang['recent_global']         = 'Tu observa actualmente le modificationes intra le spatio de nomines <b>%s</b>. Tu pote etiam <a href="%s">vider le modificationes recente de tote le wiki</a>.';
 $lang['years']                 = '%d annos retro';
 $lang['months']                = '%d menses retro';
