@@ -1,8 +1,8 @@
 <?php
+
 /**
- * Italian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Giorgio Vecchiocattivi <giorgio@vecchio.it>
  * @author Roberto Bolli [http://www.rbnet.it/]
  * @author Silvia Sargentoni <polinnia@tin.it>
@@ -13,6 +13,10 @@
  * @author Matteo Carnevali <rekstorm@gmail.com>
  * @author Osman Tekin <osman.tekin93@hotmail.it>
  * @author Jacopo Corbetta <jacopo.corbetta@gmail.com>
+ * @author Matteo Pasotti <matteo@xquiet.eu>
+ * @author snarchio@gmail.com
+ * @author Edmondo Di Tucci <snarchio@gmail.com>
+ * @author Claudio Lanconelli <lancos@libero.it>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -48,12 +52,15 @@ $lang['btn_backtomedia']       = 'Torna alla selezione file';
 $lang['btn_subscribe']         = 'Sottoscrivi modifiche';
 $lang['btn_profile']           = 'Aggiorna profilo';
 $lang['btn_reset']             = 'Annulla';
-$lang['btn_resendpwd']         = 'Invia nuova password';
+$lang['btn_resendpwd']         = 'Imposta nuova password';
 $lang['btn_draft']             = 'Modifica bozza';
 $lang['btn_recover']           = 'Ripristina bozza';
 $lang['btn_draftdel']          = 'Elimina bozza';
 $lang['btn_revert']            = 'Ripristina';
 $lang['btn_register']          = 'Registrazione';
+$lang['btn_apply']             = 'Applica';
+$lang['btn_media']             = 'Gestore Media';
+$lang['btn_deleteuser']        = 'Rimuovi il mio account';
 $lang['loggedinas']            = 'Collegato come';
 $lang['user']                  = 'Nome utente';
 $lang['pass']                  = 'Password';
@@ -65,6 +72,7 @@ $lang['fullname']              = 'Nome completo';
 $lang['email']                 = 'Email';
 $lang['profile']               = 'Profilo utente';
 $lang['badlogin']              = 'Il nome utente o la password non sono validi.';
+$lang['badpassconfirm']        = 'La password è errata';
 $lang['minoredit']             = 'Modifiche minori';
 $lang['draftdate']             = 'Bozza salvata in automatico il';
 $lang['nosecedit']             = 'La pagina è stata modificata nel frattempo; è impossibile modificare solo la sezione scelta, quindi è stata caricata la pagina intera.';
@@ -81,9 +89,14 @@ $lang['profna']                = 'Questo wiki non supporta modifiche al profilo'
 $lang['profnochange']          = 'Nessuna modifica, niente da aggiornare.';
 $lang['profnoempty']           = 'Nome o indirizzo email vuoti non sono consentiti.';
 $lang['profchanged']           = 'Aggiornamento del profilo utente riuscito.';
+$lang['profnodelete']          = 'Questa wiki non supporta la cancellazione degli utenti';
+$lang['profdeleteuser']        = 'Elimina account';
+$lang['profdeleted']           = 'Il tuo account utente è stato rimosso da questa wiki';
+$lang['profconfdelete']        = 'Voglio rimuovere il mio account da questa wiki. <br/> Questa operazione non può essere annullata.';
+$lang['profconfdeletemissing'] = 'La check box di conferma non è selezionata';
 $lang['pwdforget']             = 'Hai dimenticato la password? Richiedine una nuova';
 $lang['resendna']              = 'Questo wiki non supporta l\'invio di nuove password.';
-$lang['resendpwd']             = 'Invia nuova password per';
+$lang['resendpwd']             = 'Imposta nuova password per';
 $lang['resendpwdmissing']      = 'Devi riempire tutti i campi.';
 $lang['resendpwdnouser']       = 'Impossibile trovare questo utente nel database.';
 $lang['resendpwdbadauth']      = 'Spiacenti, questo codice di autorizzazione non è valido. Assicurati di aver usato il link completo di conferma.';
@@ -92,13 +105,14 @@ $lang['resendpwdsuccess']      = 'La nuova password è stata spedita via email.'
 $lang['license']               = 'Ad eccezione da dove è diversamente indicato, il contenuto di questo wiki è soggetto alla seguente licenza:';
 $lang['licenseok']             = 'Nota: modificando questa pagina accetti di rilasciare il contenuto sotto la seguente licenza:';
 $lang['searchmedia']           = 'Cerca file di nome:';
-$lang['searchmedia_in']        = 'Cerca in &s';
+$lang['searchmedia_in']        = 'Cerca in %s';
 $lang['txt_upload']            = 'Seleziona un file da caricare';
 $lang['txt_filename']          = 'Carica come (opzionale)';
 $lang['txt_overwrt']           = 'Sovrascrivi file esistente';
+$lang['maxuploadsize']         = 'Upload max. %s per ogni file.';
 $lang['lockedby']              = 'Attualmente bloccato da';
 $lang['lockexpire']            = 'Il blocco scade alle';
-$lang['willexpire']            = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';
+$lang['js']['willexpire']      = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';
 $lang['js']['notsavedyet']     = 'Le modifiche non salvate andranno perse.';
 $lang['js']['searchmedia']     = 'Cerca file';
 $lang['js']['keepopen']        = 'Tieni la finestra aperta durante la selezione';
@@ -129,7 +143,15 @@ $lang['js']['nosmblinks']      = 'I collegamenti con le risorse condivise di Win
 $lang['js']['linkwiz']         = 'Collegamento guidato';
 $lang['js']['linkto']          = 'Collega a:';
 $lang['js']['del_confirm']     = 'Eliminare veramente questa voce?';
-$lang['js']['mu_btn']          = 'Carica più di un file alla volta';
+$lang['js']['restore_confirm'] = 'Vuoi davvero ripristinare questa versione?';
+$lang['js']['media_diff']      = 'Guarda le differenze:';
+$lang['js']['media_diff_both'] = 'Fianco a Fianco';
+$lang['js']['media_select']    = 'Seleziona files..';
+$lang['js']['media_upload_btn'] = 'Upload';
+$lang['js']['media_done_btn']  = 'Fatto';
+$lang['js']['media_drop']      = 'Sgancia i files qui per caricarli';
+$lang['js']['media_cancel']    = 'rimuovi';
+$lang['js']['media_overwrt']   = 'Sovrascrivi i file esistenti';
 $lang['rssfailed']             = 'Si è verificato un errore cercando questo feed: ';
 $lang['nothingfound']          = 'Nessun risultato trovato.';
 $lang['mediaselect']           = 'Selezione dei file';
@@ -164,6 +186,9 @@ $lang['yours']                 = 'la tua versione';
 $lang['diff']                  = 'differenze con la versione attuale';
 $lang['diff2']                 = 'differenze tra le versioni selezionate';
 $lang['difflink']              = 'Link a questa pagina di confronto';
+$lang['diff_type']             = 'Guarda le differenze:';
+$lang['diff_inline']           = 'In linea';
+$lang['diff_side']             = 'Fianco a Fianco';
 $lang['line']                  = 'Linea';
 $lang['breadcrumb']            = 'Traccia';
 $lang['youarehere']            = 'Ti trovi qui';
@@ -171,16 +196,26 @@ $lang['lastmod']               = 'Ultima modifica';
 $lang['by']                    = 'da';
 $lang['deleted']               = 'eliminata';
 $lang['created']               = 'creata';
-$lang['restored']              = 'versione precedente ripristinata';
+$lang['restored']              = 'versione precedente ripristinata (%s)';
 $lang['external_edit']         = 'modifica esterna';
 $lang['summary']               = 'Oggetto della modifica';
 $lang['noflash']               = 'E\' necessario <a href="http://www.adobe.com/products/flashplayer/">il plugin Adobe Flash</a> per visualizzare questo contenuto.';
 $lang['download']              = 'Scarica lo "snippet"';
+$lang['tools']                 = 'Strumenti';
+$lang['user_tools']            = 'Strumenti Utente';
+$lang['site_tools']            = 'Strumenti Sito';
+$lang['page_tools']            = 'Strumenti Pagina';
+$lang['skip_to_content']       = 'salta al contenuto';
+$lang['sidebar']               = 'Barra laterale';
 $lang['mail_newpage']          = 'pagina aggiunta:';
 $lang['mail_changed']          = 'pagina modificata:';
 $lang['mail_subscribe_list']   = 'pagine modificate nella categoria:';
 $lang['mail_new_user']         = 'nuovo utente:';
 $lang['mail_upload']           = 'file caricato:';
+$lang['changes_type']          = 'Guarda cambiamenti di';
+$lang['pages_changes']         = 'Pagine';
+$lang['media_changes']         = 'File multimediali';
+$lang['both_changes']          = 'Sia pagine che media files';
 $lang['qb_bold']               = 'Grassetto';
 $lang['qb_italic']             = 'Corsivo';
 $lang['qb_underl']             = 'Sottolineato';
@@ -221,13 +256,16 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Parole chiave';
+$lang['img_width']             = 'Larghezza';
+$lang['img_height']            = 'Altezza';
+$lang['img_manager']           = 'Guarda nel gestore media';
 $lang['subscr_subscribe_success'] = 'Aggiunto %s alla lista di sottoscrizioni %s';
 $lang['subscr_subscribe_error'] = 'Impossibile aggiungere %s alla lista di sottoscrizioni %s';
 $lang['subscr_subscribe_noaddress'] = 'Non esiste alcun indirizzo associato al tuo account, non puoi essere aggiunto alla lista di sottoscrizioni';
 $lang['subscr_unsubscribe_success'] = 'Rimosso %s dalla lista di sottoscrizioni %s';
 $lang['subscr_unsubscribe_error'] = 'Impossibile rimuovere %s dalla lista di sottoscrizioni %s';
-$lang['subscr_already_subscribed'] = '% è già iscritto a %s';
-$lang['subscr_not_subscribed'] = '% non è iscritto a %s';
+$lang['subscr_already_subscribed'] = '%s è già iscritto a %s';
+$lang['subscr_not_subscribed'] = '%s non è iscritto a %s';
 $lang['subscr_m_not_subscribed'] = 'Attualmente non sei iscritto alla pagina o categoria corrente';
 $lang['subscr_m_new_header']   = 'Aggiungi sottoscrizione';
 $lang['subscr_m_current_header'] = 'Sottoscrizioni attuali';
@@ -235,10 +273,10 @@ $lang['subscr_m_unsubscribe']  = 'Rimuovi sottoscrizione';
 $lang['subscr_m_subscribe']    = 'Sottoscrivi';
 $lang['subscr_m_receive']      = 'Ricevi';
 $lang['subscr_style_every']    = 'email per ogni modifica';
-$lang['subscr_style_digest']   = 'email riassuntiva delle modifiche di ogni pagina';
-$lang['subscr_style_list']     = 'elenco delle pagine modificate dall\'ultima email';
-$lang['authmodfailed']         = 'La configurazione dell\'autenticazione non è corretta. Informa l\'amministratore di questo wiki.';
+$lang['subscr_style_digest']   = 'email di riassunto dei cambiamenti per ogni pagina (ogni %.2f giorni)';
+$lang['subscr_style_list']     = 'lista delle pagine cambiate dall\'ultima email (ogni %.2f giorni)';
 $lang['authtempfail']          = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, informa l\'amministratore di questo wiki.';
+$lang['authpwdexpire']         = 'La tua password scadrà in %d giorni, dovresti cambiarla quanto prima.';
 $lang['i_chooselang']          = 'Scegli la lingua';
 $lang['i_installer']           = 'Installazione di DokuWiki';
 $lang['i_wikiname']            = 'Nome Wiki';
@@ -255,29 +293,18 @@ $lang['i_confexists']          = '<code>%s</code> esiste già';
 $lang['i_writeerr']            = 'Impossibile creare <code>%s</code>. E\' necessario verificare i permessi della directory o del file oppure creare il file manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php (hash=<code>%s</code>) non riconosciuto o modificato';
 $lang['i_badval']              = '<code>%s</code> - valore vuoto o non valido';
-$lang['i_success']             = 'La configurazione è stata completata correttamente. Ora è possibile eliminare il file install.php. Poi, visita <a href="doku.php">il tuo nuovo DokuWiki</a>.';
-$lang['i_failure']             = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima di poter utilizzare <a href="doku.php">il tuo nuovo DokuWiki</a>.';
+$lang['i_success']             = 'La configurazione è stata completata correttamente. Ora è possibile eliminare il file install.php. Poi, visita <a href="doku.php?id=wiki:welcome">il tuo nuovo DokuWiki</a>.';
+$lang['i_failure']             = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima di poter utilizzare <a href="doku.php?id=wiki:welcome">il tuo nuovo DokuWiki</a>.';
 $lang['i_policy']              = 'Regole di accesso iniziali';
 $lang['i_pol0']                = 'Wiki Aperto (lettura, scrittura, caricamento file per tutti)';
 $lang['i_pol1']                = 'Wiki Pubblico (lettura per tutti, scrittura e caricamento file per gli utenti registrati)';
 $lang['i_pol2']                = 'Wiki Chiuso (lettura, scrittura, caricamento file solamente per gli utenti registrati)';
+$lang['i_allowreg']            = 'Permetti agli utenti di registrarsi';
 $lang['i_retry']               = 'Riprova';
 $lang['i_license']             = 'Per favore scegli la licenza sotto cui vuoi rilasciare il contenuto:';
-$lang['mu_intro']              = 'Qui si possono caricare più di un file alla volta. Scegliere "Sfoglia..." per aggiungere file alla coda. Alla fine, fai click su "Invia file".';
-$lang['mu_gridname']           = 'Nome file';
-$lang['mu_gridsize']           = 'Dimensione';
-$lang['mu_gridstat']           = 'Stato';
-$lang['mu_namespace']          = 'Categoria';
-$lang['mu_browse']             = 'Sfoglia';
-$lang['mu_toobig']             = 'troppo grande';
-$lang['mu_ready']              = 'pronto per caricare';
-$lang['mu_done']               = 'completo';
-$lang['mu_fail']               = 'fallito';
-$lang['mu_authfail']           = 'sessione scaduta';
-$lang['mu_progress']           = '@PCT@% caricato';
-$lang['mu_filetypes']          = 'Tipi di file permessi';
-$lang['mu_info']               = 'file caricati.';
-$lang['mu_lasterr']            = 'Ultimo errore:';
+$lang['i_license_none']        = 'Non mostrare informazioni sulla licenza';
+$lang['i_pop_field']           = 'Per favore, aiutaci ad incrementare la conoscenza di DokuWiki:';
+$lang['i_pop_label']           = 'Mensilmente invia una statistica d\'uso anonima di DokuWiki agli sviluppatori';
 $lang['recent_global']         = 'Stai attualmente vedendo le modifiche effettuate nell\'area <b>%s</b>. Puoi anche <a href="%s">vedere le modifiche recenti dell\'intero wiki</a>.';
 $lang['years']                 = '%d anni fa';
 $lang['months']                = '%d mesi fa';
@@ -287,3 +314,27 @@ $lang['hours']                 = '%d ore fa';
 $lang['minutes']               = '%d minuti fa';
 $lang['seconds']               = '%d secondi fa';
 $lang['wordblock']             = 'La modifica non è stata salvata perché contiene testo bloccato (spam).';
+$lang['media_uploadtab']       = 'Upload';
+$lang['media_searchtab']       = 'Cerca';
+$lang['media_file']            = 'File';
+$lang['media_viewtab']         = 'Guarda';
+$lang['media_edittab']         = 'Modifica';
+$lang['media_historytab']      = 'Storia';
+$lang['media_list_thumbs']     = 'Miniatura';
+$lang['media_list_rows']       = 'Righe';
+$lang['media_sort_name']       = 'Nome';
+$lang['media_sort_date']       = 'Data';
+$lang['media_namespaces']      = 'Scegli il namespace';
+$lang['media_files']           = 'File in %s';
+$lang['media_upload']          = 'Upload al %s';
+$lang['media_search']          = 'Cerca in %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s a %s';
+$lang['media_edit']            = 'Modifica %s';
+$lang['media_history']         = 'Storia di %s';
+$lang['media_meta_edited']     = 'metadata modificati';
+$lang['media_perm_read']       = 'Spiacente, non hai abbastanza privilegi per leggere i files.';
+$lang['media_perm_upload']     = 'Spiacente, non hai abbastanza privilegi per caricare files.';
+$lang['media_update']          = 'Carica nuova versione';
+$lang['media_restore']         = 'Ripristina questa versione';
+$lang['searchresult']          = 'Risultati della ricerca';
