@@ -1,10 +1,16 @@
 <?php
+
 /**
- * japanese language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Yuji Takenaka <webmaster@davilin.com>
  * @author Ikuo Obataya <i.obataya@gmail.com>
+ * @author Daniel Dupriest <kououken@gmail.com>
+ * @author Kazutaka Miyasaka <kazmiya@gmail.com>
+ * @author Taisuke Shimamoto <dentostar@gmail.com>
+ * @author Satoshi Sahara <sahara.satoshi@gmail.com>
+ * @author Hideaki SAWADA <chuno@live.jp>
+ * @author Hideaki SAWADA <sawadakun@live.jp>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -19,7 +25,7 @@ $lang['btn_show']              = '文書の表示';
 $lang['btn_create']            = '文書の作成';
 $lang['btn_search']            = '検索';
 $lang['btn_save']              = '保存';
-$lang['btn_preview']           = '確認';
+$lang['btn_preview']           = 'プレビュー';
 $lang['btn_top']               = '文書の先頭へ';
 $lang['btn_newer']             = '<< より新しい';
 $lang['btn_older']             = 'より古い >>';
@@ -27,7 +33,7 @@ $lang['btn_revs']              = '以前のリビジョン';
 $lang['btn_recent']            = '最近の変更';
 $lang['btn_upload']            = 'アップロード';
 $lang['btn_cancel']            = 'キャンセル';
-$lang['btn_index']             = '索引';
+$lang['btn_index']             = 'サイトマップ';
 $lang['btn_secedit']           = '編集';
 $lang['btn_login']             = 'ログイン';
 $lang['btn_logout']            = 'ログアウト';
@@ -38,15 +44,17 @@ $lang['btn_back']              = '戻る';
 $lang['btn_backlink']          = 'バックリンク';
 $lang['btn_backtomedia']       = 'メディアファイル選択に戻る';
 $lang['btn_subscribe']         = '変更履歴配信の登録';
-$lang['btn_unsubscribe']       = '変更履歴配信の解除';
-$lang['btn_subscribens']       = '名前空間変更配信の登録';
-$lang['btn_unsubscribens']     = '名前空間変更配信の解除';
 $lang['btn_profile']           = 'ユーザー情報の更新';
 $lang['btn_reset']             = 'リセット';
-$lang['btn_resendpwd']         = 'パスワード再発行';
+$lang['btn_resendpwd']         = '新しいパスワードをセット';
 $lang['btn_draft']             = 'ドラフトを編集';
 $lang['btn_recover']           = 'ドラフトを復元';
 $lang['btn_draftdel']          = 'ドラフトを削除';
+$lang['btn_revert']            = '元に戻す';
+$lang['btn_register']          = 'ユーザー登録';
+$lang['btn_apply']             = '適用';
+$lang['btn_media']             = 'メディアマネージャー';
+$lang['btn_deleteuser']        = '自分のアカウントの抹消';
 $lang['loggedinas']            = 'ようこそ';
 $lang['user']                  = 'ユーザー名';
 $lang['pass']                  = 'パスワード';
@@ -56,9 +64,9 @@ $lang['passchk']               = '確認';
 $lang['remember']              = 'ユーザー名とパスワードを記憶する';
 $lang['fullname']              = 'フルネーム';
 $lang['email']                 = 'メールアドレス';
-$lang['register']              = 'ユーザー登録';
 $lang['profile']               = 'ユーザー情報';
 $lang['badlogin']              = 'ユーザー名かパスワードが違います。';
+$lang['badpassconfirm']        = 'パスワードが間違っています。';
 $lang['minoredit']             = '小変更';
 $lang['draftdate']             = 'ドラフト保存日時：';
 $lang['nosecedit']             = 'ページ内容が変更されていますがセクション情報が古いため、代わりにページ全体をロードしました。';
@@ -75,9 +83,14 @@ $lang['profna']                = 'ユーザー情報の変更は出来ません'
 $lang['profnochange']          = '変更点はありませんでした。';
 $lang['profnoempty']           = 'ユーザー名とメールアドレスを入力して下さい。';
 $lang['profchanged']           = 'ユーザー情報は更新されました。';
+$lang['profnodelete']          = 'この wiki はユーザーを削除できない。';
+$lang['profdeleteuser']        = 'アカウントの削除';
+$lang['profdeleted']           = 'このwikiからあなたのユーザーアカウントは削除済です。';
+$lang['profconfdelete']        = 'このwikiから自分のアカウント抹消を希望します。<br/> この操作は取消すことができません。';
+$lang['profconfdeletemissing'] = '確認のチェックボックスがチェックされていません。';
 $lang['pwdforget']             = 'パスワードをお忘れですか？パスワード再発行';
 $lang['resendna']              = 'パスワードの再発行は出来ません。';
-$lang['resendpwd']             = '新しいパスワードを送信します：';
+$lang['resendpwd']             = '新しいパスワードをセット';
 $lang['resendpwdmissing']      = '全ての項目を入力して下さい。';
 $lang['resendpwdnouser']       = '入力されたユーザーが見つかりませんでした。';
 $lang['resendpwdbadauth']      = '申し訳ありません。この確認コードは有効ではありません。メール内に記載されたリンクを確認してください。';
@@ -85,16 +98,58 @@ $lang['resendpwdconfirm']      = '確認用のリンクを含んだメールを
 $lang['resendpwdsuccess']      = '新しいパスワードがメールで送信されました。';
 $lang['license']               = '特に明示されていない限り、本Wikiの内容は次のライセンスに従います：';
 $lang['licenseok']             = '注意： 本ページを編集することは、あなたの編集した内容が次のライセンスに従うことに同意したものとみなします：';
+$lang['searchmedia']           = '検索ファイル名：';
+$lang['searchmedia_in']        = '%s 内を検索';
 $lang['txt_upload']            = 'アップロードするファイルを選んでください。';
 $lang['txt_filename']          = '名前を変更してアップロード（オプション）';
 $lang['txt_overwrt']           = '既存のファイルを上書き';
-$lang['lockedby']              = 'この文書は次のユーザによってロックされています';
+$lang['maxuploadsize']         = 'アップロード上限サイズ %s /ファイル';
+$lang['lockedby']              = 'この文書は次のユーザーによってロックされています';
 $lang['lockexpire']            = 'ロック期限：';
-$lang['willexpire']            = '編集中の文書はロック期限を過ぎようとしています。このままロックする場合は、一度文書の確認を行って期限をリセットしてください。';
-$lang['notsavedyet']           = '変更は保存されません。このまま処理を続けてよろしいですか？';
-$lang['rssfailed']             = 'RSSの取り出しに失敗しました：';
+$lang['js']['willexpire']      = '編集中の文書はロック期限を過ぎようとしています。このままロックする場合は、一度文書の確認を行って期限をリセットしてください。';
+$lang['js']['notsavedyet']     = '変更は保存されません。このまま処理を続けてよろしいですか？';
+$lang['js']['searchmedia']     = 'ファイル検索';
+$lang['js']['keepopen']        = '選択中はウィンドウを閉じない';
+$lang['js']['hidedetails']     = '詳細を非表示';
+$lang['js']['mediatitle']      = 'リンク設定';
+$lang['js']['mediadisplay']    = 'リンクタイプ';
+$lang['js']['mediaalign']      = '位置';
+$lang['js']['mediasize']       = 'イメージサイズ';
+$lang['js']['mediatarget']     = 'リンク先';
+$lang['js']['mediaclose']      = '閉じる';
+$lang['js']['mediainsert']     = '挿入';
+$lang['js']['mediadisplayimg'] = 'イメージを表示';
+$lang['js']['mediadisplaylnk'] = 'リンクのみ表示';
+$lang['js']['mediasmall']      = '小さいサイズ';
+$lang['js']['mediamedium']     = '通常サイズ';
+$lang['js']['medialarge']      = '大きいサイズ';
+$lang['js']['mediaoriginal']   = 'オリジナルのサイズ';
+$lang['js']['medialnk']        = '詳細ページへのリンク';
+$lang['js']['mediadirect']     = 'オリジナルへの直リンク';
+$lang['js']['medianolnk']      = 'リンク無し';
+$lang['js']['medianolink']     = 'イメージをリンクしない';
+$lang['js']['medialeft']       = 'イメージを左に寄せる';
+$lang['js']['mediaright']      = 'イメージを右に寄せる';
+$lang['js']['mediacenter']     = 'イメージを中央に寄せる';
+$lang['js']['medianoalign']    = '位置を設定しない';
+$lang['js']['nosmblinks']      = 'ウィンドウズの共有フォルダへリンクは Microsoft Internet Explorer でしか機能しませんが、リンクをコピーして貼り付けることは可能です。';
+$lang['js']['linkwiz']         = 'リンクウィザード';
+$lang['js']['linkto']          = 'リンク先：';
+$lang['js']['del_confirm']     = '選択した項目を本当に削除しますか？';
+$lang['js']['restore_confirm'] = '本当にこのバージョンを復元しますか?';
+$lang['js']['media_diff']      = '差分の表示方法:';
+$lang['js']['media_diff_both'] = '並べて表示';
+$lang['js']['media_diff_opacity'] = '重ねて透過表示';
+$lang['js']['media_diff_portions'] = '重ねて切替表示';
+$lang['js']['media_select']    = 'ファイルを選択...';
+$lang['js']['media_upload_btn'] = 'アップロード';
+$lang['js']['media_done_btn']  = '完了';
+$lang['js']['media_drop']      = 'ここにファイルをドロップするとアップロードします';
+$lang['js']['media_cancel']    = '削除';
+$lang['js']['media_overwrt']   = '既存のファイルを上書きする';
+$lang['rssfailed']             = 'RSSの取得に失敗しました：';
 $lang['nothingfound']          = '該当文書はありませんでした。';
-$lang['mediaselect']           = 'メディアファイルを選択';
+$lang['mediaselect']           = 'メディアファイル';
 $lang['fileupload']            = 'メディアファイルをアップロード';
 $lang['uploadsucc']            = 'アップロード完了';
 $lang['uploadfail']            = 'アップロードに失敗しました。権限がありません。';
@@ -109,11 +164,7 @@ $lang['deletefail']            = 'ファイル "%s" が削除できません。
 $lang['mediainuse']            = 'ファイル "%s" は使用中のため、削除されませんでした。';
 $lang['namespaces']            = '名前空間';
 $lang['mediafiles']            = '有効なファイル：';
-$lang['js']['keepopen']        = '選択中はウィンドウを閉じない';
-$lang['js']['hidedetails']     = '詳細を非表示';
-$lang['js']['nosmblinks']      = 'ウィンドウズの共有フォルダへリンクは Microsoft Internet Explorer でのみ可能となります。
-当然、カットアンドペーストが使用できます。';
-$lang['js']['mu_btn']          = '複数のファイルを一度にアップロード';
+$lang['accessdenied']          = 'このページを閲覧する権限がありません。';
 $lang['mediausage']            = 'このファイルを使用するためには次の文法を使用する：';
 $lang['mediaview']             = 'オリジナルファイルを閲覧';
 $lang['mediaroot']             = 'ルート';
@@ -129,6 +180,10 @@ $lang['current']               = '現在';
 $lang['yours']                 = 'あなたのバージョン';
 $lang['diff']                  = '現在のリビジョンとの差分を表示';
 $lang['diff2']                 = '選択したリビジョン間の差分を表示';
+$lang['difflink']              = 'この比較画面にリンクする';
+$lang['diff_type']             = '差分の表示方法：';
+$lang['diff_inline']           = 'インライン';
+$lang['diff_side']             = '横に並べる';
 $lang['line']                  = 'ライン';
 $lang['breadcrumb']            = 'トレース';
 $lang['youarehere']            = '現在位置';
@@ -136,15 +191,26 @@ $lang['lastmod']               = '最終更新';
 $lang['by']                    = 'by';
 $lang['deleted']               = '削除';
 $lang['created']               = '作成';
-$lang['restored']              = '以前のバージョンを復元';
+$lang['restored']              = '以前のリビジョンを復元 (%s)';
 $lang['external_edit']         = '外部編集';
-$lang['summary']               = 'サマリーを編集';
+$lang['summary']               = '編集の概要';
 $lang['noflash']               = 'この内容を表示するためには <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> が必要です。';
+$lang['download']              = 'この部分をダウンロード';
+$lang['tools']                 = 'ツール';
+$lang['user_tools']            = 'ユーザ用ツール';
+$lang['site_tools']            = 'サイト用ツール';
+$lang['page_tools']            = 'ページ用ツール';
+$lang['skip_to_content']       = '内容へ移動';
+$lang['sidebar']               = 'サイドバー';
 $lang['mail_newpage']          = '文書の追加：';
 $lang['mail_changed']          = '文書の変更：';
+$lang['mail_subscribe_list']   = '名前空間内でページが変更：';
 $lang['mail_new_user']         = '新規ユーザー：';
 $lang['mail_upload']           = 'ファイルのアップロード：';
-$lang['qb_alert']              = '文書の最後に挿入したい定型文書を入力して下さい。';
+$lang['changes_type']          = '表示する変更のタイプ:';
+$lang['pages_changes']         = 'ページの変更';
+$lang['media_changes']         = 'メディアファイルの変更';
+$lang['both_changes']          = 'ページとメディアファイルの変更';
 $lang['qb_bold']               = '太字';
 $lang['qb_italic']             = '斜体';
 $lang['qb_underl']             = '下線';
@@ -155,6 +221,11 @@ $lang['qb_h2']                 = '第二見出し';
 $lang['qb_h3']                 = '第三見出し';
 $lang['qb_h4']                 = '第四見出し';
 $lang['qb_h5']                 = '第五見出し';
+$lang['qb_h']                  = '見出し';
+$lang['qb_hs']                 = '見出し選択';
+$lang['qb_hplus']              = '上の階層の見出し';
+$lang['qb_hminus']             = '下の階層の見出し';
+$lang['qb_hequal']             = '同じ階層の見出し';
 $lang['qb_link']               = '内部リンク';
 $lang['qb_extlink']            = '外部リンク';
 $lang['qb_hr']                 = '横罫線';
@@ -164,7 +235,7 @@ $lang['qb_media']              = 'イメージやファイルの追加';
 $lang['qb_sig']                = '署名の挿入';
 $lang['qb_smileys']            = 'スマイリー';
 $lang['qb_chars']              = '特殊文字';
-$lang['del_confirm']           = '選択した項目を本当に削除しますか？';
+$lang['upperns']               = '上の階層の名前空間へ';
 $lang['admin_register']        = '新規ユーザー作成';
 $lang['metaedit']              = 'メタデータ編集';
 $lang['metasaveerr']           = 'メタデータの書き込みに失敗しました';
@@ -180,13 +251,27 @@ $lang['img_copyr']             = '著作権';
 $lang['img_format']            = 'フォーマット';
 $lang['img_camera']            = '使用カメラ';
 $lang['img_keywords']          = 'キーワード';
-$lang['subscribe_success']     = '変更履歴配信の登録が完了しました。';
-$lang['subscribe_error']       = '変更履歴配信の登録に失敗しました。';
-$lang['subscribe_noaddress']   = 'ログインしていないため、変更履歴配信に登録することはできません。';
-$lang['unsubscribe_success']   = '変更履歴配信の解除が完了しました。';
-$lang['unsubscribe_error']     = '変更履歴配信の解除に失敗しました。';
-$lang['authmodfailed']         = 'ユーザー認証の設定が正しくありません。Wikiの管理者に連絡して下さい。';
+$lang['img_width']             = '幅';
+$lang['img_height']            = '高さ';
+$lang['img_manager']           = 'メディアマネージャーで閲覧';
+$lang['subscr_subscribe_success'] = '%sが%sの購読リストに登録されました。';
+$lang['subscr_subscribe_error'] = '%sを%sの購読リストへの追加に失敗しました。';
+$lang['subscr_subscribe_noaddress'] = 'あなたのログインに対応するアドレスがないため、購読リストへ追加することができません。';
+$lang['subscr_unsubscribe_success'] = '%sを%sの購読リストから削除しました。';
+$lang['subscr_unsubscribe_error'] = '%sを%sの購読リストからの削除に失敗しました。';
+$lang['subscr_already_subscribed'] = '%sは既に%sに登録されています。';
+$lang['subscr_not_subscribed'] = '%sは%sに登録されていません。';
+$lang['subscr_m_not_subscribed'] = '現在のページ、もしくは名前空間にあなたは登録されていません。';
+$lang['subscr_m_new_header']   = '購読を追加';
+$lang['subscr_m_current_header'] = '現在の購読リスト';
+$lang['subscr_m_unsubscribe']  = '購読を解除';
+$lang['subscr_m_subscribe']    = '購読';
+$lang['subscr_m_receive']      = '受信';
+$lang['subscr_style_every']    = '全ての変更にメールを送信';
+$lang['subscr_style_digest']   = 'それぞれのページへの変更の要約をメールする（%.2f 日毎）';
+$lang['subscr_style_list']     = '前回のメールから変更されたページをリスト（%.2f 日毎）';
 $lang['authtempfail']          = 'ユーザー認証が一時的に使用できなくなっています。この状態が続いているようであれば、Wikiの管理者に連絡して下さい。';
+$lang['authpwdexpire']         = 'あなたのパスワードは、あと%d日で有効期限が切れます。パスワードを変更してください。';
 $lang['i_chooselang']          = '使用言語を選択してください';
 $lang['i_installer']           = 'DokuWiki インストーラー';
 $lang['i_wikiname']            = 'Wiki名';
@@ -196,31 +281,58 @@ $lang['i_problems']            = '問題が発見されました。以下に示
 $lang['i_modified']            = 'セキュリティの理由から、新規もしくはカスタマイズしていない DokuWiki に対してのみ、このスクリプトは有効です。
                          ダウンロードしたパッケージを再解凍して使用するか、
                          <a href="http://dokuwiki.org/install">Dokuwiki インストールガイド</a>を参考にしてインストールしてください。';
-$lang['i_funcna']              = 'PHPの関数 <code>%s</code> が使用できません。ホスティング会社が何らかの理由で無効にしている恐れがあります。';
+$lang['i_funcna']              = 'PHPの関数 <code>%s</code> が使用できません。ホスティング会社が何らかの理由で無効にしている可能性があります。';
 $lang['i_phpver']              = 'PHPのバージョン <code>%s</code> が必要なバージョン <code>%s</code> より以前のものです。PHPのアップグレードが必要です。';
 $lang['i_permfail']            = '<code>%s</code> に書き込みできません。このディレクトリの権限を確認して下さい。';
 $lang['i_confexists']          = '<code>%s</code> は既に存在します';
 $lang['i_writeerr']            = '<code>%s</code> を作成できません。ディレクトリとファイルの権限を確認し、それらを手動で作成する必要があります。';
 $lang['i_badhash']             = 'dokuwiki.php が認識できないか、編集されています（hash=<code>%s</code>）';
 $lang['i_badval']              = '<code>%s</code> - 正しくない、もしくは値が空です';
-$lang['i_success']             = '設定ファイルは正しく作成されました。<a href="doku.php">作成した DokuWiki</a>を使用するには install.php を削除してください。';
-$lang['i_failure']             = '設定ファイルの作成中にエラーが発生しました。<a href="doku.php">作成した DokuWiki</a>を使用する前に、それらの問題を手動で修正する必要があります。';
+$lang['i_success']             = '設定ファイルは正しく作成されました。<a href="doku.php?id=wiki:welcome">作成した DokuWiki</a>を使用するには install.php を削除してください。';
+$lang['i_failure']             = '設定ファイルの作成中にエラーが発生しました。<a href="doku.php?id=wiki:welcome">作成した DokuWiki</a>を使用する前に、それらの問題を手動で修正する必要があります。';
 $lang['i_policy']              = 'ACL初期設定';
 $lang['i_pol0']                = 'オープン Wiki（全ての人に、閲覧・書き込み・アップロードを許可）';
 $lang['i_pol1']                = 'パブリック Wiki（閲覧は全ての人が可能、書き込み・アップロードは登録ユーザーのみ）';
 $lang['i_pol2']                = 'クローズド Wiki (登録ユーザーにのみ使用を許可)';
+$lang['i_allowreg']            = 'ユーザ自身で登録可能';
 $lang['i_retry']               = '再試行';
-$lang['mu_intro']              = '複数のファイルを一度にアップロードできます。ブラウズボタンをクリックしてファイルを追加してください。追加したら、アップロードボタンをクリックしてください。';
-$lang['mu_gridname']           = 'ファイル名';
-$lang['mu_gridsize']           = 'サイズ';
-$lang['mu_gridstat']           = 'ステータス';
-$lang['mu_namespace']          = '名前空間';
-$lang['mu_browse']             = 'ブラウズ';
-$lang['mu_toobig']             = '大きすぎます';
-$lang['mu_ready']              = 'アップロードできます';
-$lang['mu_done']               = '完了';
-$lang['mu_fail']               = '失敗';
-$lang['mu_authfail']           = 'セッション期限切れ';
-$lang['mu_progress']           = '@PCT@% アップロード完了';
-$lang['mu_filetypes']          = '使用できるファイル形式';
-$lang['recent_global']         = '現在、<b>%s</b> 名前空間内の変更点を閲覧中です。<a href="%s">Wiki全体の最近の変更点を確認する</a>ことも可能です。';
+$lang['i_license']             = 'あなたが作成したコンテンツが属するライセンスを選択してください：';
+$lang['i_license_none']        = 'ライセンス情報を表示しません。';
+$lang['i_pop_field']           = 'Dokuwiki の内容の向上に協力して下さい：';
+$lang['i_pop_label']           = '月に一回、DokuWikiの開発者に匿名の使用データを送信します。';
+$lang['recent_global']         = '現在、<b>%s</b> 名前空間内の変更点を閲覧中です。<a href="%s">Wiki全体の最近の変更点の確認</a>もできます。';
+$lang['years']                 = '%d年前';
+$lang['months']                = '%dカ月前';
+$lang['weeks']                 = '%d週間前';
+$lang['days']                  = '%d日前';
+$lang['hours']                 = '%d時間前';
+$lang['minutes']               = '%d分前';
+$lang['seconds']               = '%d秒前';
+$lang['wordblock']             = 'スパムと認識されるテキストが含まれているため、変更は保存されませんでした。';
+$lang['media_uploadtab']       = 'アップロード';
+$lang['media_searchtab']       = '検索';
+$lang['media_file']            = 'ファイル';
+$lang['media_viewtab']         = '詳細';
+$lang['media_edittab']         = '編集';
+$lang['media_historytab']      = '履歴';
+$lang['media_list_thumbs']     = 'サムネイル';
+$lang['media_list_rows']       = '行';
+$lang['media_sort_name']       = '名前';
+$lang['media_sort_date']       = '日付';
+$lang['media_namespaces']      = '名前空間を選択';
+$lang['media_files']           = '%s 内のファイル';
+$lang['media_upload']          = '%s にアップロード';
+$lang['media_search']          = '%s 内で検索';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s at %s';
+$lang['media_edit']            = '%s を編集';
+$lang['media_history']         = '%s の履歴';
+$lang['media_meta_edited']     = 'メタデータが編集されました';
+$lang['media_perm_read']       = 'ファイルを閲覧する権限がありません。';
+$lang['media_perm_upload']     = 'ファイルをアップロードする権限がありません。';
+$lang['media_update']          = '新しいバージョンをアップロード';
+$lang['media_restore']         = 'このバージョンを復元';
+$lang['currentns']             = '現在の名前空間';
+$lang['searchresult']          = '検索結果';
+$lang['plainhtml']             = 'プレーンHTML';
+$lang['wikimarkup']            = 'Wikiマークアップ';
