@@ -40,7 +40,6 @@ $lang['btn_back']              = 'Atgal';
 $lang['btn_backlink']          = 'Atgalinės nuorodos';
 $lang['btn_backtomedia']       = 'Atgal į Mediabylos išsirinkimą';
 $lang['btn_subscribe']         = 'Užsisakyti keitimų prenumeratą';
-$lang['btn_unsubscribe']       = 'Atsisakyti keitimų prenumeratos';
 $lang['btn_profile']           = 'Atnaujinti profilį';
 $lang['btn_reset']             = 'Atstata';
 $lang['btn_draft']             = 'Redaguoti juodraštį';
@@ -175,12 +174,6 @@ $lang['img_copyr']             = 'Autorinės teisės';
 $lang['img_format']            = 'Formatas';
 $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Raktiniai žodžiai';
-$lang['subscribe_success']     = '%s užsakyta "%s" prenumerata';
-$lang['subscribe_error']       = '%s užsakant "%s" prenumeratą įvyko klaida';
-$lang['subscribe_noaddress']   = 'Jūs nesatė nurodęs el. pašto adreso, todėl negalima Jums užsakyti prenumeratos';
-$lang['unsubscribe_success']   = '%s ištrintas iš "%s" prenumeratos';
-$lang['unsubscribe_error']     = '%s trinant iš "%s" prenumeratos įvyko klaida';
-$lang['authmodfailed']         = 'Bloga vartotojo tapatumo nustatymo konfigūracija. Praneškite apie tai savo administratoriui.';
 $lang['authtempfail']          = 'Vartotojo tapatumo nustatymas laikinai nepasiekiamas. Jei ši situacija kartojasi, tai praneškite savo administratoriui.';
 $lang['i_chooselang']          = 'Pasirinkite kalbą';
 $lang['i_installer']           = 'DokuWiki Instaliatorius';
