@@ -56,7 +56,7 @@ $lang['lockedby']     = 'Mbola voahidin\'i';
 $lang['lockexpire']   = 'Afaka ny hidy amin\'ny';
 $lang['js']['willexpire']   = 'Efa ho lany fotoana afaka iray minitra ny hidy ahafahanao manova ny pejy.\nMba hialana amin\'ny conflit dia ampiasao ny bokotra topi-maso hamerenana ny timer-n\'ny hidy.';
 
-$lang['js']['notsavedyet'] = "Misy fiovana tsy voarakitra, ho very izany ireo.\nAzo antoka fa hotohizana?";
+$lang['js']['notsavedyet'] = 'Misy fiovana tsy voarakitra, ho very izany ireo.\nAzo antoka fa hotohizana?';
 $lang['rssfailed']   = 'An error occured while fetching this feed: ';
 $lang['nothingfound']= 'Tsy nahitana n\'inon\'inona.';
 
@@ -88,7 +88,7 @@ $lang['lastmod']    = 'Novaina farany:';
 $lang['by']         = '/';
 $lang['deleted']    = 'voafafa';
 $lang['created']    = 'Voamboatra';
-$lang['restored']   = 'Naverina tamin\'ny kinova taloha';
+$lang['restored']   = 'Naverina tamin\'ny kinova taloha (%s)';
 $lang['summary']    = 'Fanovana teo';
 
 $lang['mail_newpage'] = 'pejy niampy:';
@@ -116,20 +116,6 @@ $lang['qb_sig']     = 'Manisy sonia';
 
 $lang['js']['del_confirm']= 'Hofafana ilay andalana?';
 
-$lang['admin_acl']  = 'Fitantanana ACL (Access Control List)...';
 $lang['admin_register']= 'Ampio mpampiasa vaovao...';
 
-$lang['acl_group']  = 'Vondrona';
-$lang['acl_user']   = 'Mpampiasa';
-$lang['acl_perms']  = 'Alalana @';
-$lang['page']       = 'Pejy';
-$lang['namespace']  = 'Namespace';
-
-$lang['acl_perm1']  = 'Mamaky';
-$lang['acl_perm2']  = 'Manova';
-$lang['acl_perm4']  = 'Manamboatra';
-$lang['acl_perm8']  = 'Mandefa rakitra';
-$lang['acl_perm16'] = 'Mamafa';
-$lang['acl_new']    = 'Ampio andalana vaovao';
-
 //Setup VIM: ex: et ts=2 :
