@@ -1,6 +1,7 @@
 <?php
+
 /**
- * Nepali language file
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  *
  * @author Saroj Kumar Dhakal <lotusnagarkot@gmail.com>
  * @author Saroj Kumar Dhakal <lotusnagarkot@yahoo.com>
@@ -37,12 +38,8 @@ $lang['btn_back']              = 'पछाडि';
 $lang['btn_backlink']          = 'पछाडिका लिङ्कहरु ';
 $lang['btn_backtomedia']       = 'मिडिया छनौटमा फर्कनुहोस्';
 $lang['btn_subscribe']         = 'पृष्ठ परिवर्तन ग्राह्य गर्नुहोस्';
-$lang['btn_unsubscribe']       = 'पृष्ठ परिवर्तन अग्राह्य गर्नुहोस्';
-$lang['btn_subscribens']       = 'नेमस्पेस परिवर्तन ग्राह्य गर्नुहोस् ';
-$lang['btn_unsubscribens']     = 'नेमस्पेस परिवर्तन अग्राह्य गर्नुहोस् ';
 $lang['btn_profile']           = 'प्रोफाइल अध्यावधिक गर्नुहोस् ';
 $lang['btn_reset']             = 'पूर्वरुपमा फर्काउनुहोस';
-$lang['btn_resendpwd']         = 'नयाँ प्रवेश शव्द(पासवर्ड) पठाउनुहोस् ';
 $lang['btn_draft']             = ' ड्राफ्ट सम्पादन गर्नुहोस् ';
 $lang['btn_recover']           = 'पहिलेको ड्राफ्ट हासिल गर्नुहोस ';
 $lang['btn_draftdel']          = ' ड्राफ्ट मेटाउनुहोस् ';
@@ -77,7 +74,6 @@ $lang['profchanged']           = 'प्रयोगकर्ताको प्
 $lang['pwdforget']             = 'आफ्नो पासवर्ड भुल्नु भयो ? नयाँ हासिल गर्नुहोस् ';
 $lang['resendna']              = 'यो विकिबाट प्रवेशशव्द पठाउन समर्थित छैन ।';
 $lang['resendpwd']             = 'नयाँ  प्रवेशशव्द पठाउनुहोस् ';
-$lang['resendpwdmissing']      = 'माफ गर्नुहोस् , तपाईले सबै ठाउ भर्नुपर्छ। ';
 $lang['resendpwdnouser']       = 'माफ गर्नुहोस्,  हाम्रो डेटावेसमा यो प्रयोगकर्ता भेटिएन ।';
 $lang['resendpwdbadauth']      = 'माफ गर्नुहोस् , यो अनुमति चिन्ह गलत छ। तपाईले पूरै जानकारी लिङ्क प्रयोग गर्नु पर्नेछ। ';
 $lang['resendpwdconfirm']      = 'तपाईको इमेलमा कन्फरमेशन लिङ्क पठाइएको छ। ';
@@ -89,8 +85,12 @@ $lang['txt_filename']          = 'अर्को रुपमा अपलो
 $lang['txt_overwrt']           = 'रहेको उहि नामको फाइललाई मेटाउने';
 $lang['lockedby']              = 'अहिले ताल्चा लगाइएको';
 $lang['lockexpire']            = 'ताल्चा अवधि सकिने :';
-$lang['willexpire']            = 'तपाईलले यो पृष्ठ सम्पादन गर्न लगाउनु भएको ताल्चाको अवधि एक मिनेट भित्र सकिदै छ। \n द्वन्द हुन नदिन  पूर्वरुप वा ताल्चा समय परिवर्तन गर्नुहोस् ।';
-$lang['js']['notsavedyet']     = "तपाईले वचन गर्नु नभएको परिवर्रन हराउने छ। \n साच्चै जारी गर्नुहुन्छ ।";
+$lang['js']['willexpire']      = 'तपाईलले यो पृष्ठ सम्पादन गर्न लगाउनु भएको ताल्चाको अवधि एक मिनेट भित्र सकिदै छ। \n द्वन्द हुन नदिन  पूर्वरुप वा ताल्चा समय परिवर्तन गर्नुहोस् ।';
+$lang['js']['notsavedyet']     = 'तपाईले वचन गर्नु नभएको परिवर्रन हराउने छ। \n साच्चै जारी गर्नुहुन्छ ।';
+$lang['js']['keepopen']        = 'छनौटमा विन्डो खुला राख्नुहोस् ';
+$lang['js']['hidedetails']     = 'जानकारी लुकाउनु होस् ';
+$lang['js']['nosmblinks']      = 'विन्डोहरु लिङ्क गर्दा माइक्रो सफ्ट एक्सप्लोररमामात्र  काम साझा हुन्छ । तर कपि गर्न र टास्न मिल्छ।   ';
+$lang['js']['del_confirm']     = 'साच्चै छानिएका वस्तुहरु मेट्ने हो ?';
 $lang['rssfailed']             = 'यो फिड लिइ आउदा गल्ति भयो ।';
 $lang['nothingfound']          = 'केहि पनि भेटिएन ।';
 $lang['mediaselect']           = 'मिडिया फाइलहरू ';
@@ -107,10 +107,6 @@ $lang['deletefail']            = '"%s"  मेट्न सकिएन - अन
 $lang['mediainuse']            = 'फाइल "%s" मेटिएको छैन - प्रयोगमा छ।';
 $lang['namespaces']            = 'नेमस्पेसहरु ';
 $lang['mediafiles']            = ' उपलब्ध फाइलहरु ';
-$lang['js']['keepopen']        = 'छनौटमा विन्डो खुला राख्नुहोस् ';
-$lang['js']['hidedetails']     = 'जानकारी लुकाउनु होस् ';
-$lang['js']['nosmblinks']      = 'विन्डोहरु लिङ्क गर्दा माइक्रो सफ्ट एक्सप्लोररमामात्र  काम साझा हुन्छ । तर कपि गर्न र टास्न मिल्छ।   ';
-$lang['js']['mu_btn']          = 'धेरै वटा फाइलहरु एकैपटक अपलोड गर्नुहोस् ।';
 $lang['mediausage']            = 'फाइललाई रेफरेन्स गर्न निम्न सुत्र प्रयोग गर्नुहोस् :';
 $lang['mediaview']             = 'सक्कली फाइल हेर्नुहोस् ';
 $lang['mediaroot']             = 'रुट(मूख्य प्रयोगकर्ता)';
@@ -133,7 +129,6 @@ $lang['lastmod']               = 'अन्तिम पटक सच्या
 $lang['by']                    = 'द्वारा ';
 $lang['deleted']               = 'हटाइएको';
 $lang['created']               = 'निर्माण गरिएको';
-$lang['restored']              = 'पुरानो संस्करण पुनर्‌प्रयोग गरिएको';
 $lang['external_edit']         = 'बाह्य सम्पादन';
 $lang['summary']               = 'सम्पादनको बारेमा';
 $lang['mail_newpage']          = 'थपिएको पृष्ठ';
@@ -159,7 +154,6 @@ $lang['qb_media']              = 'तस्विर र अरु फाइल
 $lang['qb_sig']                = 'हस्ताक्षर थप्नुहोस् ';
 $lang['qb_smileys']            = 'स्माइलीहरु ';
 $lang['qb_chars']              = 'विशेष वर्णहरु ';
-$lang['js']['del_confirm']           = 'साच्चै छानिएका वस्तुहरु मेट्ने हो ?';
 $lang['admin_register']        = 'नयाँ प्रयोगकर्ता थप्नुहोस् ';
 $lang['metaedit']              = 'मेटाडेटा सम्पादन गर्नुहोस्';
 $lang['metasaveerr']           = 'मेटाडाटा लेखन असफल';
@@ -175,12 +169,6 @@ $lang['img_copyr']             = 'सर्वाधिकार';
 $lang['img_format']            = 'ढाचा';
 $lang['img_camera']            = 'क्यामेरा';
 $lang['img_keywords']          = 'खोज शब्द';
-$lang['subscribe_success']     = '%s ,%s को ग्राह्यताको लागि थपियो  ';
-$lang['subscribe_error']       = '%s ,%s को ग्राह्यताको लागि थपिदा त्रुटि';
-$lang['subscribe_noaddress']   = 'तपाईको खातासँग कुनै पनि ठेगाना संबन्धित छैन , तपाईलाई  ग्रहाक सुचीमा राखन मिलेन।';
-$lang['unsubscribe_success']   = '%s लाई %s को ग्रहाक सुचीबाट हटाइयो';
-$lang['unsubscribe_error']     = '%s लाई %s को ग्राहक सुचीबाट हटाउदा त्रुटि';
-$lang['authmodfailed']         = 'खराब प्रयोगकर्ता प्रामाणिकरण विधि ।तपाईको विकी एड्मिनलाई खवर गर्नुहोस् ।';
 $lang['authtempfail']          = 'प्रयोगकर्ता प्रामाणिकरण अस्थाइरुपमा अनुपलब्ध छ। यदि यो समस्या रहि रहेमा तपाईको  विकि एड्मिनलाई खवर गर्नुहोला ।';
 $lang['i_chooselang']          = 'भाषा छान्नुहोस् ';
 $lang['i_installer']           = 'DokuWiki  स्थापक';
@@ -196,24 +184,11 @@ $lang['i_confexists']          = '<code>%s</code> पहिले देखि 
 $lang['i_writeerr']            = '<code>%s</code> बनाउन असमर्थ । तपाईले डाइरेक्टरी / फाइल अनुमति जाच्नु पर्छ र फाइल आफैले बनाउनु पर्छ ।';
 $lang['i_badhash']             = 'पहिचान हुन नसकेको वा परिवर्तित  okuwiki.php (hash=code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - अवैध वा रित्तो मान ';
-$lang['i_success']             = 'स्थापना सफलरुपमा समाप्त भयो ।तपाई install.php मेट्न सक्नुहु्न्छ । <a href="doku.php">तपाईको नयाँ DokuWiki</a> निरन्तर गर्न सक्नुहुन्छ ।';
-$lang['i_failure']             = 'स्थापना समयमा केहि त्रुटि फेला पर्यो ।तपाईले आफैले यसलाई <a href="doku.php">तपाईको नयाँ DokuWiki</a> प्रयोग गर्नु अगि	सच्याउनुपर्ने  हुन्छ ।';
+$lang['i_success']             = 'स्थापना सफलरुपमा समाप्त भयो ।तपाई install.php मेट्न सक्नुहु्न्छ । <a href="doku.php?id=wiki:welcome">तपाईको नयाँ DokuWiki</a> निरन्तर गर्न सक्नुहुन्छ ।';
+$lang['i_failure']             = 'स्थापना समयमा केहि त्रुटि फेला पर्यो ।तपाईले आफैले यसलाई <a href="doku.php?id=wiki:welcome">तपाईको नयाँ DokuWiki</a> प्रयोग गर्नु अगि	सच्याउनुपर्ने  हुन्छ ।';
 $lang['i_policy']              = 'सुरुको ACL निति';
 $lang['i_pol0']                = 'खुल्ला विकि (पठन, लेखन , अपलोड ) सबैका लागि';
 $lang['i_pol1']                = 'Public विकि (पठन सवैका लागि,लेखन र अपलोड दर्ता गरिएका प्रयपगकर्ताका लागि ) ';
 $lang['i_pol2']                = 'बन्द विकि (पठन , लेखन, अपलोड ) दर्ता भएका प्रयोगकर्ताका लागि मात्र ।';
 $lang['i_retry']               = 'पुन: प्रयास गर्नुहोस् ';
-$lang['mu_intro']              = 'तपाईले धेरै वटा फाइलहरु एकै पटक अपलोड गर्न सक्नुहुन्छ । browse थिच्नुहोस् अनि सुचीमा थप्नुहोस् । सकिएपछि अपलोड थिछ्चुहोस् ।';
-$lang['mu_gridname']           = 'फाइलनाम ';
-$lang['mu_gridsize']           = 'आकार';
-$lang['mu_gridstat']           = 'स्थिति';
-$lang['mu_namespace']          = 'नेमस्पेस';
-$lang['mu_browse']             = 'Browse';
-$lang['mu_toobig']             = 'धेरै ठूलो';
-$lang['mu_ready']              = 'अपलोडको लागि तयार';
-$lang['mu_done']               = 'पूरा';
-$lang['mu_fail']               = 'असफल';
-$lang['mu_authfail']           = 'सत्र सकियो ';
-$lang['mu_progress']           = '@PCT@% अपलोड भयो ';
-$lang['mu_filetypes']          = 'समर्थित फाइल प्रकार';
 $lang['recent_global']         = 'तपाई अहिले <b>%s</b> नेमस्पेस भित्र भएका परिवर्तन हेर्दैहुनुहुन्छ। तपाई <a href="%s">पुरै विकिमा भएको परिवर्तन हेर्न सक्नुहुन्छ</a>.';
