@@ -1,8 +1,8 @@
 <?php
+
 /**
- * dutch language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author François Kooman <fkooman.tuxed.net>
  * @author Jack van Klaren <dokuwiki@afentoe.xs4all.nl>
  * @author Riny Heijdendael <riny@heijdendael.nl>
@@ -16,6 +16,11 @@
  * @author Timon Van Overveldt <timonvo@gmail.com>
  * @author Jeroen
  * @author Ricardo Guijt <ricardoguijt@gmail.com>
+ * @author Gerrit <klapinklapin@gmail.com>
+ * @author mprins <mprins@users.sf.net>
+ * @author Gerrit Uitslag <klapinklapin@gmail.com>
+ * @author Klap-in <klapinklapin@gmail.com>
+ * @author Remon <no@email.local>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -51,14 +56,15 @@ $lang['btn_backtomedia']       = 'Terug naar Bestandsselectie';
 $lang['btn_subscribe']         = 'Inschrijven wijzigingen';
 $lang['btn_profile']           = 'Profiel aanpassen';
 $lang['btn_reset']             = 'Wissen';
-$lang['btn_resendpwd']         = 'Stuur een nieuw wachtwoord';
+$lang['btn_resendpwd']         = 'Nieuw wachtwoord bepalen';
 $lang['btn_draft']             = 'Bewerk concept';
 $lang['btn_recover']           = 'Herstel concept';
 $lang['btn_draftdel']          = 'Verwijder concept';
 $lang['btn_revert']            = 'Herstellen';
 $lang['btn_register']          = 'Registreren';
 $lang['btn_apply']             = 'Toepassen';
-$lang['btn_media']             = 'Media beheerder';
+$lang['btn_media']             = 'Mediabeheerder';
+$lang['btn_deleteuser']        = 'Verwijder mijn account';
 $lang['loggedinas']            = 'Ingelogd als';
 $lang['user']                  = 'Gebruikersnaam';
 $lang['pass']                  = 'Wachtwoord';
@@ -70,6 +76,7 @@ $lang['fullname']              = 'Volledige naam';
 $lang['email']                 = 'E-mail';
 $lang['profile']               = 'Gebruikersprofiel';
 $lang['badlogin']              = 'Sorry, gebruikersnaam of wachtwoord onjuist';
+$lang['badpassconfirm']        = 'Sorry, het wachtwoord was onjuist';
 $lang['minoredit']             = 'Kleine wijziging';
 $lang['draftdate']             = 'Concept automatisch opgeslagen op';
 $lang['nosecedit']             = 'De pagina is tussentijds veranderd, sectie-informatie was verouderd, volledige pagina geladen.';
@@ -86,9 +93,14 @@ $lang['profna']                = 'Deze wiki ondersteunt geen profielwijzigingen'
 $lang['profnochange']          = 'Geen wijzigingen, niets gedaan';
 $lang['profnoempty']           = 'Een lege gebruikersnaam of e-mailadres is niet toegestaan';
 $lang['profchanged']           = 'Gebruikersprofiel succesvol aangepast';
+$lang['profnodelete']          = 'Deze wiki heeft biedt geen ondersteuning voor verwijdering van gebruikers';
+$lang['profdeleteuser']        = 'Verwijder gebruiker';
+$lang['profdeleted']           = 'Uw gebruikersaccount is verwijderd van deze wiki';
+$lang['profconfdelete']        = 'Ik wil mijn gebruikersaccount verwijderen van deze wiki. <br/> Deze actie kan niet ongedaan gemaakt worden.';
+$lang['profconfdeletemissing'] = 'Bevestigingsvinkje niet gezet';
 $lang['pwdforget']             = 'Je wachtwoord vergeten? Vraag een nieuw wachtwoord aan';
 $lang['resendna']              = 'Deze wiki ondersteunt het verzenden van wachtwoorden niet';
-$lang['resendpwd']             = 'Stuur een nieuw wachtwoord voor';
+$lang['resendpwd']             = 'Nieuw wachtwoord bepalen voor';
 $lang['resendpwdmissing']      = 'Sorry, je moet alle velden invullen.';
 $lang['resendpwdnouser']       = 'Sorry, we kunnen deze gebruikersnaam niet vinden in onze database.';
 $lang['resendpwdbadauth']      = 'Sorry, deze authentiecatiecode is niet geldig. Controleer of je de volledige bevestigings-link hebt gebruikt.';
@@ -101,6 +113,7 @@ $lang['searchmedia_in']        = 'Zoek in %s';
 $lang['txt_upload']            = 'Selecteer een bestand om te uploaden';
 $lang['txt_filename']          = 'Vul nieuwe naam in (optioneel)';
 $lang['txt_overwrt']           = 'Overschrijf bestaand bestand';
+$lang['maxuploadsize']         = 'Max %s per bestand';
 $lang['lockedby']              = 'Momenteel in gebruik door';
 $lang['lockexpire']            = 'Exclusief gebruiksrecht vervalt op';
 $lang['js']['willexpire']      = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nKlik op de Voorbeeld-knop om het exclusieve gebruiksrecht te verlengen.';
@@ -190,11 +203,17 @@ $lang['lastmod']               = 'Laatst gewijzigd';
 $lang['by']                    = 'door';
 $lang['deleted']               = 'verwijderd';
 $lang['created']               = 'aangemaakt';
-$lang['restored']              = 'oude revisie hersteld';
+$lang['restored']              = 'oude revisie hersteld (%s)';
 $lang['external_edit']         = 'Externe bewerking';
 $lang['summary']               = 'Samenvatting wijziging';
 $lang['noflash']               = 'De <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> is vereist om de pagina te kunnen weergeven.';
 $lang['download']              = 'Download fragment';
+$lang['tools']                 = 'Hulpmiddelen';
+$lang['user_tools']            = 'Gebruikershulpmiddelen';
+$lang['site_tools']            = 'Site-hulpmiddelen';
+$lang['page_tools']            = 'Paginahulpmiddelen';
+$lang['skip_to_content']       = 'spring naar tekst';
+$lang['sidebar']               = 'Zijbalk';
 $lang['mail_newpage']          = 'pagina toegevoegd:';
 $lang['mail_changed']          = 'pagina aangepast:';
 $lang['mail_subscribe_list']   = 'Pagina\'s veranderd in namespace:';
@@ -202,9 +221,9 @@ $lang['mail_new_user']         = 'nieuwe gebruiker:';
 $lang['mail_upload']           = 'bestand geüpload:';
 $lang['changes_type']          = 'Bekijk wijzigingen van';
 $lang['pages_changes']         = 'Pagina\'s';
-$lang['media_changes']         = 'Media bestanden';
-$lang['both_changes']          = 'Zowel pagina\'s als media bestanden';
-$lang['qb_bold']               = 'Vette tekst';
+$lang['media_changes']         = 'Mediabestanden';
+$lang['both_changes']          = 'Zowel pagina\'s als mediabestanden';
+$lang['qb_bold']               = 'Vetgedrukte tekst';
 $lang['qb_italic']             = 'Cursieve tekst';
 $lang['qb_underl']             = 'Onderstreepte tekst';
 $lang['qb_code']               = 'Code tekst';
@@ -246,10 +265,10 @@ $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Trefwoorden';
 $lang['img_width']             = 'Breedte';
 $lang['img_height']            = 'Hoogte';
-$lang['img_manager']           = 'In media beheerder bekijken';
+$lang['img_manager']           = 'In mediabeheerder bekijken';
 $lang['subscr_subscribe_success'] = '%s is ingeschreven voor %s';
 $lang['subscr_subscribe_error'] = 'Fout bij inschrijven van %s voor %s';
-$lang['subscr_subscribe_noaddress'] = 'Er is geen emailadres geassocieerd met uw account, u kunt daardoor niet worden ingeschreven.';
+$lang['subscr_subscribe_noaddress'] = 'Er is geen e-mailadres gekoppeld aan uw account, u kunt daardoor niet worden ingeschreven.';
 $lang['subscr_unsubscribe_success'] = '%s is nu uitgeschreven bij %s.';
 $lang['subscr_unsubscribe_error'] = 'Fout bij uitschrijven van %s bij %s.';
 $lang['subscr_already_subscribed'] = '%s is reeds ingeschreven bij %s.';
@@ -263,15 +282,15 @@ $lang['subscr_m_receive']      = 'Ontvang';
 $lang['subscr_style_every']    = 'Email bij iedere wijziging';
 $lang['subscr_style_digest']   = 'Samenvattings-email met wijzigingen per pagina (elke %.2f dagen)';
 $lang['subscr_style_list']     = 'Lijst van veranderde pagina\'s sinds laatste email (elke %.2f dagen)';
-$lang['authmodfailed']         = 'Ongeldige gebruikersauthenticatie-configuratie. Informeer de wikibeheerder.';
 $lang['authtempfail']          = 'Gebruikersauthenticatie is tijdelijk niet beschikbaar. Als deze situatie zich blijft voordoen, informeer dan de wikibeheerder.';
+$lang['authpwdexpire']         = 'Je wachtwoord verloopt in %d dagen, je moet het binnenkort veranderen';
 $lang['i_chooselang']          = 'Kies je taal';
 $lang['i_installer']           = 'DokuWiki Installer';
 $lang['i_wikiname']            = 'Wikinaam';
 $lang['i_enableacl']           = 'ACLs inschakelen (aanbevolen)';
 $lang['i_superuser']           = 'Superuser';
 $lang['i_problems']            = 'De installer vond problemen, hieronder aangegeven. Verhelp deze voor je doorgaat.';
-$lang['i_modified']            = 'Uit veiligheidsoverwegingen werkt dit script alleen met nieuwe en onveranderde DokuWiki-installaties. Pak de bestanden opnieuw uit of raadpleeg de <a href="http://wiki.splitbrain.org/wiki:install">Dokuwiki installatie-instructies</a>';
+$lang['i_modified']            = 'Uit veiligheidsoverwegingen werkt dit script alleen met nieuwe en onveranderde DokuWiki-installaties. Pak de bestanden opnieuw uit of raadpleeg de <a href="http://dokuwiki.org/install">Dokuwiki installatie-instructies</a>';
 $lang['i_funcna']              = 'PHP functie <code>%s</code> is niet beschikbaar. Wellicht heeft je hosting provider deze uitgeschakeld?';
 $lang['i_phpver']              = 'PHP-versie <code>%s</code> is lager dan de vereiste <code>%s</code>. Upgrade PHP.';
 $lang['i_permfail']            = '<code>%s</code> is niet schrijfbaar voor DokuWiki. Pas de permissie-instellingen van deze directory aan.';
@@ -279,14 +298,18 @@ $lang['i_confexists']          = '<code>%s</code> bestaat reeds';
 $lang['i_writeerr']            = 'Niet mogelijk om <code>%s</code> aan te maken. Controleer de directory/bestandspermissies en maak het bestand handmatig aan.';
 $lang['i_badhash']             = 'Onbekende of aangepaste dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - onjuiste of lege waarde';
-$lang['i_success']             = 'De configuratie is succesvol afgerond. Je kunt nu het bestand install.php verwijderen. Ga naar <a href="doku.php">je nieuwe DokuWiki</a>.';
-$lang['i_failure']             = 'Fouten deden zich voor tijdens het schrijven naar de configuratiebestanden. Pas deze aan voor je gebruik kunt maken van <a href="doku.php">je nieuwe DokuWiki</a>.';
+$lang['i_success']             = 'De configuratie is succesvol afgerond. Je kunt nu het bestand install.php verwijderen. Ga naar <a href="doku.php?id=wiki:welcome">je nieuwe DokuWiki</a>.';
+$lang['i_failure']             = 'Fouten deden zich voor tijdens het schrijven naar de configuratiebestanden. Pas deze aan voor je gebruik kunt maken van <a href="doku.php?id=wiki:welcome">je nieuwe DokuWiki</a>.';
 $lang['i_policy']              = 'Initieel ACL-beleid';
 $lang['i_pol0']                = 'Open wiki (lezen, schrijven, uploaden voor iedereen)';
 $lang['i_pol1']                = 'Publieke wiki (lezen voor iedereen, schrijven en uploaden voor geregistreerde gebruikers)';
 $lang['i_pol2']                = 'Besloten wiki (lezen, schrijven en uploaden alleen voor geregistreerde gebruikers)';
+$lang['i_allowreg']            = 'Toestaan dat gebruikers zichzelf registeren';
 $lang['i_retry']               = 'Opnieuw';
 $lang['i_license']             = 'Kies a.u.b. een licentie die u voor uw inhoud wilt gebruiken:';
+$lang['i_license_none']        = 'Toon geen licentie informatie';
+$lang['i_pop_field']           = 'Help ons om je DokuWiki ervaring te verbeteren';
+$lang['i_pop_label']           = 'Stuur eens per maand geanonimiseerde gebruiksstatistieken naar de Dokuwiki ontwikkelaars';
 $lang['recent_global']         = 'Je bekijkt momenteel de wijzigingen binnen de <b>%s</b> namespace. Je kunt ook de <a href="%s">recente wijzigingen van de hele wiki</a> bekijken.';
 $lang['years']                 = '%d jaar geleden';
 $lang['months']                = '%d maand geleden';
@@ -306,7 +329,7 @@ $lang['media_list_thumbs']     = 'Miniatuurweergaven';
 $lang['media_list_rows']       = 'Regels';
 $lang['media_sort_name']       = 'Naam';
 $lang['media_sort_date']       = 'Datum';
-$lang['media_namespaces']      = 'Kies naamruimte';
+$lang['media_namespaces']      = 'Kies namespace';
 $lang['media_files']           = 'Bestanden in %s';
 $lang['media_upload']          = 'Upload naar %s';
 $lang['media_search']          = 'Zoeken in %s';
@@ -319,4 +342,7 @@ $lang['media_perm_read']       = 'Sorry, u heeft niet voldoende rechten om besta
 $lang['media_perm_upload']     = 'Sorry, u heeft niet voldoende rechten om bestanden te uploaden.';
 $lang['media_update']          = 'Upload nieuwe versie';
 $lang['media_restore']         = 'Deze versie terugzetten';
-$lang['plugin_install_err']    = 'Plugin is juist geinstalleerd. Hernoem plugin map \'%s\' naar \'%s\'.';
+$lang['currentns']             = 'Huidige namespace';
+$lang['searchresult']          = 'Zoekresultaat';
+$lang['plainhtml']             = 'Alleen HTML';
+$lang['wikimarkup']            = 'Wiki Opmaak';
