@@ -1,27 +1,35 @@
 <?php
+
 /**
- * Norwegian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Reidar Mosvold <Reidar.Mosvold@hit.no>
  * @author Jorge Barrera Grandon <jorge@digitalwolves.org>
- * @author Rune Rasmussen http://www.syntaxerror.no/
+ * @author Rune Rasmussen [http://www.syntaxerror.no/]
  * @author Thomas Nygreen <nygreen@gmail.com>
  * @author Arild Burud <arildb@met.no>
  * @author Torkill Bruland <torkar-b@online.no>
  * @author Rune M. Andersen <rune.andersen@gmail.com>
- * @author Jakob Vad Nielsen (me@jakobnielsen.net)
- * @author Kjell Tore Næsgaard  <kjell.t.nasgaard@ntnu.no>
+ * @author Jakob Vad Nielsen <me@jakobnielsen.net>
+ * @author Kjell Tore Næsgaard <kjell.t.nasgaard@ntnu.no>
+ * @author Knut Staring <knutst@gmail.com>
+ * @author Lisa Ditlefsen <lisa@vervesearch.com>
+ * @author Erik Pedersen <erik.pedersen@shaw.ca>
+ * @author Rune Rasmussen syntaxerror.no@gmail.com
+ * @author Jon Bøe <jonmagneboe@hotmail.com>
+ * @author Egil Hansen <egil@rosetta.no>
+ * @author Thomas Juberg <Thomas.Juberg@Gmail.com>
+ * @author Boris <boris@newton-media.no>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '“';
-$lang['doublequoteclosing']    = '”';
+$lang['doublequoteopening']    = '«';
+$lang['doublequoteclosing']    = '»';
 $lang['singlequoteopening']    = '‘';
 $lang['singlequoteclosing']    = '’';
 $lang['apostrophe']            = '\'';
 $lang['btn_edit']              = 'Rediger denne siden';
-$lang['btn_source']            = 'Vis kildetekst';
+$lang['btn_source']            = 'Vis kildekode';
 $lang['btn_show']              = 'Vis siden';
 $lang['btn_create']            = 'Lag denne siden';
 $lang['btn_search']            = 'Søk';
@@ -42,18 +50,20 @@ $lang['btn_admin']             = 'Admin';
 $lang['btn_update']            = 'Oppdater';
 $lang['btn_delete']            = 'Slett';
 $lang['btn_back']              = 'Tilbake';
-$lang['btn_backlink']          = 'Tilbakelinker';
+$lang['btn_backlink']          = 'Tilbakelenker';
 $lang['btn_backtomedia']       = 'Tilbake til valg av mediafil';
-$lang['btn_subscribe']         = 'Abonner på endringer';
-$lang['btn_unsubscribe']       = 'Ikke abonner på endringer';
-$lang['btn_subscribens']       = 'Abonner på endringer i navnerom';
-$lang['btn_unsubscribens']     = 'Stopp abonnement på endringer i navnerom';
+$lang['btn_subscribe']         = 'Abonnér på endringer';
 $lang['btn_profile']           = 'Oppdater profil';
 $lang['btn_reset']             = 'Tilbakestill';
-$lang['btn_resendpwd']         = 'Send nytt passord';
+$lang['btn_resendpwd']         = 'Sett nytt passord';
 $lang['btn_draft']             = 'Rediger kladd';
 $lang['btn_recover']           = 'Gjennvinn kladd';
 $lang['btn_draftdel']          = 'Slett kladd';
+$lang['btn_revert']            = 'Gjenopprette';
+$lang['btn_register']          = 'Registrer deg';
+$lang['btn_apply']             = 'Bruk';
+$lang['btn_media']             = 'Mediefiler';
+$lang['btn_deleteuser']        = 'Fjern min konto';
 $lang['loggedinas']            = 'Innlogget som';
 $lang['user']                  = 'Brukernavn';
 $lang['pass']                  = 'Passord';
@@ -63,9 +73,9 @@ $lang['passchk']               = 'Bekreft passord';
 $lang['remember']              = 'Husk meg';
 $lang['fullname']              = 'Fullt navn';
 $lang['email']                 = 'E-post';
-$lang['register']              = 'Registrer deg';
 $lang['profile']               = 'Brukerprofil';
 $lang['badlogin']              = 'Ugyldig brukernavn og/eller passord.';
+$lang['badpassconfirm']        = 'Beklager, passordet var feil';
 $lang['minoredit']             = 'Mindre endringer';
 $lang['draftdate']             = 'Kladd autolagret';
 $lang['nosecedit']             = 'Siden ble endret i mellomtiden, seksjonsinfo har blitt foreldet - lastet full side istedet.';
@@ -81,24 +91,73 @@ $lang['reghere']               = 'Har du ikke en konto ennå? Lag deg en';
 $lang['profna']                = 'Denne wikien støtter ikke profilendringer';
 $lang['profnochange']          = 'Ingen endringer, ingenting å gjøre.';
 $lang['profnoempty']           = 'Tomt navn- eller e-postfelt er ikke tillatt.';
-$lang['profchanged']           = 'Brukerprofil ble vellykket oppdatert.';
-$lang['pwdforget']             = 'Glemt ditt passord? Få deg et nytt';
-$lang['resendna']              = 'Denne wikien støtter ikke nyutsending.';
-$lang['resendpwd']             = 'Send nytt passord for';
+$lang['profchanged']           = 'Brukerprofilen ble vellykket oppdatert.';
+$lang['profnodelete']          = 'Denne wikien støtter ikke sletting av brukere';
+$lang['profdeleteuser']        = 'Slett konto';
+$lang['profdeleted']           = 'Din brukerkonto har blitt slettet fra denne wikien';
+$lang['profconfdelete']        = 'Jeg ønsker å fjerne min konto fra denne wikien. <br/> Denne handlingen kan ikke omgjøres.';
+$lang['profconfdeletemissing'] = 'Boks for bekreftelse ikke avkrysset';
+$lang['pwdforget']             = 'Glemt passordet ditt? Få deg et nytt';
+$lang['resendna']              = 'Denne wikien støtter ikke nyutsending av passord.';
+$lang['resendpwd']             = 'Sett nytt passord for';
 $lang['resendpwdmissing']      = 'Beklager, du må fylle inn alle felt.';
 $lang['resendpwdnouser']       = 'Beklager, vi kan ikke finne denne brukeren i vår database.';
 $lang['resendpwdbadauth']      = 'Beklager, denne autorisasjonskoden er ikke gyldig. Sjekk at du brukte hele bekreftelseslenken.';
 $lang['resendpwdconfirm']      = 'En bekreftelseslenke er blitt sendt på e-post.';
 $lang['resendpwdsuccess']      = 'Ditt nye passord er blitt sendt på e-post.';
-$lang['license']               = 'Der annet ikke er særskilt beskrevet, er innholdet på denne wiki regulert av følgende lisens:';
-$lang['licenseok']             = 'Merk: Ved å endre på denne siden godtar du at ditt innhold blir regulert av følgende lisens:';
+$lang['license']               = 'Der annet ikke er angitt, er innholdet på denne wiki utgitt under følgende lisens:';
+$lang['licenseok']             = 'Merk: Ved å endre på denne siden godtar du at ditt innhold utgis under følgende lisens:';
+$lang['searchmedia']           = 'Søk filnavn';
+$lang['searchmedia_in']        = 'Søk i %s';
 $lang['txt_upload']            = 'Velg fil som skal lastes opp';
 $lang['txt_filename']          = 'Skriv inn wikinavn (alternativt)';
 $lang['txt_overwrt']           = 'Overskriv eksisterende fil';
-$lang['lockedby']              = 'Stengt av';
-$lang['lockexpire']            = 'Avstengningen opphører';
-$lang['willexpire']            = 'Din redigeringslås for dette dokumentet kommer snart til å opphøre.\nFor å unngå versjonskonflikter bør du forhåndsvise dokumentet ditt for å forlenge redigeringslåsen.';
-$lang['notsavedyet']           = 'Ulagrede endringer vil gå tapt.\nVil du fortsette?';
+$lang['maxuploadsize']         = 'Opplast maks % per fil.';
+$lang['lockedby']              = 'Låst av';
+$lang['lockexpire']            = 'Låsingen utløper';
+$lang['js']['willexpire']      = 'Din redigeringslås for dette dokumentet kommer snart til å utløpe.\nFor å unngå versjonskonflikter bør du forhåndsvise dokumentet ditt for å forlenge redigeringslåsen.';
+$lang['js']['notsavedyet']     = 'Ulagrede endringer vil gå tapt!
+Vil du fortsette?';
+$lang['js']['searchmedia']     = 'Søk etter filer';
+$lang['js']['keepopen']        = 'Hold vindu åpent ved valg';
+$lang['js']['hidedetails']     = 'Skjul detaljer';
+$lang['js']['mediatitle']      = 'Lenkeinnstillinger';
+$lang['js']['mediadisplay']    = 'Lenketype';
+$lang['js']['mediaalign']      = 'Justering';
+$lang['js']['mediasize']       = 'Bildestørrelse';
+$lang['js']['mediatarget']     = 'Lenkemål';
+$lang['js']['mediaclose']      = 'Lukk';
+$lang['js']['mediainsert']     = 'Sett inn';
+$lang['js']['mediadisplayimg'] = 'Vis bilde.';
+$lang['js']['mediadisplaylnk'] = 'Vis bare lenken.';
+$lang['js']['mediasmall']      = 'Liten versjon';
+$lang['js']['mediamedium']     = 'Medium versjon';
+$lang['js']['medialarge']      = 'Stor versjon';
+$lang['js']['mediaoriginal']   = 'Original versjon';
+$lang['js']['medialnk']        = 'Lenke til detaljside';
+$lang['js']['mediadirect']     = 'Direktelenke til original';
+$lang['js']['medianolnk']      = 'Ingen lenke';
+$lang['js']['medianolink']     = 'Ikke lenk bildet';
+$lang['js']['medialeft']       = 'Venstrejuster bilde';
+$lang['js']['mediaright']      = 'Høyrejuster bilde';
+$lang['js']['mediacenter']     = 'Midtstill bilde';
+$lang['js']['medianoalign']    = 'Ingen justering';
+$lang['js']['nosmblinks']      = 'Lenker til Windows-ressurser fungerer bare i Microsoft sin Internet Explorer.
+Du kan fortsatt kopiere og lime inn lenken.';
+$lang['js']['linkwiz']         = 'guide til lenker';
+$lang['js']['linkto']          = 'Lenke til:';
+$lang['js']['del_confirm']     = 'Slett denne oppføringen?';
+$lang['js']['restore_confirm'] = 'Er du sikker på at du vil gjenopprette denne versjonen?';
+$lang['js']['media_diff']      = 'Vis forskjeller:';
+$lang['js']['media_diff_both'] = 'Side ved side';
+$lang['js']['media_diff_opacity'] = 'Gjennomskinnelighet';
+$lang['js']['media_diff_portions'] = 'Glidebryter';
+$lang['js']['media_select']    = 'Velg filer…';
+$lang['js']['media_upload_btn'] = 'Last opp';
+$lang['js']['media_done_btn']  = 'Ferdig';
+$lang['js']['media_drop']      = 'Dra filer hit for å laste dem opp';
+$lang['js']['media_cancel']    = 'fjern';
+$lang['js']['media_overwrt']   = 'Erstatt eksisterende filer';
 $lang['rssfailed']             = 'En feil oppstod da denne kilden skulle hentes:';
 $lang['nothingfound']          = 'Ingen data funnet.';
 $lang['mediaselect']           = 'Valg av mediafil';
@@ -110,23 +169,20 @@ $lang['uploadexist']           = 'Filen eksisterer. Ingenting har blitt gjort.';
 $lang['uploadbadcontent']      = 'Det opplastede innholdet passer ikke til filendelsen %s.';
 $lang['uploadspam']            = 'Opplastingen ble blokkert av svartelisten for spam.';
 $lang['uploadxss']             = 'Opplastingen ble blokkert på grunn av mulig skadelig innhold.';
+$lang['uploadsize']            = 'Den opplastede filen var for stor. (max. %s)';
 $lang['deletesucc']            = 'Filen "%s" har blitt slettet.';
 $lang['deletefail']            = '"%s" kunne ikke slettes - sjekk rettighetene.';
 $lang['mediainuse']            = 'Filen "%s" har ikke biltt slettet - den er fortsatt i bruk.';
 $lang['namespaces']            = 'Navnerom';
 $lang['mediafiles']            = 'Tilgjengelige filer i';
-$lang['js']['keepopen']        = 'Hold vindu åpent ved valg';
-$lang['js']['hidedetails']     = 'Skjul detaljer';
-$lang['js']['nosmblinks']      = 'Lenker til Windows-ressurser fungerer bare i Microsoft sin Internet Explorer.
-Du kan fortsatt kopiere og lime inn lenken.';
-$lang['js']['mu_btn']          = 'Last opp flere filer samtidig';
-$lang['mediausage']            = 'Bruk følgende syntaks til å refferer til denne filen:';
+$lang['accessdenied']          = 'Du har ikke tilgang til å se denne siden';
+$lang['mediausage']            = 'Bruk følgende syntaks til å referere til denne filen:';
 $lang['mediaview']             = 'Vis original fil';
 $lang['mediaroot']             = 'rot';
 $lang['mediaupload']           = 'Last opp en fil til gjeldende navnerom her. For å opprette undernavnerom, før dem opp før filnavn i "Last opp som" adskilt med kolon.';
 $lang['mediaextchange']        = 'Filendelse endret fra .%s til .%s!';
 $lang['reference']             = 'Referanser for';
-$lang['ref_inuse']             = 'Denne filen kan ikke slettes fordi den er fortsatt i bruk av følgende sider:';
+$lang['ref_inuse']             = 'Denne filen kan ikke slettes fordi den er fortsatt i bruk på følgende sider:';
 $lang['ref_hidden']            = 'Noen referanser er på sider du ikke har tilgang til å lese';
 $lang['hits']                  = 'Treff';
 $lang['quickhits']             = 'Matchende wikinavn';
@@ -135,21 +191,37 @@ $lang['current']               = 'nåværende versjon';
 $lang['yours']                 = 'Din versjon';
 $lang['diff']                  = 'Vis forskjeller mot nåværende versjon';
 $lang['diff2']                 = 'Vis forskjeller mellom valgte versjoner';
+$lang['difflink']              = 'Lenk til denne sammenligningen';
+$lang['diff_type']             = 'Vis forskjeller:';
+$lang['diff_inline']           = 'I teksten';
+$lang['diff_side']             = 'Side ved side';
 $lang['line']                  = 'Linje';
 $lang['breadcrumb']            = 'Spor';
 $lang['youarehere']            = 'Du er her';
-$lang['lastmod']               = 'Sist modifisert';
+$lang['lastmod']               = 'Sist endret';
 $lang['by']                    = 'av';
 $lang['deleted']               = 'fjernet';
 $lang['created']               = 'opprettet';
-$lang['restored']              = 'gjenopprettet til en tidligere versjon';
+$lang['restored']              = 'gjenopprettet til en tidligere versjon (%s)';
 $lang['external_edit']         = 'ekstern redigering';
 $lang['summary']               = 'Redigeringskommentar';
+$lang['noflash']               = 'For at dette innholdet skal vises må du ha <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
+$lang['download']              = 'Last ned utdraget';
+$lang['tools']                 = 'Verktøy';
+$lang['user_tools']            = 'Brukerverktøy';
+$lang['site_tools']            = 'Nettstedverktøy';
+$lang['page_tools']            = 'Sideverktøy';
+$lang['skip_to_content']       = 'Hopp til innhold';
+$lang['sidebar']               = 'Sidefelt';
 $lang['mail_newpage']          = 'side lagt til:';
 $lang['mail_changed']          = 'side endret:';
+$lang['mail_subscribe_list']   = 'side endret i \'namespace\':';
 $lang['mail_new_user']         = 'ny bruker:';
 $lang['mail_upload']           = 'fil opplastet:';
-$lang['qb_alert']              = 'Vennligst skriv inn teksten du ønsker å formatere.\nDen vil bli lagt til mot slutten av dokumentet.';
+$lang['changes_type']          = 'Vis endringer av';
+$lang['pages_changes']         = 'Sider';
+$lang['media_changes']         = 'Mediefiler';
+$lang['both_changes']          = 'Både sider og mediefiler';
 $lang['qb_bold']               = 'Fet tekst';
 $lang['qb_italic']             = 'Kursiv tekst';
 $lang['qb_underl']             = 'Understreket tekst';
@@ -160,6 +232,11 @@ $lang['qb_h2']                 = 'Overskrift nivå 2';
 $lang['qb_h3']                 = 'Overskrift nivå 3';
 $lang['qb_h4']                 = 'Overskrift nivå 4';
 $lang['qb_h5']                 = 'Overskrift nivå 5';
+$lang['qb_h']                  = 'Overskrift';
+$lang['qb_hs']                 = 'Velg overskrift';
+$lang['qb_hplus']              = 'Høyere overskrift';
+$lang['qb_hminus']             = 'Lavere overskrift';
+$lang['qb_hequal']             = 'Overskrift på samme nivå';
 $lang['qb_link']               = 'Intern lenke';
 $lang['qb_extlink']            = 'Ekstern lenke';
 $lang['qb_hr']                 = 'Horisontal linje';
@@ -169,7 +246,7 @@ $lang['qb_media']              = 'Legg til bilder og andre filer';
 $lang['qb_sig']                = 'Føy til signatur';
 $lang['qb_smileys']            = 'Smilefjes';
 $lang['qb_chars']              = 'Spesialtegn';
-$lang['del_confirm']           = 'Slett denne oppføringen?';
+$lang['upperns']               = 'gå til overordnet navnerom';
 $lang['admin_register']        = 'Legg til ny bruker';
 $lang['metaedit']              = 'Rediger metadata';
 $lang['metasaveerr']           = 'Skriving av metadata feilet';
@@ -185,14 +262,28 @@ $lang['img_copyr']             = 'Opphavsrett';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Nøkkelord';
-$lang['subscribe_success']     = 'Lagt til %s som abonnent av listen for %s';
-$lang['subscribe_error']       = 'En feil oppstod når %s skulle legges til som abonnent av listen for %s';
-$lang['subscribe_noaddress']   = 'Det er ingen adresse assosiert med din login. Du kan dermed ikke bli lagt til som abonnent av listen.';
-$lang['unsubscribe_success']   = 'Fjernet %s som abonnent for listen %s';
-$lang['unsubscribe_error']     = 'En feil oppstod når %s skulle fjernes som abonnent fra listen for %s';
-$lang['authmodfailed']         = 'Feilkonfigurert brukerautorisasjon. Vennligst innformer Wiki-admin.';
+$lang['img_width']             = 'Bredde';
+$lang['img_height']            = 'Høyde';
+$lang['img_manager']           = 'Vis i mediefilbehandler';
+$lang['subscr_subscribe_success'] = 'La til %s som abonnent på %s';
+$lang['subscr_subscribe_error'] = 'Klarte ikke å legge til %s som abonnent på %s';
+$lang['subscr_subscribe_noaddress'] = 'Brukeren din er ikke registrert med noen adresse. Du kan derfor ikke legges til som abonnent.';
+$lang['subscr_unsubscribe_success'] = 'Avsluttet %s sitt abonnement på %s';
+$lang['subscr_unsubscribe_error'] = 'Klarte ikke å avslutte %s sitt abonnement på %s';
+$lang['subscr_already_subscribed'] = '%s abonnerer allerede på %s';
+$lang['subscr_not_subscribed'] = '%s abonnerer ikke på %s';
+$lang['subscr_m_not_subscribed'] = 'Du abonnerer ikke på denne sida eller dette navnerommet';
+$lang['subscr_m_new_header']   = 'Legg til abonnement';
+$lang['subscr_m_current_header'] = 'Gjeldende abonnementer';
+$lang['subscr_m_unsubscribe']  = 'Stoppe abonnement';
+$lang['subscr_m_subscribe']    = 'Abonnere på';
+$lang['subscr_m_receive']      = 'Motta';
+$lang['subscr_style_every']    = 'e-post for alle endringer';
+$lang['subscr_style_digest']   = 'e-post med sammendrag av endringer for hver side (%.2f dager mellom hver)';
+$lang['subscr_style_list']     = 'liste med sider som er endra siden forrige e-post (%.2f dager mellom hver)';
 $lang['authtempfail']          = 'Brukerautorisasjon er midlertidig utilgjengelig. Om dette vedvarer, vennligst informer Wiki-admin.';
-$lang['i_chooselang']          = 'Velg ditt språk';
+$lang['authpwdexpire']         = 'Ditt passord går ut om %d dager, du bør endre det snarest.';
+$lang['i_chooselang']          = 'Velg språk';
 $lang['i_installer']           = 'DokuWiki-installasjon';
 $lang['i_wikiname']            = 'Wikinavn';
 $lang['i_enableacl']           = 'Aktiver ACL (anbefalt)';
@@ -202,32 +293,58 @@ $lang['i_modified']            = 'For sikkerhets skyld vil dette skriptet bare v
                          Du bør enten pakke ut filene på nytt fra den nedlastede pakken, eller konsultere den komplette
                          <a href="http://dokuwiki.org/install">Dokuwiki-installasjonsinstruksen</a>';
 $lang['i_funcna']              = 'PHP-funksjonen <code>%s</code> er ikke tilgjengelig. Kanskje din leverandør har deaktivert den av noen grunn?';
-$lang['i_phpver']              = 'Your PHP version <code>%s</code> is lower than the needed <code>%s</code>. You need to upgrade your PHP install.';
+$lang['i_phpver']              = 'Din PHP versjon <code>%s</code> er lavere enn kravet <code>%s</code>. Du må oppgradere PHP installasjonen. ';
 $lang['i_permfail']            = '<code>%s</code> er ikke skrivbar for DokuWiki. Du må fikse rettighetene for denne mappen!';
 $lang['i_confexists']          = '<code>%s</code> eksisterer allerede';
 $lang['i_writeerr']            = 'Kunne ikke opprette <code>%s</code>. Du må sjekke mappe-/filrettigheter og opprette filen manuelt.';
 $lang['i_badhash']             = 'ikke gjenkjent eller modifisert dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - ugyldig eller tom verdi';
 $lang['i_success']             = 'Konfigurasjonen ble vellykket fullført. Du kan slette install.php filen nå. Fortsett til
-                        <a href="doku.php">din nye DokuWiki</a>.';
+                        <a href="doku.php?id=wiki:welcome">din nye DokuWiki</a>.';
 $lang['i_failure']             = 'En eller flere feil oppstod ved skriving til konfigurasjonsfilene. Du må kanskje fikse dem manuelt før
-                         du kan bruke <a href="doku.php">din nye DokuWiki</a>.';
+                         du kan bruke <a href="doku.php?id=wiki:welcome">din nye DokuWiki</a>.';
 $lang['i_policy']              = 'Innledende ACL-politikk';
 $lang['i_pol0']                = 'Åpen Wiki (les, skriv og opplasting for alle)';
 $lang['i_pol1']                = 'Offentlig Wiki (les for alle, skriving og opplasting bare for registrerte brukere)';
 $lang['i_pol2']                = 'Lukket Wiki (les, skriv og opplasting bare for registrerte brukere)';
+$lang['i_allowreg']            = 'Tillat at brukere registrerer seg selv';
 $lang['i_retry']               = 'Prøv igjen';
-$lang['mu_intro']              = 'Her kan du laste opp flere filer samtidig. Klikk på utforsk-knappen for å legge dem til i køen. Klikk på "last opp" når du er ferdig med å velge filene. ';
-$lang['mu_gridname']           = 'Filnavn';
-$lang['mu_gridsize']           = 'Størrelse';
-$lang['mu_gridstat']           = 'Status';
-$lang['mu_namespace']          = 'Navnerom (Namespace)';
-$lang['mu_browse']             = 'Utforsk';
-$lang['mu_toobig']             = 'for stor';
-$lang['mu_ready']              = 'klar for opplasting';
-$lang['mu_done']               = 'komplett';
-$lang['mu_fail']               = 'feilet';
-$lang['mu_authfail']           = 'sesjonen har utløpt';
-$lang['mu_progress']           = '@PCT@% lastet opp';
-$lang['mu_filetypes']          = 'Tillatte filtyper';
+$lang['i_license']             = 'Velg lisens som du vil legge ut innholdet under:';
+$lang['i_license_none']        = 'Ikke vis noen lisensinformasjon';
+$lang['i_pop_field']           = 'Venligst hejlp oss å forbedre Dokuwiki-opplevelsen:';
+$lang['i_pop_label']           = 'Sand annonyme bruksdata til Dokuwiki-utviklerene, en gang i måneden';
 $lang['recent_global']         = 'Du ser nå på endringene i navnerommet <b>%s</b>. Du kan også<a href="%s">se på nylig foretatte endringer for hele wikien</a>.';
+$lang['years']                 = '%d år siden';
+$lang['months']                = '%d måneder siden';
+$lang['weeks']                 = '%d uker siden';
+$lang['days']                  = '%d dager siden';
+$lang['hours']                 = '%d timer siden';
+$lang['minutes']               = '%d minutter siden';
+$lang['seconds']               = '%d sekunder siden';
+$lang['wordblock']             = 'Din endring ble ikke lagret ettersom den inneholder blokkert tekst (søppel).';
+$lang['media_uploadtab']       = 'Last opp';
+$lang['media_searchtab']       = 'Søk';
+$lang['media_file']            = 'Fil';
+$lang['media_viewtab']         = 'Vis';
+$lang['media_edittab']         = 'Rediger';
+$lang['media_historytab']      = 'Historikk';
+$lang['media_list_thumbs']     = 'Miniatyrbilder';
+$lang['media_list_rows']       = 'Rader';
+$lang['media_sort_name']       = 'etter navn';
+$lang['media_sort_date']       = 'etter dato';
+$lang['media_namespaces']      = 'Velg navnerom';
+$lang['media_files']           = 'Filer i %s';
+$lang['media_upload']          = 'Last opp til navnerommet <strong>%s</strong>.';
+$lang['media_search']          = 'Søk i navnerommet <strong>%s</strong>.';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s på %s';
+$lang['media_edit']            = 'Rediger %s';
+$lang['media_history']         = '%vis historikk';
+$lang['media_meta_edited']     = 'metadata er endra';
+$lang['media_perm_read']       = 'Beklager, du har ikke tilgang til å lese filer.';
+$lang['media_perm_upload']     = 'Beklager, du har ikke tilgang til å laste opp filer.';
+$lang['media_update']          = 'Last opp ny versjon';
+$lang['media_restore']         = 'Gjenopprett denne versjonen';
+$lang['currentns']             = 'gjeldende navnemellomrom';
+$lang['searchresult']          = 'Søk i resultat';
+$lang['plainhtml']             = 'Enkel HTML';
