@@ -1,8 +1,8 @@
 <?php
+
 /**
- * Portuguese language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author José Carlos Monteiro <jose.c.monteiro@netcabo.pt>
  * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
  * @author Enrico Nicoletto <liverig@gmail.com>
@@ -12,12 +12,11 @@
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
-$lang['doublequoteopening']    = '“';//&ldquo;
-$lang['doublequoteclosing']    = '”';//&rdquo;
-$lang['singlequoteopening']    = '‘';//&lsquo;
-$lang['singlequoteclosing']    = '’';//&rsquo;
-$lang['apostrophe']            = '’';//&rsquo;
-
+$lang['doublequoteopening']    = '“';
+$lang['doublequoteclosing']    = '”';
+$lang['singlequoteopening']    = '‘';
+$lang['singlequoteclosing']    = '’';
+$lang['apostrophe']            = '’';
 $lang['btn_edit']              = 'Editar página';
 $lang['btn_source']            = 'Ver fonte';
 $lang['btn_show']              = 'Ver página';
@@ -45,7 +44,6 @@ $lang['btn_backtomedia']       = 'Voltar à Selecção de Media';
 $lang['btn_subscribe']         = 'Subscrever Alterações';
 $lang['btn_profile']           = 'Actualizar Perfil';
 $lang['btn_reset']             = 'Limpar';
-$lang['btn_resendpwd']         = 'Enviar nova senha';
 $lang['btn_draft']             = 'Editar rascunho';
 $lang['btn_recover']           = 'Recuperar rascunho';
 $lang['btn_draftdel']          = 'Apagar rascunho';
@@ -53,7 +51,7 @@ $lang['btn_revert']            = 'Restaurar';
 $lang['btn_register']          = 'Registar';
 $lang['btn_apply']             = 'Aplicar';
 $lang['btn_media']             = 'Gestor de Media';
-
+$lang['btn_deleteuser']        = 'Remover a Minha Conta';
 $lang['loggedinas']            = 'Está em sessão como';
 $lang['user']                  = 'Utilizador';
 $lang['pass']                  = 'Senha';
@@ -68,7 +66,6 @@ $lang['badlogin']              = 'O utilizador inválido ou senha inválida.';
 $lang['minoredit']             = 'Alterações Menores';
 $lang['draftdate']             = 'Rascunho automaticamente gravado em';
 $lang['nosecedit']             = 'A página foi modificada entretanto. Como a informação da secção estava desactualizada, foi carregada a página inteira.';
-
 $lang['regmissing']            = 'Por favor, preencha todos os campos.';
 $lang['reguexists']            = 'Este utilizador já está inscrito. Por favor escolha outro nome de utilizador.';
 $lang['regsuccess']            = 'O utilizador foi criado e a senha foi enviada para o endereço de correio electrónico usado na inscrição.';
@@ -78,24 +75,22 @@ $lang['regbadmail']            = 'O endereço de correio electrónico é inváli
 $lang['regbadpass']            = 'As duas senhas não são idênticas, por favor tente de novo.';
 $lang['regpwmail']             = 'A sua senha DokuWiki';
 $lang['reghere']               = 'Para se registar, clique em';
-
 $lang['profna']                = 'Este Wiki não suporta modificações aos perfis.';
 $lang['profnochange']          = 'Nada alteração, nada a fazer.';
 $lang['profnoempty']           = 'Não são permitidos nomes ou endereços em branco.';
 $lang['profchanged']           = 'Perfil do utilizador actualizado com sucesso.';
-
+$lang['profnodelete']          = 'Esta wiki não suporta remoção de utilizadores';
+$lang['profdeleteuser']        = 'Apagar Conta';
+$lang['profdeleted']           = 'A sua conta de utilizador foi removida desta wiki';
 $lang['pwdforget']             = 'Esqueceu a sua senha? Pedir nova senha';
 $lang['resendna']              = 'Este wiki não suporta reenvio de senhas.';
-$lang['resendpwd']             = 'Enviar nova senha para';
 $lang['resendpwdmissing']      = 'É preciso preencher todos os campos.';
 $lang['resendpwdnouser']       = 'Não foi possível encontrar este utilizador.';
 $lang['resendpwdbadauth']      = 'O código de autenticação não é válido. Por favor, assegure-se de que o link de confirmação está completo.';
 $lang['resendpwdconfirm']      = 'O link de confirmação foi enviado por e-mail.';
 $lang['resendpwdsuccess']      = 'A nova senha foi enviada por e-mail.';
-
 $lang['license']               = 'Excepto menção em contrário, o conteúdo neste wiki está sob a seguinte licença:';
 $lang['licenseok']             = 'Nota: Ao editar esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
-
 $lang['searchmedia']           = 'Procurar nome de ficheiro:';
 $lang['searchmedia_in']        = 'Procurar em %s';
 $lang['txt_upload']            = 'Escolha ficheiro para carregar';
@@ -104,9 +99,7 @@ $lang['txt_overwrt']           = 'Escrever por cima do ficheiro já existente';
 $lang['lockedby']              = 'Bloqueado por';
 $lang['lockexpire']            = 'Expira em';
 $lang['js']['willexpire']      = 'O bloqueio de edição para este documento irá expirar num minuto.\nPara evitar conflitos use o botão Prever para re-iniciar o temporizador de bloqueio.';
-
 $lang['js']['notsavedyet']     = 'Alterações não gravadas serão perdidas.';
-
 $lang['js']['searchmedia']     = 'Procurar por ficheiros';
 $lang['js']['keepopen']        = 'Mantenha a janela aberta durante a selecção';
 $lang['js']['hidedetails']     = 'Esconder Detalhes';
@@ -137,6 +130,16 @@ $lang['js']['linkwiz']         = 'Assistente de Criação de Ligação';
 $lang['js']['linkto']          = 'Ligação para:';
 $lang['js']['del_confirm']     = 'Remover o(s) item(s) selecionados?';
 $lang['js']['restore_confirm'] = 'Restaurar esta versão?';
+$lang['js']['media_diff']      = 'Ver diferenças:';
+$lang['js']['media_diff_both'] = 'Lado a Lado';
+$lang['js']['media_diff_opacity'] = 'Sobreposição';
+$lang['js']['media_diff_portions'] = 'Slider';
+$lang['js']['media_select']    = 'Selecione ficheiros…';
+$lang['js']['media_upload_btn'] = 'Enviar';
+$lang['js']['media_done_btn']  = 'Feito';
+$lang['js']['media_drop']      = 'Largue ficheiros aqui para enviar';
+$lang['js']['media_cancel']    = 'remover';
+$lang['js']['media_overwrt']   = 'Escrever por cima de ficheiros existentes';
 $lang['rssfailed']             = 'Ocorreu um erro neste canal RSS: ';
 $lang['nothingfound']          = 'Nada foi encontrado.';
 $lang['mediaselect']           = 'Selecção de ficheiros';
@@ -181,20 +184,26 @@ $lang['lastmod']               = 'Esta página foi modificada pela última vez e
 $lang['by']                    = 'por';
 $lang['deleted']               = 'Documento automaticamente removido.';
 $lang['created']               = 'Criação deste novo documento.';
-$lang['restored']              = 'Versão anterior restaurada.';
+$lang['restored']              = 'Versão anterior restaurada (%s)';
 $lang['external_edit']         = 'Edição externa';
 $lang['summary']               = 'Sumário da Edição';
 $lang['noflash']               = 'O <a href="http://www.adobe.com/products/flashplayer/">Plugin Adobe Flash</a> é necessário para exibir este conteúdo.';
 $lang['download']              = 'Descarregar Snippet';
-$lang['changes_type']          = 'Ver alterações de';
-$lang['pages_changes']         = 'Páginas';
-$lang['media_changes']         = 'Ficheiros Media';
-$lang['both_changes']          = 'Tanto páginas como ficheiros media';
+$lang['tools']                 = 'Ferramentas';
+$lang['user_tools']            = 'Ferramentas de Utilizador';
+$lang['site_tools']            = 'Ferramentas de Site';
+$lang['page_tools']            = 'Ferramentas de Página';
+$lang['skip_to_content']       = 'saltar para conteúdo';
+$lang['sidebar']               = 'Barra Lateral';
 $lang['mail_newpage']          = 'documento adicionado:';
 $lang['mail_changed']          = 'documento modificado:';
 $lang['mail_subscribe_list']   = 'páginas alteradas no espaço de nome:';
 $lang['mail_new_user']         = 'Novo utilizador:';
 $lang['mail_upload']           = 'Ficheiro carregado:';
+$lang['changes_type']          = 'Ver alterações de';
+$lang['pages_changes']         = 'Páginas';
+$lang['media_changes']         = 'Ficheiros Media';
+$lang['both_changes']          = 'Tanto páginas como ficheiros media';
 $lang['qb_bold']               = 'Texto com Ênfase';
 $lang['qb_italic']             = 'Texto Itálico';
 $lang['qb_underl']             = 'Texto Sublinhado';
@@ -254,8 +263,8 @@ $lang['subscr_m_receive']      = 'Receber';
 $lang['subscr_style_every']    = 'email em qualquer alteração';
 $lang['subscr_style_digest']   = '"digest email" de alterações em cada página (cada %.2f dias)';
 $lang['subscr_style_list']     = 'lista de páginas alteradas desde o último email (cada %.2f dias)';
-$lang['authmodfailed']         = 'Configuração de autenticação errada. Por favor, informe o Wiki Admin.';
 $lang['authtempfail']          = 'Autenticação temporariamente indisponível. Se a situação persistir, por favor informe o Wiki Admin.';
+$lang['authpwdexpire']         = 'A sua senha expirará dentro de %d dias, deve mudá-la em breve.';
 $lang['i_chooselang']          = 'Escolha a linguagem';
 $lang['i_installer']           = 'Instalador do DokuWiki';
 $lang['i_wikiname']            = 'Nome Wiki';
@@ -270,14 +279,17 @@ $lang['i_confexists']          = '<code>%s</code> já existe';
 $lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É preciso verificar as permissões e criar o ficheiro manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php não é o original ou não é reconhecido (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valor ilegal ou vazio';
-$lang['i_success']             = 'A instalação e configuração inicial foram bem sucedidas. Pode remover o install.php. Aceda ao seu novo <a href="doku.php">Wiki</a> a correr o DokuWiki.';
-$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita nos ficheiros de configuração. Poderá ser preciso corrigi-los manualmente antes de poder aceder ao seu novo <a href="doku.php">Wiki</a> a correr o DokuWiki.';
+$lang['i_success']             = 'A instalação e configuração inicial foram bem sucedidas. Pode remover o install.php. Aceda ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> a correr o DokuWiki.';
+$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita nos ficheiros de configuração. Poderá ser preciso corrigi-los manualmente antes de poder aceder ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> a correr o DokuWiki.';
 $lang['i_policy']              = 'Politica ACL inicial';
 $lang['i_pol0']                = 'Wiki Aberto (ler, escrever e carregar para todos)';
 $lang['i_pol1']                = 'Wiki Público (ler para todos, escrever e carregar para utilizadores inscritos)';
 $lang['i_pol2']                = 'Wiki Fechado (ler, escrever e carregar somente para utilizadores inscritos)';
 $lang['i_retry']               = 'Repetir';
 $lang['i_license']             = 'Por favor escolha a licença sob a qual quer colocar o seu conteúdo:';
+$lang['i_license_none']        = 'Não mostrar nenhuma informação de licença';
+$lang['i_pop_field']           = 'Por favor ajude-nos a melhorar a experiência Dokuwiki:';
+$lang['i_pop_label']           = 'Uma vez por mês, enviar dados anónimos de uso para os desenvolvedores DokuWiki';
 $lang['recent_global']         = 'Você está a observar as alterações dentro do espaço de nomes <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
 $lang['years']                 = '%d anos atrás';
 $lang['months']                = '%d meses atrás';
@@ -287,36 +299,23 @@ $lang['hours']                 = '%d horas atrás';
 $lang['minutes']               = '%d minutos atrás';
 $lang['seconds']               = '%d segundos atrás';
 $lang['wordblock']             = 'A sua alteração não foi guardada porque contém texto bloqueado (spam).';
-
-$lang['media_uploadtab']  = 'Enviar';
-$lang['media_searchtab']  = 'Procurar';
-$lang['media_viewtab']    = 'Ver';
-$lang['media_edittab']    = 'Editar';
-$lang['media_historytab'] = 'Histórico';
-$lang['media_sort']       = 'Ordenar';
-$lang['media_sort_name']  = 'Ordenar por nome';
-$lang['media_sort_date']  = 'Ordenar por data';
-$lang['media_upload']     = 'Enviar para o grupo <strong>%s</strong>.';
-$lang['media_search']     = 'Procurar no grupo <strong>%s</strong>.';
-$lang['media_view']       = '%s';
-$lang['media_edit']       = 'Editar %s';
-$lang['media_history']    = 'Histórico do %s';
-$lang['media_meta_edited']= 'metadata editada';
-$lang['media_perm_read']  = 'Perdão, não tem permissão para ler ficheiros.';
-$lang['media_perm_upload']= 'Perdão, não tem permissão para enviar ficheiros.';
-$lang['media_update']     = 'enviar nova versão';
-$lang['media_restore']    = 'Restaurar esta versão';
-
-$lang['js']['media_diff']          = 'Ver diferenças:';
-$lang['js']['media_diff_both']     = 'Lado a Lado';
-$lang['js']['media_diff_opacity']  = 'Sobreposição';
-$lang['js']['media_diff_portions'] = 'Slider'; // Needs translation. 'Deslizador' ?
-
-$lang['js']['media_select']     = 'Selecione ficheiros…';
-$lang['js']['media_upload_btn'] = 'Enviar';
-$lang['js']['media_done_btn']   = 'Feito';
-$lang['js']['media_drop']       = 'Largue ficheiros aqui para enviar';
-$lang['js']['media_cancel']     = 'remover';
-$lang['js']['media_overwrt']    = 'Escrever por cima de ficheiros existentes';
-
-$lang['plugin_install_err'] = "Plugin instalado incorrectamente. Renomeie a pasta do plugin de '%s' para '%s'.";
+$lang['media_uploadtab']       = 'Enviar';
+$lang['media_searchtab']       = 'Procurar';
+$lang['media_file']            = 'Ficheiro';
+$lang['media_viewtab']         = 'Ver';
+$lang['media_edittab']         = 'Editar';
+$lang['media_historytab']      = 'Histórico';
+$lang['media_list_rows']       = 'Linhas';
+$lang['media_sort_name']       = 'Ordenar por nome';
+$lang['media_sort_date']       = 'Ordenar por data';
+$lang['media_files']           = 'Ficheiros em %s';
+$lang['media_upload']          = 'Enviar para o grupo <strong>%s</strong>.';
+$lang['media_search']          = 'Procurar no grupo <strong>%s</strong>.';
+$lang['media_view']            = '%s';
+$lang['media_edit']            = 'Editar %s';
+$lang['media_history']         = 'Histórico do %s';
+$lang['media_meta_edited']     = 'metadata editada';
+$lang['media_perm_read']       = 'Perdão, não tem permissão para ler ficheiros.';
+$lang['media_perm_upload']     = 'Perdão, não tem permissão para enviar ficheiros.';
+$lang['media_update']          = 'enviar nova versão';
+$lang['media_restore']         = 'Restaurar esta versão';
