@@ -1,8 +1,8 @@
 <?php
+
 /**
- * Russian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Yuri Pimenov <up@ftpsearch.lv>
  * @author Igor Tarasov <tigr@mail15.com>
  * @author Denis Simakov <akinoame1@gmail.com>
@@ -21,6 +21,8 @@
  * @author Eugene <windy.wanderer@gmail.com>
  * @author Johnny Utah <pcpa@cyberpunk.su>
  * @author Ivan I. Udovichenko (sendtome@mymailbox.pp.ua)
+ * @author Pavel <ivanovtsk@mail.ru>
+ * @author Artur <ncuxxx@gmail.com>
  */
 $lang['encoding']              = ' utf-8';
 $lang['direction']             = 'ltr';
@@ -63,7 +65,8 @@ $lang['btn_draftdel']          = 'Удалить черновик';
 $lang['btn_revert']            = 'Восстановить';
 $lang['btn_register']          = 'Зарегистрироваться';
 $lang['btn_apply']             = 'Применить';
-$lang['btn_media']             = 'Media Manager';
+$lang['btn_media']             = 'Управление медиафайлами';
+$lang['btn_deleteuser']        = 'Удалить мой аккаунт';
 $lang['loggedinas']            = 'Зашли как';
 $lang['user']                  = 'Логин';
 $lang['pass']                  = 'Пароль';
@@ -75,12 +78,13 @@ $lang['fullname']              = 'Полное имя';
 $lang['email']                 = 'Эл. адрес';
 $lang['profile']               = 'Профиль пользователя';
 $lang['badlogin']              = 'Извините, неверное имя пользователя или пароль.';
+$lang['badpassconfirm']        = 'Простите, пароль неверный';
 $lang['minoredit']             = 'Небольшие изменения';
 $lang['draftdate']             = 'Черновик сохранён';
 $lang['nosecedit']             = 'За это время страница была изменена и информация о секции устарела. Загружена полная версия страницы.';
 $lang['regmissing']            = 'Извините, вам следует заполнить все поля.';
 $lang['reguexists']            = 'Извините, пользователь с таким логином уже существует.';
-$lang['regsuccess']            = 'Пользователь создан, пароль выслан на адрес электронной почты.';
+$lang['regsuccess']            = 'Пользователь создан; пароль выслан на адрес электронной почты.';
 $lang['regsuccess2']           = 'Пользователь создан.';
 $lang['regmailfail']           = 'Похоже есть проблема с отправкой пароля по почте. Пожалуйста, сообщите об этом администратору.';
 $lang['regbadmail']            = 'Данный вами адрес электронной почты выглядит неправильным. Если вы считаете это ошибкой, сообщите администратору.';
@@ -91,6 +95,11 @@ $lang['profna']                = 'Данная вики не поддержив
 $lang['profnochange']          = 'Изменений не было внесено, профиль не обновлён.';
 $lang['profnoempty']           = 'Логин и адрес электронной почты не могут быть пустыми.';
 $lang['profchanged']           = 'Профиль пользователя успешно обновлён.';
+$lang['profnodelete']          = 'Удалённый пользователь не может работать с этим документом';
+$lang['profdeleteuser']        = 'Удалить аккаунт';
+$lang['profdeleted']           = 'Ваш аккаунт был удален из этой вики';
+$lang['profconfdelete']        = 'Я хочу удалить мой аккаунт из этой вики.<br />Это действие необратимо.';
+$lang['profconfdeletemissing'] = 'Флажок подтверждения не установлен';
 $lang['pwdforget']             = 'Забыли пароль? Получите новый';
 $lang['resendna']              = 'Данная вики не поддерживает повторную отправку пароля.';
 $lang['resendpwd']             = 'Установить новый пароль для';
@@ -109,7 +118,7 @@ $lang['txt_overwrt']           = 'Перезаписать существующ
 $lang['maxuploadsize']         = 'Максимальный размер загружаемого файла %s';
 $lang['lockedby']              = 'В данный момент заблокирован';
 $lang['lockexpire']            = 'Блокировка истекает в';
-$lang['js']['willexpire']      = 'Ваша блокировка этой страницы на редактирование истекает в течении минуты.\nЧтобы предотвратить конфликты используйте кнопку "Просмотр" для сброса таймера блокировки.';
+$lang['js']['willexpire']      = 'Ваша блокировка этой страницы на редактирование истекает в течение минуты.\nЧтобы предотвратить конфликты используйте кнопку «Просмотр» для сброса таймера блокировки.';
 $lang['js']['notsavedyet']     = 'Несохранённые изменения будут потеряны. Вы действительно хотите продолжить?';
 $lang['js']['searchmedia']     = 'Поиск файлов';
 $lang['js']['keepopen']        = 'Не закрывать окно после выбора';
@@ -141,8 +150,8 @@ $lang['js']['linkto']          = 'Ссылка на:';
 $lang['js']['del_confirm']     = 'Вы на самом деле желаете удалить выбранное?';
 $lang['js']['restore_confirm'] = 'Действительно восстановить эту версию?';
 $lang['js']['media_diff']      = 'Просмотр отличий:';
-$lang['js']['media_diff_both'] = 'Рядом';
-$lang['js']['media_diff_opacity'] = 'Наложением';
+$lang['js']['media_diff_both'] = 'рядом';
+$lang['js']['media_diff_opacity'] = 'наложением';
 $lang['js']['media_diff_portions'] = 'Частями';
 $lang['js']['media_select']    = 'Выбрать файлы…';
 $lang['js']['media_upload_btn'] = 'Загрузить';
@@ -162,9 +171,9 @@ $lang['uploadbadcontent']      = 'Содержание файла не соот
 $lang['uploadspam']            = 'Загрузка заблокирована спам-фильтром.';
 $lang['uploadxss']             = 'Загрузка заблокирована по соображениям безопасности.';
 $lang['uploadsize']            = 'Загруженный файл был слишком большой. (макс. %s)';
-$lang['deletesucc']            = 'Файл "%s" был удалён.';
-$lang['deletefail']            = 'Невозможно удалить файл "%s". Проверьте права доступа к файлу.';
-$lang['mediainuse']            = 'Файл "%s" не был удалён — файл всё ещё используется.';
+$lang['deletesucc']            = 'Файл «%s» был удалён.';
+$lang['deletefail']            = 'Невозможно удалить файл «%s». Проверьте права доступа к файлу.';
+$lang['mediainuse']            = 'Файл «%s» не был удалён — файл всё ещё используется.';
 $lang['namespaces']            = 'Пространства имён';
 $lang['mediafiles']            = 'Доступные файлы';
 $lang['accessdenied']          = 'Вы не можете просмотреть эту страницу.';
@@ -185,8 +194,8 @@ $lang['diff']                  = 'показать отличия от теку
 $lang['diff2']                 = 'Показать различия между ревизиями  ';
 $lang['difflink']              = 'Ссылка на это сравнение';
 $lang['diff_type']             = 'Посмотреть отличия';
-$lang['diff_inline']           = 'Встроенный';
-$lang['diff_side']             = 'Бок о бок';
+$lang['diff_inline']           = 'встроенный';
+$lang['diff_side']             = 'бок о бок';
 $lang['line']                  = 'Строка';
 $lang['breadcrumb']            = 'Вы посетили';
 $lang['youarehere']            = 'Вы находитесь здесь';
@@ -204,16 +213,16 @@ $lang['user_tools']            = 'Инструменты пользовател
 $lang['site_tools']            = 'Инструменты сайта';
 $lang['page_tools']            = 'Инструменты страницы';
 $lang['skip_to_content']       = 'Перейти к содержанию';
-$lang['sidebar']               = 'Боковая колонна';
+$lang['sidebar']               = 'Боковая панель';
 $lang['mail_newpage']          = 'страница добавлена:';
 $lang['mail_changed']          = 'страница изменена:';
 $lang['mail_subscribe_list']   = 'изменились страницы в пространстве имён:';
 $lang['mail_new_user']         = 'новый пользователь:';
 $lang['mail_upload']           = 'файл закачан:';
 $lang['changes_type']          = 'Посмотреть изменения';
-$lang['pages_changes']         = 'Страниц';
-$lang['media_changes']         = 'Медиа файлов';
-$lang['both_changes']          = 'И страниц и медиа файлов';
+$lang['pages_changes']         = 'страниц';
+$lang['media_changes']         = 'медиафайлов';
+$lang['both_changes']          = 'и страниц, и медиафайлов';
 $lang['qb_bold']               = 'Полужирный';
 $lang['qb_italic']             = 'Курсив';
 $lang['qb_underl']             = 'Подчёркнутый';
@@ -234,7 +243,7 @@ $lang['qb_extlink']            = 'Внешняя ссылка';
 $lang['qb_hr']                 = 'Разделитель';
 $lang['qb_ol']                 = 'Элемент нумерованного списка';
 $lang['qb_ul']                 = 'Элемент ненумерованного списка';
-$lang['qb_media']              = 'Добавить изображения или другие файлы';
+$lang['qb_media']              = 'Добавить изображения или другие файлы (откроется в новом окне)';
 $lang['qb_sig']                = 'Вставить подпись';
 $lang['qb_smileys']            = 'Смайлики';
 $lang['qb_chars']              = 'Специальные символы';
@@ -256,7 +265,7 @@ $lang['img_camera']            = 'Модель';
 $lang['img_keywords']          = 'Ключевые слова';
 $lang['img_width']             = 'Ширина';
 $lang['img_height']            = 'Высота';
-$lang['img_manager']           = 'Просмотр в media manager';
+$lang['img_manager']           = 'Просмотр в «управлении медиафайлами»';
 $lang['subscr_subscribe_success'] = 'Добавлен %s в подписку на %s';
 $lang['subscr_subscribe_error'] = 'Невозможно добавить %s в подписку на %s';
 $lang['subscr_subscribe_noaddress'] = 'Нет адреса электронной почты, сопоставленного с вашей учётной записью. Вы не можете подписаться на рассылку';
@@ -271,9 +280,8 @@ $lang['subscr_m_unsubscribe']  = 'Отменить подписку';
 $lang['subscr_m_subscribe']    = 'Подписаться';
 $lang['subscr_m_receive']      = 'Получить';
 $lang['subscr_style_every']    = 'уведомлять о каждом изменении';
-$lang['subscr_style_digest']   = 'информационное электронное письмо со списком изменений для каждоый страницы (каждые %.2f дней)';
+$lang['subscr_style_digest']   = 'информационное электронное письмо со списком изменений для каждой страницы (каждые %.2f дней)';
 $lang['subscr_style_list']     = 'список изменённых страниц со времени последнего отправленного электронного письма (каждые %.2f дней)';
-$lang['authmodfailed']         = 'Неправильная конфигурация аутентификации пользователя. Пожалуйста, сообщите об этом своему администратору вики.';
 $lang['authtempfail']          = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом своему администратору вики.';
 $lang['authpwdexpire']         = 'Действие вашего пароля истекает через %d дней. Вы должны изменить его как можно скорее';
 $lang['i_chooselang']          = 'Выберите свой язык/Choose your language';
@@ -302,8 +310,8 @@ $lang['i_pol2']                = 'Закрытая вики (чтение, за
 $lang['i_retry']               = 'Повторить попытку';
 $lang['i_license']             = 'Пожалуйста, выберите тип лицензии для своей вики:';
 $lang['i_license_none']        = 'Не отображать информацию о лицензионных операциях';
-$lang['i_pop_field']           = 'Пожалуйста, помогите нам улучшить DokuWiki:';
-$lang['i_pop_label']           = 'Отправлять раз в месяц анонимную пользовательскую информацию разработчикам DokuWiki';
+$lang['i_pop_field']           = 'Пожалуйста, помогите нам улучшить «ДокуВики»:';
+$lang['i_pop_label']           = 'Отправлять раз в месяц анонимную пользовательскую информацию разработчикам «ДокуВики»';
 $lang['recent_global']         = 'Вы просматриваете изменения в пространстве имён <b>%s</b>. Вы можете также <a href="%s">просмотреть недавние изменения во всей вики</a>.';
 $lang['years']                 = '%d лет назад';
 $lang['months']                = '%d месяц(ев) назад';
@@ -333,7 +341,7 @@ $lang['media_viewold']         = '%s в %s
 $lang['media_edit']            = 'Правка %s';
 $lang['media_history']         = 'История %s';
 $lang['media_meta_edited']     = 'метаданные изменены';
-$lang['media_perm_read']       = 'Извините, у Вас недостаточно прав для чтения файлов.';
-$lang['media_perm_upload']     = 'Извините, у Вас недостаточно прав для загрузки файлов.';
+$lang['media_perm_read']       = 'Извините, у вас недостаточно прав для чтения файлов.';
+$lang['media_perm_upload']     = 'Извините, у вас недостаточно прав для загрузки файлов.';
 $lang['media_update']          = 'Загрузить новую версию';
 $lang['media_restore']         = 'Восстановить эту версию';
