@@ -1,8 +1,8 @@
 <?php
+
 /**
- * Slovak language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Ondrej Vegh <ov@vsieti.sk> with help of the scholars from Zdruzena stredna skola polygraficka in Bratislava
  * @author Michal Mesko <michal.mesko@gmail.com>
  * @author exusik@gmail.com
@@ -42,7 +42,7 @@ $lang['btn_backtomedia']       = 'Späť na výber súboru';
 $lang['btn_subscribe']         = 'Sledovať zmeny';
 $lang['btn_profile']           = 'Aktualizovať profil';
 $lang['btn_reset']             = 'Zrušiť';
-$lang['btn_resendpwd']         = 'Poslať nové heslo';
+$lang['btn_resendpwd']         = 'Nastaviť nové heslo';
 $lang['btn_draft']             = 'Upraviť koncept';
 $lang['btn_recover']           = 'Obnoviť koncept';
 $lang['btn_draftdel']          = 'Zmazať koncept';
@@ -50,6 +50,7 @@ $lang['btn_revert']            = 'Obnoviť';
 $lang['btn_register']          = 'Registrovať';
 $lang['btn_apply']             = 'Použiť';
 $lang['btn_media']             = 'Správa médií';
+$lang['btn_deleteuser']        = 'Zrušiť môj účet';
 $lang['loggedinas']            = 'Prihlásený(á) ako';
 $lang['user']                  = 'Užívateľské meno';
 $lang['pass']                  = 'Heslo';
@@ -61,6 +62,7 @@ $lang['fullname']              = 'Celé meno';
 $lang['email']                 = 'E-Mail';
 $lang['profile']               = 'Užívateľský profil';
 $lang['badlogin']              = 'Zadané užívateľské meno a heslo nie je správne.';
+$lang['badpassconfirm']        = 'Ľutujem, heslo bolo nesprávne.';
 $lang['minoredit']             = 'Menšie zmeny';
 $lang['draftdate']             = 'Koncept automaticky uložený';
 $lang['nosecedit']             = 'Stránka bola medzičasom zmenená, informácie o sekcii sú zastaralé a z tohto dôvodu bola nahraná celá stránka.';
@@ -77,9 +79,14 @@ $lang['profna']                = 'Táto wiki nepodporuje zmenu profilu';
 $lang['profnochange']          = 'Žiadne zmeny, nie je čo robiť.';
 $lang['profnoempty']           = 'Prázdne meno alebo mailová adresa nie sú povolené.';
 $lang['profchanged']           = 'Užívateľský účet úspešne zmenený.';
+$lang['profnodelete']          = 'Táto wiki neumožňuje zrušenie používateľov.';
+$lang['profdeleteuser']        = 'Zrušiť účet';
+$lang['profdeleted']           = 'Váš účet bol zrušený v tejto wiki.';
+$lang['profconfdelete']        = 'Chcem odstrániť môj účet z tejto wiki. <br/> Táto operácia je nevratná.';
+$lang['profconfdeletemissing'] = 'Nebolo zavolené potvrdzovacie políčko';
 $lang['pwdforget']             = 'Zabudli ste heslo? Získajte nové!';
 $lang['resendna']              = 'Táto wiki nepodporuje opätovné zasielanie hesla.';
-$lang['resendpwd']             = 'Pošli nové heslo pre';
+$lang['resendpwd']             = 'Nastaviť nové heslo pre';
 $lang['resendpwdmissing']      = 'Prepáčte, musíte vyplniť všetky polia.';
 $lang['resendpwdnouser']       = 'Prepáčte, nemôžeme nájsť zadaného užívateľa v databáze.';
 $lang['resendpwdbadauth']      = 'Prepáčte, tento autorizačný kód nie je platný. Uistite sa, či ste použili celý autorizačný odkaz.';
@@ -92,6 +99,7 @@ $lang['searchmedia_in']        = 'Hľadať v %s';
 $lang['txt_upload']            = 'Vyberte súbor ako prílohu';
 $lang['txt_filename']          = 'Uložiť ako (voliteľné)';
 $lang['txt_overwrt']           = 'Prepísať existujúci súbor';
+$lang['maxuploadsize']         = 'Obmedzenie max. %s na súbor.';
 $lang['lockedby']              = 'Práve zamknuté:';
 $lang['lockexpire']            = 'Zámok stratí platnosť:';
 $lang['js']['willexpire']      = 'Váš zámok pre editáciu za chvíľu stratí platnosť.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';
@@ -181,11 +189,17 @@ $lang['lastmod']               = 'Posledná úprava';
 $lang['by']                    = 'od';
 $lang['deleted']               = 'odstránené';
 $lang['created']               = 'vytvorené';
-$lang['restored']              = 'stará verzia bola obnovená';
+$lang['restored']              = 'stará verzia bola obnovená (%s)';
 $lang['external_edit']         = 'externá úprava';
 $lang['summary']               = 'Komentár k úpravám';
 $lang['noflash']               = 'Pre zobrazenie tohto obsahu potrebujete <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
 $lang['download']              = 'Stiahnuť';
+$lang['tools']                 = 'Nástroje';
+$lang['user_tools']            = 'Nástroje používateľa';
+$lang['site_tools']            = 'Nástoje správy stránok';
+$lang['page_tools']            = 'Nástoje stránky';
+$lang['skip_to_content']       = 'skok na obsah';
+$lang['sidebar']               = 'Bočný panel';
 $lang['mail_newpage']          = 'stránka pridaná:';
 $lang['mail_changed']          = 'stránka zmenená:';
 $lang['mail_subscribe_list']   = 'stránky zmenené v mennom priestore:';
@@ -254,8 +268,8 @@ $lang['subscr_m_receive']      = 'Dostávať';
 $lang['subscr_style_every']    = 'email pri každej zmene';
 $lang['subscr_style_digest']   = 'email so zhrnutím zmien pre každú stránku (perióda %.2f dňa)';
 $lang['subscr_style_list']     = 'zoznam zmenených stránok od posledného emailu (perióda %.2f dňa)';
-$lang['authmodfailed']         = 'Užívateľská autentifikácia nie je možná. Prosím informujte správcu systému.';
 $lang['authtempfail']          = 'Užívateľská autentifikácia je dočasne nedostupná. Ak táto situácia pretrváva, prosím informujte správcu systému.';
+$lang['authpwdexpire']         = 'Platnosť hesla vyprší za %d dní, mali by ste ho zmeniť čo najskôr.';
 $lang['i_chooselang']          = 'Zvoľte váš jazyk';
 $lang['i_installer']           = 'DokuWiki inštalátor';
 $lang['i_wikiname']            = 'Názov Wiki';
@@ -270,14 +284,17 @@ $lang['i_confexists']          = '<code>%s</code> už existuje';
 $lang['i_writeerr']            = 'Nie je možné vytvoriť <code>%s</code>. Potrebujete skontrolovať prístupové práva pre adresár/súbor a vytvoriť ho manuálne.';
 $lang['i_badhash']             = 'neznámy alebo zmenený súbor dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - nesprávna alebo žiadna hodnota';
-$lang['i_success']             = 'Konfigurácia bola úspešne ukončená. Teraz môžete zmazať súbor install.php. Pokračujte vo <a href="doku.php">vašej novej DokuWiki</a>.';
-$lang['i_failure']             = 'Pri zápise konfiguračného súboru nastali nejaké chyby. Potrebujete ich opraviť manuálne pred tým, ako budete môcť používať <a href="doku.php">vašu novú DokuWiki</a>.';
+$lang['i_success']             = 'Konfigurácia bola úspešne ukončená. Teraz môžete zmazať súbor install.php. Pokračujte vo <a href="doku.php?id=wiki:welcome">vašej novej DokuWiki</a>.';
+$lang['i_failure']             = 'Pri zápise konfiguračného súboru nastali nejaké chyby. Potrebujete ich opraviť manuálne pred tým, ako budete môcť používať <a href="doku.php?id=wiki:welcome">vašu novú DokuWiki</a>.';
 $lang['i_policy']              = 'Počiatočná ACL politika';
 $lang['i_pol0']                = 'Otvorená Wiki (čítanie, zápis a nahrávanie pre každého)';
 $lang['i_pol1']                = 'Verejná Wiki (čítanie pre každého, zápis a nahrávanie pre registrovaných užívateľov)';
 $lang['i_pol2']                = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných užívateľov)';
 $lang['i_retry']               = 'Skúsiť znovu';
 $lang['i_license']             = 'Vyberte licenciu, pod ktorou chcete uložiť váš obsah:';
+$lang['i_license_none']        = 'Nezobrazovať žiadne licenčné informácie';
+$lang['i_pop_field']           = 'Prosím pomôžte nám zlepšiť prácu s DokuWiki:';
+$lang['i_pop_label']           = 'Raz mesačne zaslať anonymné údaje vývojárom DokuWiki';
 $lang['recent_global']         = 'Práve prehliadate zmeny v mennom priestore <b>%s</b>. Môžete si tiež pozrieť <a href="%s">aktuálne zmeny celej wiki</a>.';
 $lang['years']                 = 'pred %d rokmi';
 $lang['months']                = 'pred %d mesiacmi';
@@ -310,4 +327,7 @@ $lang['media_perm_read']       = 'Prepáčte, ale nemáte dostatočné oprávnen
 $lang['media_perm_upload']     = 'Prepáčte, ale nemáte dostatočné oprávnenie na nahrávanie súborov.';
 $lang['media_update']          = 'Nahrať novú verziu';
 $lang['media_restore']         = 'Obnoviť túto verziu';
-$lang['plugin_install_err']    = 'Plugin nebol nainštalovaný úspešne. Premenujte adresár s pluginom \'%s\' na \'%s\'.';
+$lang['currentns']             = 'Aktuálny menný priestor';
+$lang['searchresult']          = 'Výsledky hľadania';
+$lang['plainhtml']             = 'Jednoduché HTML';
+$lang['wikimarkup']            = 'Wiki formát';
