@@ -4,7 +4,8 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Filip Brcic <brcha@users.sourceforge.net>
- * @author Иван Петровић petrovicivan@ubuntusrbija.org
+ * @author Иван Петровић (Ivan Petrovic) <petrovicivan@ubuntusrbija.org>
+ * @author Miroslav Šolti <solti.miroslav@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -36,31 +37,29 @@ $lang['btn_update']            = 'Ажурирај';
 $lang['btn_delete']            = 'Избриши';
 $lang['btn_back']              = 'Натраг';
 $lang['btn_backlink']          = 'Повратне везе';
-$lang['btn_backtomedia']       = 'Врати се на избор медијског фајла';
+$lang['btn_backtomedia']       = 'Врати се на избор медијске датотеке';
 $lang['btn_subscribe']         = 'Пријави се на измене';
-$lang['btn_unsubscribe']       = 'Одјави се са измена';
-$lang['btn_subscribens']       = 'Претплати се на промене у именском простору';
-$lang['btn_unsubscribens']     = 'Откажи претплату на промене у именском простору';
 $lang['btn_profile']           = 'Ажурирај профил';
 $lang['btn_reset']             = 'Поништи';
-$lang['btn_resendpwd']         = 'Пошаљи нову лозинку';
 $lang['btn_draft']             = 'Измени нацрт';
 $lang['btn_recover']           = 'Опорави нацрт';
 $lang['btn_draftdel']          = 'Обриши нацрт';
+$lang['btn_revert']            = 'Врати на пређашњу верзију';
+$lang['btn_register']          = 'Региструј се';
 $lang['loggedinas']            = 'Пријављен као';
 $lang['user']                  = 'Корисничко име';
-$lang['pass']                  = 'Шифра';
+$lang['pass']                  = 'Лозинка';
 $lang['newpass']               = 'Нова лозинка';
 $lang['oldpass']               = 'Потврди нову лозинку';
 $lang['passchk']               = 'поново';
 $lang['remember']              = 'Запамти ме';
-$lang['fullname']              = 'Пуно име';
+$lang['fullname']              = 'Име и презиме';
 $lang['email']                 = 'Е-адреса';
-$lang['register']              = 'Региструј се';
 $lang['profile']               = 'Кориснички профил';
 $lang['badlogin']              = 'Извините, није добро корисничко име или шифра.';
 $lang['minoredit']             = 'Мала измена';
 $lang['draftdate']             = 'Нацрт је аутоматски сачуван';
+$lang['nosecedit']             = 'Страна је у међувремену промењена, поглавље је застарело и поново се учитава цела страна.';
 $lang['regmissing']            = 'Извините, морате да попуните сва поља.';
 $lang['reguexists']            = 'Извините, корисник са истим именом већ постоји.';
 $lang['regsuccess']            = 'Корисник је направљен и лозинка је послата путем е-поште.';
@@ -76,19 +75,52 @@ $lang['profnoempty']           = 'Није дозвољено оставити 
 $lang['profchanged']           = 'Кориснички профил је ажуриран.';
 $lang['pwdforget']             = 'Заборавили сте лозинку? Направите нову';
 $lang['resendna']              = 'Овај вики не дозвољава слање лозинки.';
-$lang['resendpwd']             = 'Пошаљи нову лозинку за';
 $lang['resendpwdmissing']      = 'Жао ми је, сва поља морају бити попуњена.';
 $lang['resendpwdnouser']       = 'Жао ми је, овај корисник не постоји у нашој бази.';
 $lang['resendpwdbadauth']      = 'Жао ми је, потврдни код није исправан. Проверите да ли сте користили комплетан потврдни линк.';
 $lang['resendpwdconfirm']      = 'Потврдни линк је постат као е-порука.';
 $lang['resendpwdsuccess']      = 'Ваша нова лозинка је послата као е-порука.';
+$lang['license']               = 'Осим где је другачије назначено, материјал на овом викију је под следећом лиценцом:';
+$lang['licenseok']             = 'Напомена: Изменом ове стране слажете се да ће ваше измене бити под следећом лиценцом:';
+$lang['searchmedia']           = 'Претражи по имену фајла';
+$lang['searchmedia_in']        = 'Претражи у %s';
 $lang['txt_upload']            = 'Изаберите датотеку за слање';
 $lang['txt_filename']          = 'Унесите вики-име (опционо)';
 $lang['txt_overwrt']           = 'Препишите тренутни фајл';
 $lang['lockedby']              = 'Тренутно закључано од стране';
 $lang['lockexpire']            = 'Закључавање истиче';
-$lang['willexpire']            = 'Ваше закључавање за измену ове странице ће да истекне за један минут.\nДа би сте избегли конфликте, искористите дугме за преглед како би сте ресетовали тајмер закључавања.';
-$lang['notsavedyet']           = 'Несачуване измене ће бити изгубљене.\nДа ли стварно желите да наставите?';
+$lang['js']['willexpire']            = 'Ваше закључавање за измену ове странице ће да истекне за један минут.\nДа би сте избегли конфликте, искористите дугме за преглед како би сте ресетовали тајмер закључавања.';
+$lang['js']['notsavedyet']     = 'Несачуване измене ће бити изгубљене.
+Да ли стварно желите да наставите?';
+$lang['js']['searchmedia']     = 'Потражи фајлове';
+$lang['js']['keepopen']        = 'Задржи отворен прозор након одабира';
+$lang['js']['hidedetails']     = 'Сакриј детаље';
+$lang['js']['mediatitle']      = 'Подешаванја везе';
+$lang['js']['mediadisplay']    = 'Тип везе';
+$lang['js']['mediaalign']      = 'Поравнање';
+$lang['js']['mediasize']       = 'Величина слике';
+$lang['js']['mediatarget']     = 'веза води ка:';
+$lang['js']['mediaclose']      = 'Затвори';
+$lang['js']['mediainsert']     = 'Убаци';
+$lang['js']['mediadisplayimg'] = 'Покажи слику';
+$lang['js']['mediadisplaylnk'] = 'Покажи само везу';
+$lang['js']['mediasmall']      = 'Мала верзија';
+$lang['js']['mediamedium']     = 'Средња верзија';
+$lang['js']['medialarge']      = 'Велика верзија';
+$lang['js']['mediaoriginal']   = 'Оригинална верзија';
+$lang['js']['medialnk']        = 'Веза ка страници са детаљима';
+$lang['js']['mediadirect']     = 'Директна веза ка оригиналу';
+$lang['js']['medianolnk']      = 'Без везе';
+$lang['js']['medianolink']     = 'Не постављај слику као везу';
+$lang['js']['medialeft']       = 'Поравнај слику на лево';
+$lang['js']['mediaright']      = 'Поравнај слику на десно';
+$lang['js']['mediacenter']     = 'Поравнај слику по средини';
+$lang['js']['medianoalign']    = 'Без поравнања';
+$lang['js']['nosmblinks']      = 'Повезивање са Windows дељеним фолдерима ради само у Мајкрософтовом Интернет Претраживачу.
+Ипак, можете да ископирате и залепите везу.';
+$lang['js']['linkwiz']         = 'Чаробњак за стварање везе';
+$lang['js']['linkto']          = 'Повежи ка:';
+$lang['js']['del_confirm']     = 'Обриши овај унос?';
 $lang['rssfailed']             = 'Дошло је до грешке приликом преузимања овог довода: ';
 $lang['nothingfound']          = 'Ништа није нађено.';
 $lang['mediaselect']           = 'Избор медијске датотеке';
@@ -100,13 +132,13 @@ $lang['uploadexist']           = 'Датотека већ постоји. Ниш
 $lang['uploadbadcontent']      = 'Материјал који шаљете не одговара %s ';
 $lang['uploadspam']            = 'Слање је блокирано јер се налазите на црној листи пошиљаоца.';
 $lang['uploadxss']             = 'Слање је блокирано јер је потенцијално малициозног садржаја.';
+$lang['uploadsize']            = 'Послата датотека је превелика. (максимум је %s)';
 $lang['deletesucc']            = 'Фајл "%s" је избрисан.';
 $lang['deletefail']            = '"%s" није могао да буде избрисан - проверите дозволе.';
 $lang['mediainuse']            = 'Фајл "%s" није избрисан - још је у употреби.';
 $lang['namespaces']            = 'Именски простори';
 $lang['mediafiles']            = 'Доступни фајлови у';
-$lang['js']['hidedetails']     = 'Сакриј детаље';
-$lang['js']['mu_btn']          = 'Слање више датотека одједном';
+$lang['accessdenied']          = 'Немате дозволу да видите ову страницу.';
 $lang['mediausage']            = 'Користите следећу синтаксу за референцу ка овој датотеци:';
 $lang['mediaview']             = 'Прикажи оригиналну датотеку';
 $lang['mediaroot']             = 'почетак';
@@ -122,6 +154,7 @@ $lang['current']               = 'тренутно';
 $lang['yours']                 = 'Ваша верзија';
 $lang['diff']                  = 'прикажи разлике до тренутне верзије';
 $lang['diff2']                 = 'Прикажи разлике између одабраних ревизија';
+$lang['difflink']              = 'Постави везу ка овом компаративном приказу';
 $lang['line']                  = 'Линија';
 $lang['breadcrumb']            = 'Траг';
 $lang['youarehere']            = 'Сада сте овде';
@@ -129,15 +162,16 @@ $lang['lastmod']               = 'Последњи пут мењано';
 $lang['by']                    = 'од';
 $lang['deleted']               = 'избрисано';
 $lang['created']               = 'направљено';
-$lang['restored']              = 'стара верзија повраћена';
+$lang['restored']              = 'стара верзија повраћена (%s)';
 $lang['external_edit']         = 'спољна измена';
 $lang['summary']               = 'Сажетак измене';
+$lang['noflash']               = 'За приказивање ове врсте материјала потребан вам је <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
+$lang['download']              = 'Преузми снипет';
 $lang['mail_newpage']          = 'страница додата:';
 $lang['mail_changed']          = 'страница измењена:';
+$lang['mail_subscribe_list']   = 'Странице промењене у именском простору:';
 $lang['mail_new_user']         = 'нови корисник:';
 $lang['mail_upload']           = 'послата датотека:';
-$lang['js']['nosmblinks']            = "Повезивање са Windows дељеним фолдерима ради само у Мајкрософтовом Интернет Претраживачу.\nИпак, можете да ископирате и залепите везу.";
-$lang['qb_alert']              = 'Молим вас, унесите текст који желите да форматизујете.\nБиће додат на крај документа.';
 $lang['qb_bold']               = 'Мастан текст';
 $lang['qb_italic']             = 'Курзивни текст';
 $lang['qb_underl']             = 'Подвучени текст';
@@ -148,6 +182,11 @@ $lang['qb_h2']                 = 'Наслов 2. нивоа';
 $lang['qb_h3']                 = 'Наслов 3. нивоа';
 $lang['qb_h4']                 = 'Наслов 4. нивоа';
 $lang['qb_h5']                 = 'Наслов 5. нивоа';
+$lang['qb_h']                  = 'Наслов';
+$lang['qb_hs']                 = 'Одабери наслов';
+$lang['qb_hplus']              = 'Виши наслов';
+$lang['qb_hminus']             = 'Нижи наслов';
+$lang['qb_hequal']             = 'Наслов на истом нивоу';
 $lang['qb_link']               = 'Унутрашња веза';
 $lang['qb_extlink']            = 'Спољашња веза';
 $lang['qb_hr']                 = 'Хоризонтална линија';
@@ -157,7 +196,7 @@ $lang['qb_media']              = 'Додај слике и друге фајло
 $lang['qb_sig']                = 'Убаци потпис';
 $lang['qb_smileys']            = 'Смешко';
 $lang['qb_chars']              = 'Посебни карактери';
-$lang['del_confirm']           = 'Обриши овај унос?';
+$lang['upperns']               = 'Скочи на виши именски простор';
 $lang['admin_register']        = 'Додај новог корисника';
 $lang['metaedit']              = 'Измени мета-податке';
 $lang['metasaveerr']           = 'Записивање мета-података није било успешно';
@@ -173,12 +212,22 @@ $lang['img_copyr']             = 'Права копирања';
 $lang['img_format']            = 'Формат';
 $lang['img_camera']            = 'Камера';
 $lang['img_keywords']          = 'Кључне речи';
-$lang['subscribe_success']     = 'Додао сам %s на листу претплатника за %s';
-$lang['subscribe_error']       = 'Дошло је до грешке при додавању %s на листу претплатника за %s';
-$lang['subscribe_noaddress']   = 'Не постоји е-адреса асоцирана са Вашим налогом. Не можете да будете додати на листу претплатника';
-$lang['unsubscribe_success']   = 'Избрисао сам %s са листе претплатника за %s';
-$lang['unsubscribe_error']     = 'Дошло је до грешке приликом брисања %s са листе претплатника за %s';
-$lang['authmodfailed']         = 'Лоше подешена провера корисника. Молим Вас да обавестите администратора викија.';
+$lang['subscr_subscribe_success'] = '%s је додат на списак претплатника %s';
+$lang['subscr_subscribe_error'] = 'Грешка приликом додавања %s на списак претплатника %s';
+$lang['subscr_subscribe_noaddress'] = 'Не постоји адреса повезана са вашим подацима, стога вас не можемо додати на списак претплатника.';
+$lang['subscr_unsubscribe_success'] = '%s уклоњен са списка претплатника %s';
+$lang['subscr_unsubscribe_error'] = 'Грешка приликом уклањања %s са списка претплатника %s';
+$lang['subscr_already_subscribed'] = '%s је већ претплаћен на %s';
+$lang['subscr_not_subscribed'] = '%s још није претплаћен на %s';
+$lang['subscr_m_not_subscribed'] = 'Тренутно нисте претплаћени на ову страницу или именски простор.';
+$lang['subscr_m_new_header']   = 'Додај претплату';
+$lang['subscr_m_current_header'] = 'Тренутне претплате';
+$lang['subscr_m_unsubscribe']  = 'Уклони претплату';
+$lang['subscr_m_subscribe']    = 'Претплати се';
+$lang['subscr_m_receive']      = 'Прими';
+$lang['subscr_style_every']    = 'имејл о свакој промени';
+$lang['subscr_style_digest']   = 'скраћени имејл о променама за сваку страницу (сваких %.2f дана)';
+$lang['subscr_style_list']     = 'Списак страница промењених након последњег имејла (сваких %.2f дана)';
 $lang['authtempfail']          = 'Провера корисника је тренутно недоступна. Ако се ситуација настави, молимо Вас да обавестите администратора викија.';
 $lang['i_chooselang']          = 'Одаберите језик';
 $lang['i_installer']           = 'Докувики инсталација';
@@ -194,23 +243,20 @@ $lang['i_confexists']          = '<code>%s</code> већ постоји';
 $lang['i_writeerr']            = 'Не могу да направим <code>%s</code>. Проверите дозволе а затим ручно направите ову датотеку.';
 $lang['i_badhash']             = 'dokuwiki.php није препознат или је измењен (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - недозвољена или празна вредност';
-$lang['i_success']             = 'Подешавања су завршена. Сада можете обрисати датотеку install.php. Наставите у <a href="doku.php">Ваш нови DokuWiki</a>.';
-$lang['i_failure']             = 'Појавили су се проблеми при писању датотеке са подешавањима. Требало би да их ручно исправите пре него што ћете моћи да користите <a href="doku.php">Ваш нови DokuWiki</a>.';
+$lang['i_success']             = 'Подешавања су завршена. Сада можете обрисати датотеку install.php. Наставите у <a href="doku.php?id=wiki:welcome">Ваш нови DokuWiki</a>.';
+$lang['i_failure']             = 'Појавили су се проблеми при писању датотеке са подешавањима. Требало би да их ручно исправите пре него што ћете моћи да користите <a href="doku.php?id=wiki:welcome">Ваш нови DokuWiki</a>.';
 $lang['i_policy']              = 'Иницијалне корисничке дозволе';
 $lang['i_pol0']                = 'Отворени вики (читање, писање, слање датотека за све)';
 $lang['i_pol1']                = 'Јавни вики (читање за све, писање и слање датотека само за регистроване кориснике)';
 $lang['i_pol2']                = 'Затворени вики (читање, писање и слање датотека само за регистроване кориснике)';
 $lang['i_retry']               = 'Понови';
-$lang['mu_intro']              = 'Одавде можете послати више датотека одједном. Кликните на дугме Тражи да бисте додали датотеке на листу. Када завршите са одабирањем кликните на Пошаљи.';
-$lang['mu_gridname']           = 'Назив датотеке';
-$lang['mu_gridsize']           = 'Величина';
-$lang['mu_gridstat']           = 'Статус';
-$lang['mu_namespace']          = 'Именски простор';
-$lang['mu_browse']             = 'Тражи';
-$lang['mu_toobig']             = 'превелико';
-$lang['mu_ready']              = 'спремно за слање';
-$lang['mu_done']               = 'завршено';
-$lang['mu_fail']               = 'није успело';
-$lang['mu_authfail']           = 'сесија је истекла';
-$lang['mu_progress']           = '@PCT@% послато';
-$lang['mu_filetypes']          = 'Дозвољени типови датотека';
+$lang['i_license']             = 'Молимо вас, одаберите лиценцу под коју желите да ставите свој садржај:';
+$lang['recent_global']         = 'Тренутно пратите промене у именском простору <b>%s</b>. Такође, можете пратити <a href="%s">прмене на целом викију</a>.';
+$lang['years']                 = 'Пре %d година';
+$lang['months']                = 'Пре %d месеци';
+$lang['weeks']                 = 'Пре %d недеља';
+$lang['days']                  = 'Пре %d дана';
+$lang['hours']                 = 'Пре %d сати';
+$lang['minutes']               = 'Пре %d минута';
+$lang['seconds']               = 'Пре %d секунди';
+$lang['wordblock']             = 'Ваше измене нису сачуване јер садрже забрањен текст (спам)';
