@@ -1,12 +1,11 @@
 <?php
+
 /**
- * Swedish language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ *
  * @author Joaquim Homrighausen <joho@webbplatsen.se>
  * @author Per Foreby <per@foreby.se>
  * @author Nicklas Henriksson <nicklas[at]nihe.se>
- * @author Håkan Sandell <hakan.sandell[at]mydata.se>
  * @author Håkan Sandell <hakan.sandell@home.se>
  * @author Dennis Karlsson
  * @author Tormod Otter Johansson <tormod@latast.se>
@@ -17,6 +16,9 @@
  * @author Bogge Bogge <bogge@bogge.com>
  * @author Peter Åström <eaustreum@gmail.com>
  * @author mikael@mallander.net
+ * @author Smorkster Andersson smorkster@gmail.com
+ * @author Henrik <henrik@idealis.se>
+ * @author Tor Härnqvist <tor.harnqvist@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -52,11 +54,15 @@ $lang['btn_backtomedia']       = 'Tillbaka till val av Mediafil';
 $lang['btn_subscribe']         = 'Prenumerera på ändringar';
 $lang['btn_profile']           = 'Uppdatera profil';
 $lang['btn_reset']             = 'Återställ';
+$lang['btn_resendpwd']         = 'Skapa nytt lösenord';
 $lang['btn_draft']             = 'Redigera utkast';
 $lang['btn_recover']           = 'Återskapa utkast';
 $lang['btn_draftdel']          = 'Radera utkast';
 $lang['btn_revert']            = 'Återställ';
 $lang['btn_register']          = 'Registrera';
+$lang['btn_apply']             = 'Verkställ';
+$lang['btn_media']             = 'Media Hanteraren';
+$lang['btn_deleteuser']        = 'Ta bort Mitt Konto';
 $lang['loggedinas']            = 'Inloggad som';
 $lang['user']                  = 'Användarnamn';
 $lang['pass']                  = 'Lösenord';
@@ -68,6 +74,7 @@ $lang['fullname']              = 'Namn';
 $lang['email']                 = 'E-post';
 $lang['profile']               = 'Användarprofil';
 $lang['badlogin']              = 'Felaktigt användarnamn eller lösenord.';
+$lang['badpassconfirm']        = 'Ledsen, lösenordet var felaktigt';
 $lang['minoredit']             = 'Små ändringar';
 $lang['draftdate']             = 'Utkast automatiskt sparat';
 $lang['nosecedit']             = 'Sidan ändrades medan du skrev, sektionsinformationen var inte uppdaterad. Laddar hela sidan istället.';
@@ -84,8 +91,14 @@ $lang['profna']                = 'Denna wiki stödjer inte ändringar av profile
 $lang['profnochange']          = 'Ingenting ändrades, inget att göra.';
 $lang['profnoempty']           = 'Namn och e-postadress måste fyllas i.';
 $lang['profchanged']           = 'Användarprofilen uppdaterad.';
+$lang['profnodelete']          = 'Den här wiki:n stödjer ej borttagning av användare';
+$lang['profdeleteuser']        = 'Radera kontot';
+$lang['profdeleted']           = 'Ditt användarkonto har raderats från den här wiki:n';
+$lang['profconfdelete']        = 'Jag vill ta bort mitt konto/inlogg på den här wiki:n <br/> Denna åtgärd går ej att ångra.';
+$lang['profconfdeletemissing'] = 'Bekräftelse-kryssrutan är ej markerad';
 $lang['pwdforget']             = 'Glömt ditt lösenord? Ordna ett nytt';
 $lang['resendna']              = 'Den här wikin stödjer inte utskick av lösenord.';
+$lang['resendpwd']             = 'Sätt lösenord för';
 $lang['resendpwdmissing']      = 'Du måste fylla i alla fält.';
 $lang['resendpwdnouser']       = 'Den här användaren hittas inte i databasen.';
 $lang['resendpwdbadauth']      = 'Den här verifieringskoden är inte giltig. Kontrollera att du använde hela verifieringslänken.';
@@ -98,9 +111,10 @@ $lang['searchmedia_in']        = 'Sök i %s';
 $lang['txt_upload']            = 'Välj fil att ladda upp';
 $lang['txt_filename']          = 'Ladda upp som (ej obligatoriskt)';
 $lang['txt_overwrt']           = 'Skriv över befintlig fil';
+$lang['maxuploadsize']         = 'Max %s per uppladdad fil.';
 $lang['lockedby']              = 'Låst av';
 $lang['lockexpire']            = 'Lås upphör att gälla';
-$lang['js']['willexpire']            = 'Ditt redigeringslås för detta dokument kommer snart att upphöra.\nFör att undvika versionskonflikter bör du förhandsgranska ditt dokument för att förlänga redigeringslåset.';
+$lang['js']['willexpire']      = 'Ditt redigeringslås för detta dokument kommer snart att upphöra.\nFör att undvika versionskonflikter bör du förhandsgranska ditt dokument för att förlänga redigeringslåset.';
 $lang['js']['notsavedyet']     = 'Det finns ändringar som inte är sparade.
 Är du säker på att du vill fortsätta?';
 $lang['js']['searchmedia']     = 'Sök efter filer';
@@ -112,12 +126,14 @@ $lang['js']['mediaalign']      = 'Justering';
 $lang['js']['mediasize']       = 'Bildstorlek';
 $lang['js']['mediatarget']     = 'Länköppning';
 $lang['js']['mediaclose']      = 'Stäng';
+$lang['js']['mediainsert']     = 'Infoga';
 $lang['js']['mediadisplayimg'] = 'Visa bilden.';
 $lang['js']['mediadisplaylnk'] = 'Visa endast länken.';
 $lang['js']['mediasmall']      = 'Liten storlek';
 $lang['js']['mediamedium']     = 'Mellanstor storlek';
 $lang['js']['medialarge']      = 'Stor storlek';
 $lang['js']['mediaoriginal']   = 'Originalstorlek';
+$lang['js']['medialnk']        = 'Länk till detalj sida';
 $lang['js']['mediadirect']     = 'Direktlänk till originalet';
 $lang['js']['medianolnk']      = 'Ingen länk';
 $lang['js']['medianolink']     = 'Länka inte bilden';
@@ -129,6 +145,15 @@ Du kan fortfarande klippa och klistra in länken om du använder en annan webbl
 $lang['js']['linkwiz']         = 'Snabbguide Länkar';
 $lang['js']['linkto']          = 'Länk till:';
 $lang['js']['del_confirm']     = 'Vill du verkligen radera?';
+$lang['js']['restore_confirm'] = 'Återställa denna version?';
+$lang['js']['media_diff']      = 'Se skillnader:';
+$lang['js']['media_diff_both'] = 'Sida vid sida';
+$lang['js']['media_select']    = 'Välj filer...';
+$lang['js']['media_upload_btn'] = 'Ladda upp';
+$lang['js']['media_done_btn']  = 'Färdig';
+$lang['js']['media_drop']      = 'Släpp filer här för att ladda upp';
+$lang['js']['media_cancel']    = 'ta bort';
+$lang['js']['media_overwrt']   = 'Skriv över existerande filer';
 $lang['rssfailed']             = 'Ett fel uppstod när detta RSS-flöde skulle hämtas: ';
 $lang['nothingfound']          = 'Inga filer hittades.';
 $lang['mediaselect']           = 'Mediafiler';
@@ -177,10 +202,19 @@ $lang['external_edit']         = 'extern redigering';
 $lang['summary']               = 'Redigeringskommentar';
 $lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> behövs för att visa detta innehåll.';
 $lang['download']              = 'Ladda ner kodfragmentet';
+$lang['tools']                 = 'Verktyg';
+$lang['user_tools']            = 'Användarverktyg';
+$lang['page_tools']            = 'Sidverktyg';
+$lang['skip_to_content']       = 'hoppa till innehåll';
 $lang['mail_newpage']          = 'sida tillagd:';
 $lang['mail_changed']          = 'sida ändrad:';
+$lang['mail_subscribe_list']   = 'sidor ändrade i namnrymd:';
 $lang['mail_new_user']         = 'Ny användare:';
 $lang['mail_upload']           = 'fil uppladdad:';
+$lang['changes_type']          = 'Se ändringar av';
+$lang['pages_changes']         = 'Sidor';
+$lang['media_changes']         = 'Mediafiler';
+$lang['both_changes']          = 'Både sidor och mediafiler';
 $lang['qb_bold']               = 'Fet text';
 $lang['qb_italic']             = 'Kursiv text';
 $lang['qb_underl']             = 'Understruken text';
@@ -221,14 +255,25 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Nyckelord';
+$lang['img_width']             = 'Bredd';
+$lang['img_height']            = 'Höjd';
+$lang['img_manager']           = 'Se mediahanteraren';
+$lang['subscr_subscribe_success'] = 'La till %s till prenumerationslista %s';
+$lang['subscr_subscribe_noaddress'] = 'Det finns ingen adress associerad med din inloggning, du kan inte bli tillagd i prenumerationslistan';
+$lang['subscr_unsubscribe_success'] = '%s borttagen från prenumerationslistan för %s';
+$lang['subscr_unsubscribe_error'] = 'Fel vid borttagning av %s från prenumerationslista %s';
+$lang['subscr_already_subscribed'] = '%s prenumererar redan på %s';
+$lang['subscr_not_subscribed'] = '%s prenumererar inte på %s';
+$lang['subscr_m_not_subscribed'] = 'Du prenumererar inte på denna sida eller namnrymd.';
 $lang['subscr_m_new_header']   = 'Lägg till prenumeration';
 $lang['subscr_m_current_header'] = 'Nuvarande prenumerationer';
 $lang['subscr_m_unsubscribe']  = 'Avsluta prenumeration';
 $lang['subscr_m_subscribe']    = 'Prenumerera';
 $lang['subscr_m_receive']      = 'Ta emot';
 $lang['subscr_style_every']    = 'skicka epost vid varje ändring';
-$lang['authmodfailed']         = 'Felaktiga inställningar för användarautentisering. Var vänlig meddela wikiadministratören.';
+$lang['subscr_style_list']     = 'lista över ändrade sidor sedan senaste e-post (varje %.2f dag)';
 $lang['authtempfail']          = 'Tillfälligt fel på användarautentisering. Om felet kvarstår, var vänlig meddela wikiadministratören.';
+$lang['authpwdexpire']         = 'Ditt lösenord kommer att bli ogiltigt om %d dagar, du bör ändra det snart.';
 $lang['i_chooselang']          = 'Välj språk';
 $lang['i_installer']           = 'Installation av DokuWiki';
 $lang['i_wikiname']            = 'Wikins namn';
@@ -254,6 +299,10 @@ $lang['i_pol0']                = 'Öppen wiki (alla får läsa, skriva och ladda
 $lang['i_pol1']                = 'Publik wiki (alla får läsa, registrerade användare för skriva och ladda upp filer)';
 $lang['i_pol2']                = 'Sluten wiki (endast registrerade användare får läsa, skriva och ladda upp filer)';
 $lang['i_retry']               = 'Försök igen';
+$lang['i_license']             = 'Vänligen välj licens du vill använda för ditt innehåll:';
+$lang['i_license_none']        = 'Visa ingen licensinformation';
+$lang['i_pop_field']           = 'Hjälp oss förbättra DokuWiki upplevelsen:';
+$lang['i_pop_label']           = 'Sänd anonym användarinformation en gång i månaden till DokuWikis utvecklare';
 $lang['recent_global']         = 'Du bevakar ändringar i namnrymden <b>%s</b>. Du kan också titta på <a href="%s">senaste ändringar för hela wikin</a>.';
 $lang['years']                 = '%d år sedan';
 $lang['months']                = '%d månader sedan';
@@ -263,3 +312,26 @@ $lang['hours']                 = '%d timmar sedan';
 $lang['minutes']               = '%d minuter sedan';
 $lang['seconds']               = '%d sekunder sedan';
 $lang['wordblock']             = 'Din ändring sparades inte för att den innehåller otillåten text (spam).';
+$lang['media_uploadtab']       = 'Ladda upp';
+$lang['media_searchtab']       = 'Sök';
+$lang['media_file']            = 'Fil';
+$lang['media_viewtab']         = 'Visa';
+$lang['media_edittab']         = 'Redigera';
+$lang['media_historytab']      = 'Historik';
+$lang['media_list_thumbs']     = 'Miniatyrbild';
+$lang['media_list_rows']       = 'Rader';
+$lang['media_sort_name']       = 'Namn';
+$lang['media_sort_date']       = 'Datum';
+$lang['media_namespaces']      = 'Visa namnrymd';
+$lang['media_files']           = 'Filer i %s';
+$lang['media_upload']          = 'Ladda upp till %s';
+$lang['media_search']          = 'Sök i %s';
+$lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s vid %s';
+$lang['media_edit']            = 'Redigera %s';
+$lang['media_history']         = '%s-historik';
+$lang['media_meta_edited']     = 'metadata redigerat';
+$lang['media_perm_read']       = 'Du har tyvärr inte tillräckliga behörigheter för att läsa filer.';
+$lang['media_perm_upload']     = 'Du har tyvärr inte tillräckliga behörigheter för att ladda upp filer.';
+$lang['media_update']          = 'Ladda upp ny version';
+$lang['media_restore']         = 'Återställ denna version';
