@@ -1,8 +1,8 @@
 <?php
+
 /**
- * Chinese(Simplified) language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author ZDYX <zhangduyixiong@gmail.com>
  * @author http://www.chinese-tools.com/tools/converter-tradsimp.html
  * @author George Sheraton <guxd@163.com>
@@ -15,6 +15,10 @@
  * @author caii, patent agent in China <zhoucaiqi@gmail.com>
  * @author lainme993@gmail.com
  * @author Shuo-Ting Jian <shoting@gmail.com>
+ * @author Rachel <rzhang0802@gmail.com>
+ * @author Donald <donaldtcong@gmail.com>
+ * @author Yangyu Huang <yangyu.huang@gmail.com>
+ * @author anjianshi <anjianshi@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -30,7 +34,7 @@ $lang['btn_create']            = '创建该页面';
 $lang['btn_search']            = '搜索';
 $lang['btn_save']              = '保存';
 $lang['btn_preview']           = '预览';
-$lang['btn_top']               = '到顶部';
+$lang['btn_top']               = '回到顶部';
 $lang['btn_newer']             = '<< 较新的';
 $lang['btn_older']             = '较旧的 >>';
 $lang['btn_revs']              = '修订记录';
@@ -58,6 +62,7 @@ $lang['btn_revert']            = '恢复';
 $lang['btn_register']          = '注册';
 $lang['btn_apply']             = '应用';
 $lang['btn_media']             = '媒体管理器';
+$lang['btn_deleteuser']        = '移除我的账户';
 $lang['loggedinas']            = '登录为';
 $lang['user']                  = '用户名';
 $lang['pass']                  = '密码';
@@ -69,10 +74,11 @@ $lang['fullname']              = '全名';
 $lang['email']                 = 'E-Mail';
 $lang['profile']               = '用户信息';
 $lang['badlogin']              = '对不起，用户名或密码错误。';
+$lang['badpassconfirm']        = '对不起，密码错误';
 $lang['minoredit']             = '细微修改';
 $lang['draftdate']             = '草稿自动保存于';
 $lang['nosecedit']             = '在您编辑期间本页刚被他人修改过，局部信息已过期，故载入全页。';
-$lang['regmissing']            = '对不起，您必须填写所有的区域。';
+$lang['regmissing']            = '对不起，您必须填写所有的字段。';
 $lang['reguexists']            = '对不起，该用户名已经存在。';
 $lang['regsuccess']            = '新用户已建立，密码将通过电子邮件发送给您。';
 $lang['regsuccess2']           = '新用户已建立';
@@ -81,10 +87,15 @@ $lang['regbadmail']            = '您输入的邮件地址有问题——如果
 $lang['regbadpass']            = '您输入的密码与系统产生的不符，请重试。';
 $lang['regpwmail']             = '您的 DokuWiki 密码';
 $lang['reghere']               = '还没有账号？立即注册';
-$lang['profna']                = '本维基不支持修改个人信息';
+$lang['profna']                = '本维基不允许修改个人信息';
 $lang['profnochange']          = '没有改动，不进行操作。';
 $lang['profnoempty']           = '不允许使用空的用户名或邮件地址。';
 $lang['profchanged']           = '用户信息更新成功。';
+$lang['profnodelete']          = '这个 wiki 不支持删除用户';
+$lang['profdeleteuser']        = '删除账号';
+$lang['profdeleted']           = '你的用户已经从这个 wiki 中删除';
+$lang['profconfdelete']        = '我希望删除我的账户。<br/>这项操作无法撤销。';
+$lang['profconfdeletemissing'] = '确认框未勾选';
 $lang['pwdforget']             = '忘记密码？立即获取新密码';
 $lang['resendna']              = '本维基不支持二次发送密码。';
 $lang['resendpwd']             = '设置新密码用于';
@@ -269,7 +280,6 @@ $lang['subscr_m_receive']      = '接收';
 $lang['subscr_style_every']    = '对每次更改发送邮件';
 $lang['subscr_style_digest']   = '对每个页面发送更改的摘要邮件（每 %.2f 天）';
 $lang['subscr_style_list']     = '自上封邮件以来更改的页面的列表（每 %.2f 天）';
-$lang['authmodfailed']         = '错误的用户认证设置。请通知维基管理员。';
 $lang['authtempfail']          = '用户认证暂时无法使用。如果该状态一直存在，请通知维基管理员。';
 $lang['authpwdexpire']         = '您的密码将在 %d 天内过期，请尽快更改';
 $lang['i_chooselang']          = '选择您的语言';
@@ -296,6 +306,7 @@ $lang['i_policy']              = '初始的 ACL 政策';
 $lang['i_pol0']                = '开放的维基（任何人都有读、写、上传的权限）';
 $lang['i_pol1']                = '公共的维基（任何人都有读的权限，只有注册用户才有写和上传的权限）';
 $lang['i_pol2']                = '关闭的维基（只有注册用户才有读、写、上传的权限）';
+$lang['i_allowreg']            = '允许用户自行注册';
 $lang['i_retry']               = '重试';
 $lang['i_license']             = '请选择您希望的内容发布许可协议：';
 $lang['i_license_none']        = '不要显示任何许可协议信息';
@@ -333,3 +344,5 @@ $lang['media_perm_read']       = '抱歉，您没有足够权限读取这些文
 $lang['media_perm_upload']     = '抱歉，您没有足够权限来上传文件。';
 $lang['media_update']          = '上传新版本';
 $lang['media_restore']         = '恢复这个版本';
+$lang['currentns']             = '当前命名空间';
+$lang['searchresult']          = '搜索结果';
