@@ -6,7 +6,6 @@
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 if(!defined('DOKU_INC')) die('meh.');
-require_once DOKU_INC . 'inc/parser/renderer.php';
 require_once DOKU_INC . 'inc/plugin.php';
 require_once DOKU_INC . 'inc/pluginutils.php';
 
@@ -21,6 +20,8 @@ class Doku_Renderer extends DokuWiki_Plugin {
         'toc'   => true, // render the TOC?
     );
 
+    var $doc = '';
+
     // keep some config options
     var $acronyms = array();
     var $smileys = array();
@@ -49,10 +50,19 @@ class Doku_Renderer extends DokuWiki_Plugin {
         trigger_error('getFormat() not implemented in '.get_class($this), E_USER_WARNING);
     }
 
+    /**
+     * Allow the plugin to prevent DokuWiki from reusing an instance
+     *
+     * @return bool   false if the plugin has to be instantiated
+     */
+    function isSingleton() {
+        return false;
+    }
+
 
     //handle plugin rendering
     function plugin($name,$data){
-        $plugin =& plugin_load('syntax',$name);
+        $plugin = plugin_load('syntax',$name);
         if($plugin != null){
             $plugin->render($this->getFormat(),$this,$data);
         }
@@ -64,10 +74,12 @@ class Doku_Renderer extends DokuWiki_Plugin {
      */
     function nest($instructions) {
 
-      foreach ( $instructions as $instruction ) {
-        // execute the callback against ourself
-        call_user_func_array(array(&$this, $instruction[0]),$instruction[1]);
-      }
+        foreach ( $instructions as $instruction ) {
+            // execute the callback against ourself
+            if (method_exists($this,$instruction[0])) {
+                call_user_func_array(array($this, $instruction[0]), $instruction[1] ? $instruction[1] : array());
+            }
+        }
     }
 
     // dummy closing instruction issued by Doku_Handler_Nest, normally the syntax mode should
@@ -85,8 +97,6 @@ class Doku_Renderer extends DokuWiki_Plugin {
 
     function header($text, $level, $pos) {}
 
-    function section_edit($start, $end, $level, $name) {}
-
     function section_open($level) {}
 
     function section_close() {}
@@ -161,13 +171,13 @@ class Doku_Renderer extends DokuWiki_Plugin {
 
     function preformatted($text) {}
 
-    function file($text) {}
-
     function quote_open() {}
 
     function quote_close() {}
 
-    function code($text, $lang = NULL) {}
+    function file($text, $lang = null, $file = null ) {}
+
+    function code($text, $lang = null, $file = null ) {}
 
     function acronym($acronym) {}
 
@@ -193,57 +203,57 @@ class Doku_Renderer extends DokuWiki_Plugin {
     // $link like 'SomePage'
     function camelcaselink($link) {}
 
-    function locallink($hash, $name = NULL) {}
+    function locallink($hash, $name = null) {}
 
     // $link like 'wiki:syntax', $title could be an array (media)
-    function internallink($link, $title = NULL) {}
+    function internallink($link, $title = null) {}
 
     // $link is full URL with scheme, $title could be an array (media)
-    function externallink($link, $title = NULL) {}
+    function externallink($link, $title = null) {}
 
     function rss ($url,$params) {}
 
     // $link is the original link - probably not much use
     // $wikiName is an indentifier for the wiki
     // $wikiUri is the URL fragment to append to some known URL
-    function interwikilink($link, $title = NULL, $wikiName, $wikiUri) {}
+    function interwikilink($link, $title = null, $wikiName, $wikiUri) {}
 
     // Link to file on users OS, $title could be an array (media)
-    function filelink($link, $title = NULL) {}
+    function filelink($link, $title = null) {}
 
     // Link to a Windows share, , $title could be an array (media)
-    function windowssharelink($link, $title = NULL) {}
+    function windowssharelink($link, $title = null) {}
 
-//  function email($address, $title = NULL) {}
-    function emaillink($address, $name = NULL) {}
+//  function email($address, $title = null) {}
+    function emaillink($address, $name = null) {}
 
-    function internalmedia ($src, $title=NULL, $align=NULL, $width=NULL,
-                            $height=NULL, $cache=NULL, $linking=NULL) {}
+    function internalmedia ($src, $title=null, $align=null, $width=null,
+                            $height=null, $cache=null, $linking=null) {}
 
-    function externalmedia ($src, $title=NULL, $align=NULL, $width=NULL,
-                            $height=NULL, $cache=NULL, $linking=NULL) {}
+    function externalmedia ($src, $title=null, $align=null, $width=null,
+                            $height=null, $cache=null, $linking=null) {}
 
     function internalmedialink (
-        $src,$title=NULL,$align=NULL,$width=NULL,$height=NULL,$cache=NULL
+        $src,$title=null,$align=null,$width=null,$height=null,$cache=null
         ) {}
 
     function externalmedialink(
-        $src,$title=NULL,$align=NULL,$width=NULL,$height=NULL,$cache=NULL
+        $src,$title=null,$align=null,$width=null,$height=null,$cache=null
         ) {}
 
-    function table_open($maxcols = NULL, $numrows = NULL){}
+    function table_open($maxcols = null, $numrows = null, $pos = null){}
 
-    function table_close(){}
+    function table_close($pos = null){}
 
     function tablerow_open(){}
 
     function tablerow_close(){}
 
-    function tableheader_open($colspan = 1, $align = NULL){}
+    function tableheader_open($colspan = 1, $align = null, $rowspan = 1){}
 
     function tableheader_close(){}
 
-    function tablecell_open($colspan = 1, $align = NULL){}
+    function tablecell_open($colspan = 1, $align = null, $rowspan = 1){}
 
     function tablecell_close(){}
 
@@ -264,20 +274,13 @@ class Doku_Renderer extends DokuWiki_Plugin {
         list($name,$hash) = explode('#',$name,2);
         if($hash) return $hash;
 
-        //trim colons or slash of a namespace link
-        $name = rtrim($name,':');
-        if($conf['useslash'])
-          $name = rtrim($name,'/');
-
         if($conf['useslash']){
-            $nssep = '[:;/]';
+            $name = strtr($name,';/',';:');
         }else{
-            $nssep = '[:;]';
+            $name = strtr($name,';',':');
         }
-        $name = preg_replace('!.*'.$nssep.'!','',$name);
 
-        if(!$name) return $this->_simpleTitle($conf['start']);
-        return $name;
+        return noNSorNS($name);
     }
 
     /**
@@ -294,7 +297,7 @@ class Doku_Renderer extends DokuWiki_Plugin {
         }
 
         //split into hash and url part
-        list($wikiUri,$hash) = explode('#',$wikiUri,2);
+        list($reference,$hash) = explode('#',$reference,2);
 
         //replace placeholder
         if(preg_match('#\{(URL|NAME|SCHEME|HOST|PORT|PATH|QUERY)\}#',$url)){
@@ -319,4 +322,4 @@ class Doku_Renderer extends DokuWiki_Plugin {
 }
 
 
-//Setup VIM: ex: et ts=4 enc=utf-8 :
+//Setup VIM: ex: et ts=4 :
