@@ -62,7 +62,7 @@ class Subscription {
             return false;
         }
 
-        if($conf['dperm']) chmod($lock, $conf['dperm']);
+        if(!empty($conf['dperm'])) chmod($lock, $conf['dperm']);
         return true;
     }
 
@@ -617,7 +617,7 @@ class Subscription {
      * @param string $rev The revision of the page, set to the current revision of the page $id if not set
      * @return string
      */
-    protected function getMessageID($id, $rev = NULL) {
+    protected function getMessageID($id, $rev = null) {
         static $listid = null;
         if (is_null($listid)) {
             $server = parse_url(DOKU_URL, PHP_URL_HOST);
@@ -694,4 +694,4 @@ class Subscription {
 function subscription_addresslist(&$data) {
     $sub = new Subscription();
     $sub->notifyaddresses($data);
-}
\ No newline at end of file
+}
