@@ -1,10 +1,15 @@
 <?php
+
 /**
- * Esperantolanguage file
- *
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Felipe Castro <fefcas@uol.com.br>
  * @author Felipo Kastro <fefcas@gmail.com>
  * @author Felipe Castro <fefcas@gmail.com>
+ * @author Robert Bogenschneider <robog@gmx.de>
+ * @author Erik Pedersen <erik pedersen@shaw.ca>
+ * @author Erik Pedersen <erik.pedersen@shaw.ca>
+ * @author Robert Bogenschneider <bogi@uea.org>
  */
 $lang['admin_acl']             = 'Administrado de Alirkontrola Listo (ACL)';
 $lang['acl_group']             = 'Grupo';
@@ -17,9 +22,9 @@ $lang['p_user_id']             = 'Uzanto <b class="acluser">%s</b> aktuale havas
 $lang['p_user_ns']             = 'Uzanto <b class="acluser">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
 $lang['p_group_id']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la paĝo <b class="aclpage">%s</b>: <i>%s</i>.';
 $lang['p_group_ns']            = 'Anoj de la grupo <b class="aclgroup">%s</b> aktuale havas la jenajn rajtojn en la nomspaco <b class="aclns">%s</b>: <i>%s</i>.';
-$lang['p_choose_id']           = 'Bonvole <b>enmeti uzulon aŭ grupon</b> en la suba agordilo por rigardi aŭ redakti la aron da rajtoj por la paĝo <b class="aclpage">%s</b>.';
-$lang['p_choose_ns']           = 'Bonvole <b>enmeti uzulon aŭ grupon</b> en la suba agordilo por rigardi aŭ redakti la aron da rajtoj por la nomspaco <b class="aclns">%s</b>.';
-$lang['p_inherited']           = 'Rimarko: tiuj rajtoj ne estis rekte difinitaj, sed ili estis hereditaj el aliaj pli superaj grupoj aŭ nomspacoj.';
+$lang['p_choose_id']           = 'Bonvolu <b>enmeti uzanton aŭ grupon</b> en la suban agordilon por rigardi aŭ redakti la aron da rajtoj por la paĝo <b class="aclpage">%s</b>.';
+$lang['p_choose_ns']           = 'Bonvolu <b>enmeti uzanton aŭ grupon</b> en la suban agordilon por rigardi aŭ redakti la aron da rajtoj por la nomspaco <b class="aclns">%s</b>.';
+$lang['p_inherited']           = 'Rimarko: tiuj rajtoj ne estas rekte difinitaj, sed ili herediĝas el aliaj pli supraj grupoj aŭ nomspacoj.';
 $lang['p_isadmin']             = 'Rimarko: la elektita grupo aŭ uzanto ĉiam havas plenan rajtaron ĉar ĝi estas difinita kiel superuzanto.';
 $lang['p_include']             = 'Plialtaj permesoj inkluzivas malpli altajn. La permesoj por Krei, Alŝuti kaj Forigi nur aplikeblas al nomspacoj, ne al paĝoj.';
 $lang['current']               = 'Aktuala regularo ACL';
@@ -32,5 +37,5 @@ $lang['acl_perm2']             = 'Redakti';
 $lang['acl_perm4']             = 'Krei';
 $lang['acl_perm8']             = 'Alŝuti';
 $lang['acl_perm16']            = 'Forigi';
-$lang['acl_new']               = 'Aldoni novan Enmetaĵon';
-$lang['acl_mod']               = 'Modifi Enmetaĵon';
+$lang['acl_new']               = 'Aldoni novan enmetaĵon';
+$lang['acl_mod']               = 'Modifi enmetaĵon';
