@@ -2,9 +2,11 @@
 /**
  * Galicianlanguage file
  *
- * @author CiberIrmandade da Fala <infoxeral@ciberirmandade.org>
+ * @author Medúlio <medulio@ciberirmandade.org>
+ * @author Oscar M. Lage <r0sk10@gmail.com>
+ * @author Rodrigo Rega <rodrigorega@gmail.com>
  */
-$lang['admin_acl']             = 'Xestión da Lista de Control de Acceso';
+$lang['admin_acl']             = 'Xestión da Lista de Control de Acceso (ACL)';
 $lang['acl_group']             = 'Grupo';
 $lang['acl_user']              = 'Usuario';
 $lang['acl_perms']             = 'Permisos para';
