@@ -26,32 +26,32 @@ $lang['_anti_spam']            = 'Pretspama iestatījumi';
 $lang['_editing']              = 'Labošanas iestatījumi';
 $lang['_links']                = 'Saišu iestatījumi';
 $lang['_media']                = 'Mēdiju iestatījumi';
+$lang['_notifications']        = 'Brīdinājumu iestatījumi';
 $lang['_advanced']             = 'Smalkāka iestatīšana';
 $lang['_network']              = 'Tīkla iestatījumi';
-$lang['_plugin_sufix']         = 'moduļa iestatījumi';
-$lang['_template_sufix']       = 'šablona iestatījumi';
 $lang['_msg_setting_undefined'] = 'Nav atrodami iestatījumu metadati';
 $lang['_msg_setting_no_class'] = 'Nav iestatījumu klases';
 $lang['_msg_setting_no_default'] = 'Nav noklusētās vērtības';
-$lang['fmode']                 = 'Tiesības izveidotajiem failiem';
-$lang['dmode']                 = 'Tiesības izveidotajām direktorijām';
-$lang['lang']                  = 'Valoda';
-$lang['basedir']               = 'Saknes direktorija';
-$lang['baseurl']               = 'Saknes adrese (URL)';
-$lang['savedir']               = 'Direktorija datu glabāšanai';
-$lang['start']                 = 'Sākumlapas vārds';
 $lang['title']                 = 'Wiki virsraksts';
+$lang['start']                 = 'Sākumlapas vārds';
+$lang['lang']                  = 'Valoda';
 $lang['template']              = 'Šablons';
 $lang['license']               = 'Ar kādu licenci saturs tiks publicēts?';
-$lang['fullpath']              = 'Norādīt kājenē pilnu lapas ceļu';
+$lang['savedir']               = 'Direktorija datu glabāšanai';
+$lang['basedir']               = 'Saknes direktorija';
+$lang['baseurl']               = 'Saknes adrese (URL)';
+$lang['dmode']                 = 'Tiesības izveidotajām direktorijām';
+$lang['fmode']                 = 'Tiesības izveidotajiem failiem';
+$lang['allowdebug']            = 'Ieslēgt atkļūdošanu. <b>Izslēdz!</b>';
 $lang['recent']                = 'Jaunākie grozījumi';
+$lang['recent_days']           = 'Cik dienas glabāt jaunākās izmaiņas';
 $lang['breadcrumbs']           = 'Apmeklējumu vēstures garums';
 $lang['youarehere']            = 'Rādīt "tu atrodies šeit"';
+$lang['fullpath']              = 'Norādīt kājenē pilnu lapas ceļu';
 $lang['typography']            = 'Veikt tipogrāfijas aizvietošanu';
-$lang['htmlok']                = 'Atļaut iekļautu HTTP';
-$lang['phpok']                 = 'Atļaut iekļautu PHP';
 $lang['dformat']               = 'Datuma formāts (sk. PHP <a href="http://www.php.net/strftime">strftime</a> funkciju)';
 $lang['signature']             = 'Paraksts';
+$lang['showuseras']            = 'Kā rādīt pēdējo lietotāju, ka labojis lapu';
 $lang['toptoclevel']           = 'Satura rādītāja pirmais līmenis';
 $lang['tocminheads']           = 'Mazākais virsrakstu skaits, no kuriem jāveido satura rādītājs.';
 $lang['maxtoclevel']           = 'Satura rādītāja dziļākais līmenis';
@@ -59,15 +59,8 @@ $lang['maxseclevel']           = 'Dziļākais sekciju labošanas līmenis';
 $lang['camelcase']             = 'Lietot saitēm CamelCase';
 $lang['deaccent']              = 'Lapu nosaukumu transliterācija';
 $lang['useheading']            = 'Izmantot pirmo virsrakstu lapu nosaukumiem';
-$lang['refcheck']              = 'Pārbaudīt saites uz mēdiju failiem';
-$lang['refshow']               = 'Cik saites uz mēdiju failiem rādīt';
-$lang['allowdebug']            = 'Ieslēgt atkļūdošanu. <b>Izslēdz!</b>';
-$lang['usewordblock']          = 'Bloķēt spamu pēc slikto vārdu saraksta.';
-$lang['indexdelay']            = 'Laika aizture pirms indeksācijas (sekundēs)';
-$lang['relnofollow']           = 'rel="nofollow" ārējām saitēm';
-$lang['mailguard']             = 'Slēpt epasta adreses';
-$lang['iexssprotect']          = 'Pārbaudīt, vai augšupielādētajā failā nav nav potenciāli bīstamā JavaScript vai HTML koda.';
-$lang['showuseras']            = 'Kā rādīt pēdējo lietotāju, ka labojis lapu';
+$lang['sneaky_index']          = 'Pēc noklusētā DokuWiki lapu sarakstā parāda visu nodaļu lapas. Ieslēdzot šo parametru, noslēps tās nodaļas, kuras apmeklētājam nav tiesības lasīt. Bet tad  tiks arī paslēptas dziļākas, bet atļautas nodaļas. Atsevišķos pieejas tiesību konfigurācijas gadījumos lapu saraksts var nedarboties.';
+$lang['hidepages']             = 'Slēpt lapas (regulāras izteiksmes)';
 $lang['useacl']                = 'Izmantot piekļuves tiesības';
 $lang['autopasswd']            = 'Automātiski ģenerēt paroles';
 $lang['authtype']              = 'Autentifikācijas mehānisms';
@@ -76,59 +69,62 @@ $lang['defaultgroup']          = 'Noklusētā grupa';
 $lang['superuser']             = 'Administrators - grupa, lietotājs vai to saraksts ( piem.: user1,@group1,user2), kam ir pilnas tiesības.';
 $lang['manager']               = 'Pārziņi - grupa, lietotājs vai to saraksts ( piem.: user1,@group1,user2), kam ir pieeja pie dažām administrēšanas funkcijām.';
 $lang['profileconfirm']        = 'Profila labošanai vajag paroli';
+$lang['rememberme']            = 'Atļaut pastāvīgas ielogošanās sīkdatnes ("atceries mani")';
 $lang['disableactions']        = 'Bloķēt Dokuwiki darbības';
 $lang['disableactions_check']  = 'atzīmēt';
 $lang['disableactions_subscription'] = 'abonēt/atteikties';
 $lang['disableactions_wikicode'] = 'skatīt/eksportēt izejtekstu';
 $lang['disableactions_other']  = 'citas darbības (atdalīt ar komatiem)';
-$lang['sneaky_index']          = 'Pēc noklusētā DokuWiki lapu sarakstā parāda visu nodaļu lapas. Ieslēdzot šo parametru, noslēps tās nodaļas, kuras apmeklētājam nav tiesības lasīt. Bet tad  tiks arī paslēptas dziļākas, bet atļautas nodaļas. Atsevišķos pieejas tiesību konfigurācijas gadījumos lapu saraksts var nedarboties.';
 $lang['auth_security_timeout'] = 'Autorizācijas drošības intervāls (sekundēs)';
 $lang['securecookie']          = 'Vai pa HTTPS sūtāmās sīkdatnes sūtīt tikai pa HTTPS? Atslēdz šo iespēju, kad tikai pieteikšanās wiki sistēmā notiek pa SSL šifrētu savienojumu, bet skatīšana  - pa nešifrētu.';
-$lang['xmlrpc']                = 'Ieslēgt/izslēgt XML-RPC interfeisu.';
-$lang['xmlrpcuser']            = 'Ierobežot  XML-RPC piekļuvi norādītām lietotāju grupām vai lietotājiem  (atdalīt ar komatiem!). Atstāt tukšu, lai piekļuve būtu visiem.';
-$lang['updatecheck']           = 'Pārbaudīt, vai pieejami atjauninājumi un drošības brīdinājumi? Dokuwiki sazināsies ar update.dokuwiki.org';
-$lang['userewrite']            = 'Ērti lasāmas adreses (URL)';
-$lang['useslash']              = 'Lietot slīpiņu  par URL atdalītāju';
+$lang['usewordblock']          = 'Bloķēt spamu pēc slikto vārdu saraksta.';
+$lang['relnofollow']           = 'rel="nofollow" ārējām saitēm';
+$lang['indexdelay']            = 'Laika aizture pirms indeksācijas (sekundēs)';
+$lang['mailguard']             = 'Slēpt epasta adreses';
+$lang['iexssprotect']          = 'Pārbaudīt, vai augšupielādētajā failā nav nav potenciāli bīstamā JavaScript vai HTML koda.';
 $lang['usedraft']              = 'Labojot automātiski saglabāt melnrakstu';
-$lang['sepchar']               = 'Lapas nosaukuma vārdu atdalītājs';
-$lang['canonical']             = 'Lietot kanoniskus URL';
-$lang['fnencode']              = 'Ne ASCII failvārdu kodēšanas metode:';
-$lang['autoplural']            = 'Automātisks daudzskaitlis';
-$lang['compression']           = 'Saspiešanas metode vecajiem failiem';
-$lang['cachetime']             = 'Bufera maksimālais vecums (sek)';
+$lang['htmlok']                = 'Atļaut iekļautu HTTP';
+$lang['phpok']                 = 'Atļaut iekļautu PHP';
 $lang['locktime']              = 'Bloķēšanas failu maksimālais vecums';
-$lang['fetchsize']             = 'Maksimālais faila apjoms baitos, ko fetch.php var ielādēt no interneta.';
-$lang['notify']                = 'Nosūtīt izmaiņu paziņojumu uz epasta adresi';
-$lang['registernotify']        = 'Nosūtīt paziņojumu par jauniem lietotājiem uz epasta adresi';
-$lang['mailfrom']              = 'Epasta adrese automātiskajiem paziņojumiem';
-$lang['mailprefix']            = 'E-pasta temata prefikss automātiskajiem paziņojumiem';
-$lang['gzip_output']           = 'Lietot gzip Content-Encoding priekš xhtml';
-$lang['gdlib']                 = 'GD Lib versija';
-$lang['im_convert']            = 'Ceļš uz ImageMagick convert rīku';
-$lang['jpg_quality']           = 'JPG saspiešanas kvalitāte';
-$lang['subscribers']           = 'Atļaut abonēt izmaiņas';
-$lang['subscribe_time']        = 'Pēc cik ilga laika izsūtīt abonētos sarakstus un kopsavilkumus (sekundes); jābūt mazākam par laiku, kas norādīts "recent_days".';
-$lang['compress']              = 'Saspiest CSS un javascript failus';
-$lang['hidepages']             = 'Slēpt lapas (regulāras izteiksmes)';
-$lang['send404']               = 'Par neesošām lapām atbildēt "HTTP 404/Page Not Found" ';
-$lang['sitemap']               = 'Lapas karte priekš Google (dienas)';
-$lang['broken_iua']            = 'Varbūt tavā serverī nedarbojas funkcija ignore_user_abort? Tā dēļ var nestādāt meklēšanas indeksācija. Šī problēma sastopama, piemēram, IIS ar PHP/CGI. Papildus informāciju skatīt <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Kļūdā Nr.852</a>.';
-$lang['xsendfile']             = 'Lietot X-Sendfile virsrakstu, augšupielādējot failu serverī? ';
-$lang['renderer_xhtml']        = 'Galveno (xhtml) wiki saturu renderēt ar ';
-$lang['renderer__core']        = '%s (dokuwiki kodols)';
-$lang['renderer__plugin']      = '%s (modulis)';
-$lang['rememberme']            = 'Atļaut pastāvīgas ielogošanās sīkdatnes ("atceries mani")';
-$lang['rss_type']              = 'XML barotnes veids';
-$lang['rss_linkto']            = 'XML barotnes uz ';
-$lang['rss_content']           = 'Ko attēlot XML barotnē?';
-$lang['rss_update']            = 'XML barotnes atjaunošanas intervāls (sec)';
-$lang['recent_days']           = 'Cik dienas glabāt jaunākās izmaiņas';
-$lang['rss_show_summary']      = 'Rādīt visrakstos XML barotnes kopsavilkumu ';
+$lang['cachetime']             = 'Bufera maksimālais vecums (sek)';
 $lang['target____wiki']        = 'Kur atvērt iekšējās saites';
 $lang['target____interwiki']   = 'Kur atvērt saites strap wiki';
 $lang['target____extern']      = 'Kur atvērt ārējās saites';
 $lang['target____media']       = 'Kur atvērt mēdiju saites';
 $lang['target____windows']     = 'Kur atvērt saites uz tīkla mapēm';
+$lang['refcheck']              = 'Pārbaudīt saites uz mēdiju failiem';
+$lang['gdlib']                 = 'GD Lib versija';
+$lang['im_convert']            = 'Ceļš uz ImageMagick convert rīku';
+$lang['jpg_quality']           = 'JPG saspiešanas kvalitāte';
+$lang['fetchsize']             = 'Maksimālais faila apjoms baitos, ko fetch.php var ielādēt no interneta.';
+$lang['subscribers']           = 'Atļaut abonēt izmaiņas';
+$lang['subscribe_time']        = 'Pēc cik ilga laika izsūtīt abonētos sarakstus un kopsavilkumus (sekundes); jābūt mazākam par laiku, kas norādīts "recent_days".';
+$lang['notify']                = 'Nosūtīt izmaiņu paziņojumu uz epasta adresi';
+$lang['registernotify']        = 'Nosūtīt paziņojumu par jauniem lietotājiem uz epasta adresi';
+$lang['mailfrom']              = 'Epasta adrese automātiskajiem paziņojumiem';
+$lang['mailprefix']            = 'E-pasta temata prefikss automātiskajiem paziņojumiem';
+$lang['sitemap']               = 'Lapas karte priekš Google (dienas)';
+$lang['rss_type']              = 'XML barotnes veids';
+$lang['rss_linkto']            = 'XML barotnes uz ';
+$lang['rss_content']           = 'Ko attēlot XML barotnē?';
+$lang['rss_update']            = 'XML barotnes atjaunošanas intervāls (sec)';
+$lang['rss_show_summary']      = 'Rādīt visrakstos XML barotnes kopsavilkumu ';
+$lang['updatecheck']           = 'Pārbaudīt, vai pieejami atjauninājumi un drošības brīdinājumi? Dokuwiki sazināsies ar update.dokuwiki.org';
+$lang['userewrite']            = 'Ērti lasāmas adreses (URL)';
+$lang['useslash']              = 'Lietot slīpiņu  par URL atdalītāju';
+$lang['sepchar']               = 'Lapas nosaukuma vārdu atdalītājs';
+$lang['canonical']             = 'Lietot kanoniskus URL';
+$lang['fnencode']              = 'Ne ASCII failvārdu kodēšanas metode:';
+$lang['autoplural']            = 'Automātisks daudzskaitlis';
+$lang['compression']           = 'Saspiešanas metode vecajiem failiem';
+$lang['gzip_output']           = 'Lietot gzip Content-Encoding priekš xhtml';
+$lang['compress']              = 'Saspiest CSS un javascript failus';
+$lang['send404']               = 'Par neesošām lapām atbildēt "HTTP 404/Page Not Found" ';
+$lang['broken_iua']            = 'Varbūt tavā serverī nedarbojas funkcija ignore_user_abort? Tā dēļ var nestādāt meklēšanas indeksācija. Šī problēma sastopama, piemēram, IIS ar PHP/CGI. Papildus informāciju skatīt <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Kļūdā Nr.852</a>.';
+$lang['xsendfile']             = 'Lietot X-Sendfile virsrakstu, augšupielādējot failu serverī? ';
+$lang['renderer_xhtml']        = 'Galveno (xhtml) wiki saturu renderēt ar ';
+$lang['renderer__core']        = '%s (dokuwiki kodols)';
+$lang['renderer__plugin']      = '%s (modulis)';
 $lang['proxy____host']         = 'Proxy servera vārds';
 $lang['proxy____port']         = 'Proxy ports';
 $lang['proxy____user']         = 'Proxy lietotāja vārds';
