@@ -1,8 +1,8 @@
 <?php
+
 /**
- * german language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Esther Brunner <esther@kaffeehaus.ch>
  * @author Andreas Gohr <andi@splitbrain.org>
  * @author Michael Klier <chi@chimeric.de>
@@ -16,6 +16,8 @@
  * @author Robert Bogenschneider <robog@gmx.de>
  * @author Niels Lange <niels@boldencursief.nl>
  * @author Christian Wichmann <nospam@zone0.de>
+ * @author Paul Lachewsky <kaeptn.haddock@gmail.com>
+ * @author Pierre Corell <info@joomla-praxis.de>
  */
 $lang['menu']                  = 'Plugins verwalten';
 $lang['download']              = 'Neues Plugin herunterladen und installieren';
@@ -51,14 +53,14 @@ $lang['desc']                  = 'Beschreibung:';
 $lang['author']                = 'Entwickler:';
 $lang['www']                   = 'Web:';
 $lang['error']                 = 'Ein unbekannter Fehler ist aufgetreten.';
-$lang['error_download']        = 'Konnte das Plugin %s nicht installieren';
+$lang['error_download']        = 'Konnte das Plugin %s nicht herunterladen';
 $lang['error_badurl']          = 'Wahrscheinlich ungültige URL, konnte keinen Dateinamen ausfindig machen';
 $lang['error_dircreate']       = 'Konnte keinen temporären Ordner für die Downloads erstellen';
 $lang['error_decompress']      = 'Der Plugin Manager konnte das Plugin-Archiv nicht entpacken. Entweder ist der Download fehlerhaft oder das Komprimierungsverfahren wird nicht unterstützt. Bitte versuchen Sie es erneut oder downloaden und installieren Sie das Plugin manuell.';
 $lang['error_copy']            = 'Beim Kopieren der Dateien des Plugins trat ein Fehler auf <em>%s</em>: möglicherweise ist die Festplatte voll oder die Dateiberechtigungen falsch. Möglicherweise wurde das Plugin nur teilweise installiert. Sie sollten das Plugin manuell entfernen um Instabilitäten zu vermeiden.';
-$lang['error_delete']          = 'Es gab einem Fehler beim Versuch das Plugin zu löschen <em>%s</em>. Dies liegt warscheinlich an fehlenden Dateiberechtigungen.';
+$lang['error_delete']          = 'Es gab einem Fehler beim Versuch das Plugin zu löschen <em>%s</em>. Dies liegt wahrscheinlich an fehlenden Dateiberechtigungen.';
 $lang['enabled']               = 'Plugin %s wurde aktiviert.';
 $lang['notenabled']            = 'Plugin %s konnte nicht aktiviert werden, überprüfen Sie die Dateirechte.';
 $lang['disabled']              = 'Plugin %s wurde deaktiviert.';
 $lang['notdisabled']           = 'Plugin %s konnte nicht deaktiviert werden, überprüfen Sie die Dateirechte.';
-$lang['packageinstalled']      = 'Plugin-Paket (%d Plugin%s: %s) erfolgreich installiert.';
+$lang['packageinstalled']      = 'Plugin-Paket (%d Plugin(s): %s) erfolgreich installiert.';
