@@ -1,8 +1,8 @@
 <?php
+
 /**
- * spanish language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Miguel Pagano <miguel.pagano@gmail.com>
  * @author Oscar M. Lage <r0sk10@gmail.com>
  * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
@@ -22,6 +22,8 @@
  * @author emezeta <emezeta@infoprimo.com>
  * @author Oscar Ciudad <oscar@jacho.net>
  * @author Ruben Figols <ruben.figols@gmail.com>
+ * @author Gerardo Zamudio <gerardo@gerardozamudio.net>
+ * @author Mercè López mercelz@gmail.com
  */
 $lang['menu']                  = 'Administración de Plugins';
 $lang['download']              = 'Descargar e instalar un nuevo plugin';
@@ -65,6 +67,6 @@ $lang['error_copy']            = 'Hubo un error al copiar el fichero mientras se
 $lang['error_delete']          = 'Hubo un error al intentar eliminar el plugin <em>%s</em>. La causa más probable es que no se cuente con los permisos necesarios en el fichero o en el directorio';
 $lang['enabled']               = 'Plugin %s habilitado.';
 $lang['notenabled']            = 'Plugin %s no puede ser habilitado, verifica los permisos del archivo.';
-$lang['disabled']              = 'Plugin %s desabilitado.';
-$lang['notdisabled']           = 'Plugin %s no puede ser desabilitado, verifica los permisos de archivo.';
+$lang['disabled']              = 'Plugin %s deshabilitado.';
+$lang['notdisabled']           = 'Plugin %s no puede ser deshabilitado, verifica los permisos de archivo.';
 $lang['packageinstalled']      = 'Plugin (%d plugin(s): %s) instalado exitosamente.';
