@@ -1,10 +1,13 @@
 <?php
+
 /**
- * hebrew language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author DoK <kamberd@yahoo.com>
  * @author Dotan Kamber <kamberd@yahoo.com>
+ * @author Moshe Kaplan <mokplan@gmail.com>
+ * @author Yaron Yogev <yaronyogev@gmail.com>
+ * @author Yaron Shahrabani <sh.yaron@gmail.com>
  */
 $lang['menu']                  = 'ניהול הרחבות';
 $lang['download']              = 'הורדת והתקנת הרחבה חדשה';
@@ -46,3 +49,7 @@ $lang['error_dircreate']       = 'כשל ביצירת תיקיה זמנית לק
 $lang['error_decompress']      = 'מנהל ההרחבות כשל בפרישת הקובץ שהורד. יתכן כי זו תוצאה של הורדה תקולה ובמקרה זה עליך לנסות שנית; או שיתכן כי תסדיר הכיווץ אינו ידוע, במקרה זה יהיה עליך להוריד ולהתקין את ההרחבה ידנית.';
 $lang['error_copy']            = 'חלה שגיאה בהעתקת הקובץ בניסיון להתקין קבצים להרחבה <em>%s</em>: ייתכן כי הדיסק מלא או שהרשאות הגישה לקבצים שגויות. יתכן כי בשל כך נוצרה התקנה חלקית של ההרחבה שתשאיר את התקנת הויקי שלך לא יציבה.';
 $lang['error_delete']          = 'חלה שגיאה בעת ניסיון למחיקת ההרחבה <em>%s</em>.  הסיבה הסבירה ביותר היא הרשאות גישה לקבצים ולספריות שאינן מספקות';
+$lang['enabled']               = 'תוסף %s מופעל.';
+$lang['notenabled']            = 'לא ניתן להפעיל את התוסף %s, בדוק הרשאות קבצים.';
+$lang['disabled']              = 'תוסף %s מושבת.';
+$lang['notdisabled']           = 'לא ניתן להשבית את התוסף %s, בדוק הרשאות קבצים.';
