@@ -1,7 +1,8 @@
 <?php
+
 /**
- * Portuguese language file
- *
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Frederico Gonçalves Guimarães <frederico@teia.bio.br>
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Lucien Raven <lucienraven@yahoo.com.br>
@@ -11,10 +12,16 @@
  * @author jair.henrique@gmail.com
  * @author Luis Dantas <luis@dantas.com>
  * @author Frederico Guimarães <frederico@teia.bio.br>
+ * @author Jair Henrique <jair.henrique@gmail.com>
+ * @author Luis Dantas <luisdantas@gmail.com>
+ * @author Sergio Motta sergio@cisne.com.br
+ * @author Isaias Masiero Filho <masiero@masiero.org>
+ * @author Balaco Baco <balacobaco@imap.cc>
+ * @author Victor Westmann <victor.westmann@gmail.com>
  */
-$lang['menu']                  = 'Gerenciar Plugins';
-$lang['download']              = 'Baixar e instalar um novo plugin';
-$lang['manage']                = 'Plugins instalados';
+$lang['menu']                  = 'Gerenciar Plug-ins';
+$lang['download']              = 'Baixar e instalar um novo plug-in';
+$lang['manage']                = 'Plug-ins instalados';
 $lang['btn_info']              = 'informações';
 $lang['btn_update']            = 'atualizar';
 $lang['btn_delete']            = 'excluir';
@@ -50,5 +57,10 @@ $lang['error_download']        = 'Não foi possível baixar o arquivo de plug-in
 $lang['error_badurl']          = 'Suspeita de URL mal formatada - não foi possível determinar o nome do arquivo a partir da URL';
 $lang['error_dircreate']       = 'Não foi possível criar a pasta temporária para receber a transferência';
 $lang['error_decompress']      = 'O gerenciador de plug-ins não conseguiu descompactar o arquivo transferido. Isso pode ser resultado de: uma corrupção do arquivo durante a transferência, nesse caso, você deve tentar novamente; ou o formato da compactação pode ser desconhecido, nesse caso você deve transferir e instalar o plug-in manualmente.';
-$lang['error_copy']            = 'Ocorreu um erro na cópia do arquivo na tentativa de instalar o plugin <em>%s</em>: o disco pode estar cheio ou as permissões de acesso do arquivo podem estar erradas. Isso pode resultar em um plug-in parcialmente instalado e deixar a instalação do seu wiki instável.';
-$lang['error_delete']          = 'Ocorreu um erro na tentativa de excluir o plug-in <em>%s</em>. A causa mais provável é a permissão de acesso ao diretório ou ao arquivo insuficiente.';
+$lang['error_copy']            = 'Ocorreu um erro de cópia de arquivo na tentativa de instalar o plug-in <em>%s</em>: o disco pode estar cheio ou as permissões de acesso ao arquivo podem estar erradas. Isso pode resultar em um plug-in parcialmente instalado e tornar o seu wiki instável.';
+$lang['error_delete']          = 'Ocorreu um erro na tentativa de excluir o plug-in <em>%s</em>. A causa mais provável é a permissão de acesso insuficiente ao diretório ou ao arquivo.';
+$lang['enabled']               = 'O plug-in %s foi habilitado.';
+$lang['notenabled']            = 'Não foi possível habilitar o plug-in %s. Verifique as permissões de acesso.';
+$lang['disabled']              = 'O plug-in %s foi desabilitado.';
+$lang['notdisabled']           = 'Não foi possível desabilitar o plug-in %s. Verifique as permissões de acesso.';
+$lang['packageinstalled']      = 'O pacote do plugin (%d plugin(s): %s) foi instalado com sucesso.';
