@@ -1,12 +1,15 @@
 <?php
+
 /**
- * Slovak language file
- *
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Ondrej Végh <ov@vsieti.sk>
  * @author Michal Mesko <michal.mesko@gmail.com>
+ * @author exusik@gmail.com
+ * @author Martin Michalek <michalek.dev@gmail.com>
  */
 $lang['menu']                  = 'Správa pluginov';
-$lang['download']              = 'Stiahnuť a nainštalovať  plugin';
+$lang['download']              = 'Stiahnuť a nainštalovať plugin';
 $lang['manage']                = 'Nainštalované pluginy';
 $lang['btn_info']              = 'info';
 $lang['btn_update']            = 'aktualizovať';
@@ -20,15 +23,15 @@ $lang['lastupdate']            = 'Aktualizovaný:';
 $lang['source']                = 'Zdroj:';
 $lang['unknown']               = 'neznámy';
 $lang['updating']              = 'Aktualizuje sa ...';
-$lang['updated']               = 'Plugin %s bol úspešne zaktualizovaný';
-$lang['updates']               = 'Nasledujúce pluginy bol úspešne zaktualizované:';
+$lang['updated']               = 'Plugin %s bol úspešne aktualizovaný';
+$lang['updates']               = 'Nasledujúce pluginy bol úspešne aktualizované:';
 $lang['update_none']           = 'Neboli nájdené žiadne aktualizácie.';
 $lang['deleting']              = 'Vymazáva sa ...';
 $lang['deleted']               = 'Plugin %s bol zmazaný.';
 $lang['downloading']           = 'Sťahuje sa ...';
 $lang['downloaded']            = 'Plugin %s bol úspešne stiahnutý';
 $lang['downloads']             = 'Nasledujúce pluginy bol úspešne stiahnuté:';
-$lang['download_none']         = 'Neboli nájdené žiadne pluginy, alebo nastal neznámy problém počas sťahovania a inštalácie pluginov.';
+$lang['download_none']         = 'Neboli nájdené žiadne pluginy alebo nastal neznámy problém počas sťahovania a inštalácie pluginov.';
 $lang['plugin']                = 'Plugin:';
 $lang['components']            = 'Súčasti';
 $lang['noinfo']                = 'Tento plugin neobsahuje žiadne informácie, je možné, že je chybný.';
@@ -42,6 +45,11 @@ $lang['error']                 = 'Nastala neznáma chyba.';
 $lang['error_download']        = 'Nie je možné stiahnuť súbor pluginu: %s';
 $lang['error_badurl']          = 'Pravdepodobne zlá url adresa - nie je možné z nej určiť meno súboru';
 $lang['error_dircreate']       = 'Nie je možné vytvoriť dočasný adresár pre uloženie sťahovaného súboru';
-$lang['error_decompress']      = 'Správca pluginov nedokáže dekomprimovať stiahnutý súbor. Môže to byť dôsledok zlého stiahnutia, v tom prípade to skúste znovu, alebo môže ísť o neznámy formát súboru, v tom prípade musítestiahnuť a nainštalovať plugin manuálne.';
-$lang['error_copy']            = 'Nastala chyba kopírovania súboru počas pokusu inštalovať súbory pluginu<em>%s</em>: disk môže byť plný, alebo prístupové práva k súboru môžu byť nesprávne. Toto môže mať za následok čiastočne nainštalovanie pluginu a nestabilitu vašej DokuWiki.';
-$lang['error_delete']          = 'Nastala chyba počas pokusu o zmazanie pluginu <em>%s</em>.  Najpravdepodobnejším dôvodom môžu byť nedostatočné prístupové práva pre súbor, alebo adresár';
+$lang['error_decompress']      = 'Správca pluginov nedokáže dekomprimovať stiahnutý súbor. Môže to byť dôsledok zlého stiahnutia, v tom prípade to skúste znovu, alebo môže ísť o neznámy formát súboru, v tom prípade musíte stiahnuť a nainštalovať plugin manuálne.';
+$lang['error_copy']            = 'Nastala chyba kopírovania súboru počas pokusu inštalovať súbory pluginu<em>%s</em>: disk môže byť plný alebo prístupové práva k súboru môžu byť nesprávne. Toto môže mať za následok čiastočne nainštalovanie pluginu a nestabilitu vašej DokuWiki.';
+$lang['error_delete']          = 'Nastala chyba počas pokusu o zmazanie pluginu <em>%s</em>.  Najpravdepodobnejším dôvodom môžu byť nedostatočné prístupové práva pre súbor alebo adresár';
+$lang['enabled']               = 'Plugin %s aktivovaný.';
+$lang['notenabled']            = 'Plugin %s nemôže byť aktivovaný, skontrolujte prístupové práva.';
+$lang['disabled']              = 'Plugin %s deaktivovaný.';
+$lang['notdisabled']           = 'Plugin %s nemôže byť deaktivovaný, skontrolujte prístupové práva.';
+$lang['packageinstalled']      = 'Plugin package (%d plugin(s): %s) úspešne inštalovaný.';
