@@ -1,11 +1,11 @@
 <?php
+
 /**
- * swedish language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Per Foreby <per@foreby.se>
  * @author Nicklas Henriksson <nicklas[at]nihe.se>
- * @author Håkan Sandell <hakan.sandell[at]mydata.se>
+ * @author Håkan Sandell <hakan.sandell@home.se>
  * @author Dennis Karlsson
  * @author Tormod Otter Johansson <tormod@latast.se>
  * @author emil@sys.nu
@@ -14,8 +14,8 @@
  * @author Emil Lind <emil@sys.nu>
  * @author Bogge Bogge <bogge@bogge.com>
  * @author Peter Åström <eaustreum@gmail.com>
- * @author Håkan Sandell <hakan.sandell@home.se>
  * @author mikael@mallander.net
+ * @author Smorkster Andersson smorkster@gmail.com
  */
 $lang['menu']                  = 'Hantera insticksmoduler';
 $lang['download']              = 'Ladda ned och installera en ny insticksmodul';
@@ -61,3 +61,4 @@ $lang['enabled']               = 'Tilläggsmodulen %s är aktiverad.';
 $lang['notenabled']            = 'Tilläggsmodulen %s kunde inte aktiveras, kontrollera filrättigheterna.';
 $lang['disabled']              = 'Tiläggsmodulen %s är avaktiverad.';
 $lang['notdisabled']           = 'Tilläggsmodulen %s kunde inte avaktiveras, kontrollera filrättigheterna.';
+$lang['packageinstalled']      = 'Tilläggs paket (%d tillägg: %s) har installerats.';
