@@ -1,17 +1,22 @@
 <?php
+
 /**
- * ukrainian language file
- *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Oleksiy Voronin (ovoronin@gmail.com)
  * @author serg_stetsuk@ukr.net
+ * @author okunia@gmail.com
+ * @author Oleksandr Kunytsia <okunia@gmail.com>
+ * @author Uko uko@uar.net
+ * @author Ulrikhe Lukoie  <lukoie@gmail>.com
+ * @author Kate Arzamastseva pshns@ukr.net
  */
 $lang['menu']                  = 'Керування доданками';
 $lang['download']              = 'Завантажити та встановити новий доданок';
 $lang['manage']                = 'Встановлені доданки';
 $lang['btn_info']              = 'дані';
 $lang['btn_update']            = 'оновити';
-$lang['btn_delete']            = 'вилучити';
+$lang['btn_delete']            = 'видалити';
 $lang['btn_settings']          = 'параметри';
 $lang['btn_download']          = 'Завантажити';
 $lang['btn_enable']            = 'Зберегти';
@@ -24,8 +29,8 @@ $lang['updating']              = 'Оновлення ...';
 $lang['updated']               = 'Доданок %s успішно оновлено';
 $lang['updates']               = 'Наступні доданки були успішно оновлені';
 $lang['update_none']           = 'Оновлення не знайдено.';
-$lang['deleting']              = 'Знищення ...';
-$lang['deleted']               = 'Доданок %s вилучено.';
+$lang['deleting']              = 'Видалення ...';
+$lang['deleted']               = 'Доданок %s видалено.';
 $lang['downloading']           = 'Завантаження ...';
 $lang['downloaded']            = 'Доданок %s успішно встановлено';
 $lang['downloads']             = 'Наступні доданки були успішно встановлені:';
@@ -41,8 +46,13 @@ $lang['author']                = 'Автор:';
 $lang['www']                   = 'Сторінка:';
 $lang['error']                 = 'Виникла невідома помилка.';
 $lang['error_download']        = 'Не можу завантажити файл доданка: %s';
-$lang['error_badurl']          = 'Можливо, невірна адреса - не можливо визначити ім\'я файла з адреси';
-$lang['error_dircreate']       = 'Не можливо створити тимчасову теку для завантаження';
+$lang['error_badurl']          = 'Можливо, невірна адреса - не можливо визначити ім\'я файлу з адреси';
+$lang['error_dircreate']       = 'Не можливо створити тимчасову папку для завантаження';
 $lang['error_decompress']      = 'Менеджеру доданків не вдалося розпакувати завантажений файл. Це може бути результатом помилки при завантаженні, в цьому разі ви можете спробувати знову; або ж доданок упакований невідомим архіватором, тоді вам необхідно завантажити та встановити доданок вручну.';
 $lang['error_copy']            = 'Виникла помилка копіювання при спробі установки файлів для доданка <em>%s</em>: переповнення диску або невірні права доступу. Це могло привести до часткової установки доданка и нестійкості вашої Вікі.';
-$lang['error_delete']          = 'При спробі вилучення доданка <em>%s</em> виникла помилка.  Найбільш вірогідно, що немає необхідних прав доступу до файлів або тек';
+$lang['error_delete']          = 'При спробі вилучення доданка <em>%s</em> виникла помилка.  Найбільш вірогідно, що немає необхідних прав доступу до файлів або директорії';
+$lang['enabled']               = 'Доданок %s увімкнено.';
+$lang['notenabled']            = 'Не вдається увімкнути доданок %s. Перевірте права доступу до файлу.';
+$lang['disabled']              = 'Доданок %s вимкнено.';
+$lang['notdisabled']           = 'Не вдається вимкнути доданок %s. Перевірте права доступу до файлу.';
+$lang['packageinstalled']      = 'Пакет плагінів (%d plugin(s): %s) успішно встановлений.';
