@@ -1,18 +1,23 @@
 <?php
+
 /**
- * Esperantolanguage file
- *
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Felipe Castro <fefcas@uol.com.br>
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
  * @author Felipo Kastro <fefcas@gmail.com>
+ * @author Robert Bogenschneider <robog@gmx.de>
+ * @author Erik Pedersen <erik pedersen@shaw.ca>
+ * @author Erik Pedersen <erik.pedersen@shaw.ca>
+ * @author Robert Bogenschneider <bogi@uea.org>
  */
-$lang['menu']                  = 'Administrado de Restarigo';
+$lang['menu']                  = 'Administrado de restarigo';
 $lang['filter']                = 'Serĉi spamecajn paĝojn';
 $lang['revert']                = 'Restarigi la elektitajn paĝojn';
 $lang['reverted']              = '%s estas restarigita al revizio %s';
 $lang['removed']               = '%s estas forigita';
-$lang['revstart']              = 'Restariga procezo estas ekigita. Tio povas daŭri longan tempon. Se la skripto tro prokrastos antaŭ plenumo, vi bezonos restarigi po pli etaj blokoj.';
+$lang['revstart']              = 'Restariga procezo ekis. Tio povas daŭri longan tempon. Se la skripto tro prokrastos antaŭ plenumo, vi restarigu po pli etaj blokoj.';
 $lang['revstop']               = 'Restariga procezo plenumiĝis sukcese.';
 $lang['note1']                 = 'Rimarko: tiu ĉi serĉo distingas usklecon';
 $lang['note2']                 = 'Rimarko: la paĝo restariĝos al la lasta versio ne enhavanta la menditan spaman terminon <i>%s</i>.';
