@@ -1,12 +1,15 @@
 <?php
+
 /**
- * Hungarian language file
- *
+ * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * 
  * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
  * @author Siaynoq Mage <siaynoqmage@gmail.com>
  * @author schilling.janos@gmail.com
  * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
  * @author Sándor TIHANYI <stihanyi+dw@gmail.com>
+ * @author David Szabo <szabo.david@gyumolcstarhely.hu>
+ * @author Marton Sebok <sebokmarton@gmail.com>
  */
 $lang['menu']                  = 'Visszaállítás kezelő (anti-SPAM)';
 $lang['filter']                = 'SPAM tartalmú oldalak keresése';
@@ -15,5 +18,5 @@ $lang['reverted']              = '%s a következő változatra lett visszaállí
 $lang['removed']               = '%s törölve';
 $lang['revstart']              = 'A visszaállítási folyamat elindult. Ez hosszú ideig eltarthat. Ha időtúllépés miatt nem tud lefutni, kisebb darabbal kell próbálkozni.';
 $lang['revstop']               = 'A visszaállítási folyamat sikeresen befejeződött.';
-$lang['note1']                 = 'Megjegyzés: a keresés kisbetű-nagybetűre érzékeny';
+$lang['note1']                 = 'Megjegyzés: a keresés kisbetű-nagybetű érzékeny';
 $lang['note2']                 = 'Megjegyzés: Az oldalt az utolsó olyan változatra állítjuk vissza, ami nem tartalmazza a megadott spam kifejezést: <i>%s</i>.';
