@@ -8,9 +8,6 @@
 // must be run within Dokuwiki
 if(!defined('DOKU_INC')) die();
 
-if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
-require_once(DOKU_INC.'inc/parser/parser.php');
-
 /**
  * All DokuWiki plugins to extend the parser/rendering mechanism
  * need to inherit from this class
@@ -36,7 +33,11 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
      * url    - Website with more information on the plugin (eg. syntax description)
      */
     function getInfo(){
-        trigger_error('getType() not implemented in '.get_class($this), E_USER_WARNING);
+        $parts = explode('_',get_class($this));
+        $info  = DOKU_PLUGIN.'/'.$parts[2].'/plugin.info.txt';
+        if(@file_exists($info)) return confToHash($info);
+        trigger_error('getInfo() not implemented in '.get_class($this).' and '.$info.' not found', E_USER_WARNING);
+        return array();
     }
 
     /**
@@ -83,13 +84,13 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
      *
      * Usually you should only need the $match param.
      *
-     * @param   $match   string    The text matched by the patterns
-     * @param   $state   int       The lexer state for the match
-     * @param   $pos     int       The character position of the matched text
-     * @param   $handler ref       Reference to the Doku_Handler object
-     * @return  array              Return an array with all data you want to use in render
+     * @param   string       $match   The text matched by the patterns
+     * @param   int          $state   The lexer state for the match
+     * @param   int          $pos     The character position of the matched text
+     * @param   Doku_Handler $handler Reference to the Doku_Handler object
+     * @return  array Return an array with all data you want to use in render
      */
-    function handle($match, $state, $pos, &$handler){
+    function handle($match, $state, $pos, Doku_Handler &$handler){
         trigger_error('handle() not implemented in '.get_class($this), E_USER_WARNING);
     }
 
@@ -111,12 +112,12 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
      * The contents of the $data array depends on what the handler() function above
      * created
      *
-     * @param   $format   string   output format being rendered
-     * @param   $renderer ref      reference to the current renderer object
-     * @param   $data     array    data created by handler()
-     * @return  boolean            rendered correctly?
+     * @param   $format   string        output format being rendered
+     * @param   $renderer Doku_Renderer reference to the current renderer object
+     * @param   $data     array         data created by handler()
+     * @return  boolean                 rendered correctly?
      */
-    function render($format, &$renderer, $data) {
+    function render($format, Doku_Renderer &$renderer, $data) {
         trigger_error('render() not implemented in '.get_class($this), E_USER_WARNING);
 
     }
@@ -136,7 +137,7 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
 
             $idx = array_search(substr(get_class($this), 7), (array) $this->allowedModes);
             if ($idx !== false) {
-              unset($this->allowedModes[$idx]);
+                unset($this->allowedModes[$idx]);
             }
             $this->allowedModesSetup = true;
         }
@@ -148,6 +149,12 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
     // extract from class name, format = <plugin type>_plugin_<name>[_<component name>]
     function getPluginType() { list($t) = explode('_', get_class($this), 2); return $t;  }
     function getPluginName() { list($t, $p, $n) = explode('_', get_class($this), 4); return $n; }
+
+    /**
+     * Get the name of the component of the current class
+     *
+     * @return string component name
+     */
     function getPluginComponent() { list($t, $p, $n, $c) = explode('_', get_class($this), 4); return (isset($c)?$c:''); }
 
     // localisation methods
@@ -158,13 +165,13 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
      * to try to minimise unnecessary loading of the strings when the plugin doesn't require them
      * e.g. when info plugin is querying plugins for information about themselves.
      *
-     * @param   $id     id of the string to be retrieved
+     * @param   string $id     id of the string to be retrieved
      * @return  string  string in appropriate language or english if not available
      */
     function getLang($id) {
-      if (!$this->localised) $this->setupLocale();
+        if (!$this->localised) $this->setupLocale();
 
-      return (isset($this->lang[$id]) ? $this->lang[$id] : '');
+        return (isset($this->lang[$id]) ? $this->lang[$id] : '');
     }
 
     /**
@@ -173,11 +180,11 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
      * retrieve a language dependent wiki page and pass to xhtml renderer for display
      * plugin equivalent of p_locale_xhtml()
      *
-     * @param   $id     id of language dependent wiki page
+     * @param   string  $id     id of language dependent wiki page
      * @return  string  parsed contents of the wiki page in xhtml format
      */
     function locale_xhtml($id) {
-      return p_cached_output($this->localFN($id));
+        return p_cached_output($this->localFN($id));
     }
 
     /**
@@ -186,14 +193,17 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
      * plugin equivalent of localFN()
      */
     function localFN($id) {
-      global $conf;
-      $plugin = $this->getPluginName();
-      $file = DOKU_PLUGIN.$plugin.'/lang/'.$conf['lang'].'/'.$id.'.txt';
-      if(!@file_exists($file)){
-        //fall back to english
-        $file = DOKU_PLUGIN.$plugin.'/lang/en/'.$id.'.txt';
-      }
-      return $file;
+        global $conf;
+        $plugin = $this->getPluginName();
+        $file = DOKU_CONF.'/plugin_lang/'.$plugin.'/'.$conf['lang'].'/'.$id.'.txt';
+        if (!@file_exists($file)){
+            $file = DOKU_PLUGIN.$plugin.'/lang/'.$conf['lang'].'/'.$id.'.txt';
+            if(!@file_exists($file)){
+                //fall back to english
+                $file = DOKU_PLUGIN.$plugin.'/lang/en/'.$id.'.txt';
+            }
+        }
+        return $file;
     }
 
     /**
@@ -204,75 +214,97 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
     function setupLocale() {
         if ($this->localised) return;
 
-      global $conf;            // definitely don't invoke "global $lang"
-      $path = DOKU_PLUGIN.$this->getPluginName().'/lang/';
+        global $conf;            // definitely don't invoke "global $lang"
+        $path = DOKU_PLUGIN.$this->getPluginName().'/lang/';
 
-      // don't include once, in case several plugin components require the same language file
-      @include($path.'en/lang.php');
-      if ($conf['lang'] != 'en') @include($path.$conf['lang'].'/lang.php');
+        $lang = array();
+        // don't include once, in case several plugin components require the same language file
+        @include($path.'en/lang.php');
+        if ($conf['lang'] != 'en') @include($path.$conf['lang'].'/lang.php');
 
-      $this->lang = $lang;
-      $this->localised = true;
+        $this->lang = $lang;
+        $this->localised = true;
     }
 
-  // configuration methods
-  /**
-   * getConf($setting)
-   *
-   * use this function to access plugin configuration variables
-   */
-  function getConf($setting){
+    // configuration methods
+    /**
+     * getConf($setting)
+     *
+     * use this function to access plugin configuration variables
+     */
+    function getConf($setting) {
 
-    if (!$this->configloaded){ $this->loadConfig(); }
+        if(!$this->configloaded) { $this->loadConfig(); }
 
-    return $this->conf[$setting];
-  }
-
-  /**
-   * loadConfig()
-   * merges the plugin's default settings with any local settings
-   * this function is automatically called through getConf()
-   */
-  function loadConfig(){
-    global $conf;
-
-    $defaults = $this->readDefaultSettings();
-    $plugin = $this->getPluginName();
-
-    foreach ($defaults as $key => $value) {
-      if (isset($conf['plugin'][$plugin][$key])) continue;
-      $conf['plugin'][$plugin][$key] = $value;
+        return $this->conf[$setting];
     }
 
-    $this->configloaded = true;
-    $this->conf =& $conf['plugin'][$plugin];
-  }
+    /**
+     * loadConfig()
+     * merges the plugin's default settings with any local settings
+     * this function is automatically called through getConf()
+     */
+    function loadConfig() {
+        global $conf;
 
-  /**
-   * read the plugin's default configuration settings from conf/default.php
-   * this function is automatically called through getConf()
-   *
-   * @return    array    setting => value
-   */
-  function readDefaultSettings() {
+        $defaults = $this->readDefaultSettings();
+        $plugin   = $this->getPluginName();
 
-    $path = DOKU_PLUGIN.$this->getPluginName().'/conf/';
-    $conf = array();
+        foreach($defaults as $key => $value) {
+            if(isset($conf['plugin'][$plugin][$key])) continue;
+            $conf['plugin'][$plugin][$key] = $value;
+        }
 
-    if (@file_exists($path.'default.php')) {
-      include($path.'default.php');
+        $this->configloaded = true;
+        $this->conf         =& $conf['plugin'][$plugin];
     }
 
-    return $conf;
-  }
+    /**
+     * read the plugin's default configuration settings from conf/default.php
+     * this function is automatically called through getConf()
+     *
+     * @return    array    setting => value
+     */
+    function readDefaultSettings() {
+
+        $path = DOKU_PLUGIN.$this->getPluginName().'/conf/';
+        $conf = array();
+
+        if(@file_exists($path.'default.php')) {
+            include($path.'default.php');
+        }
+
+        return $conf;
+    }
+
+    /**
+     * Loads a given helper plugin (if enabled)
+     *
+     * @author  Esther Brunner <wikidesign@gmail.com>
+     *
+     * @param   string $name   name of plugin to load
+     * @param   bool   $msg    if a message should be displayed in case the plugin is not available
+     *
+     * @return  object  helper plugin object
+     */
+    function loadHelper($name, $msg = true) {
+        if(!plugin_isdisabled($name)) {
+            $obj = plugin_load('helper', $name);
+        } else {
+            $obj = null;
+        }
+        if(is_null($obj) && $msg) msg("Helper plugin $name is not available or invalid.", -1);
+        return $obj;
+    }
+
+    /**
+     * Allow the plugin to prevent DokuWiki from reusing an instance
+     *
+     * @return bool   false if the plugin has to be instantiated
+     */
+    function isSingleton() {
+        return true;
+    }
 
-  /**
-   * Allow the plugin to prevent DokuWiki creating a second instance of itself
-   *
-   * @return bool   true if the plugin can not be instantiated more than once
-   */
-  function isSingleton() {
-    return false;
-  }
 }
-//Setup VIM: ex: et ts=4 enc=utf-8 :
+//Setup VIM: ex: et ts=4 :
